component property
Component
get
component
The current configuration of the Element that is this BuildContext.
Implementation
Component get component;
The current configuration of the Element that is this BuildContext.
Component get component;