ArcaneForgotPasswordCard class

Password reset card with email input and reset link functionality.

Inheritance

Constructors

ArcaneForgotPasswordCard({Component? header, String? loginRoute, void onSuccess()?, String maxWidth = '400px', Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loginRoute String?
final
maxWidth String
final
onSuccess → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneForgotPasswordCard>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited