SocialSignInButton class

Social sign-in button with branded styling for OAuth providers.

Inheritance

Constructors

SocialSignInButton({SocialProvider? provider, String? label, Component? icon, void onPressed()?, ButtonSize size = ButtonSize.medium, bool disabled = false, bool loading = false, bool fullWidth = false, String? backgroundColor, String? foregroundColor, String? borderColor, String? hoverBackgroundColor, Key? key})
const
SocialSignInButton.apple({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.discord({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.facebook({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.github({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.gitlab({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.google({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.linkedin({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.microsoft({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.slack({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory
SocialSignInButton.twitter({void onPressed()?, String? label, ButtonSize size, bool fullWidth, bool disabled, bool loading, Key? key})
const
factory

Properties

backgroundColor String?
final
borderColor String?
final
disabled bool
final
foregroundColor String?
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
hoverBackgroundColor String?
final
icon Component?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
loading bool
final
onPressed → void Function()?
final
provider SocialProvider?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ButtonSize
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited