ArcaneCard class

Card component with consistent styling and multiple variants.

Inheritance

Constructors

ArcaneCard({Component? child, List<Component>? children, CardVariant variant = CardVariant.elevated, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const
ArcaneCard.elevated({Component? child, List<Component>? children, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const
ArcaneCard.flat({Component? child, List<Component>? children, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const
ArcaneCard.ghost({Component? child, List<Component>? children, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const
ArcaneCard.glass({Component? child, List<Component>? children, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const
ArcaneCard.interactive({Component? child, List<Component>? children, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const
ArcaneCard.outlined({Component? child, List<Component>? children, String? padding, String? borderRadius, void onTap()?, void onClick()?, String? backgroundColor, bool fillWidth = false, Key? key})
const

Properties

backgroundColor String?
final
borderRadius String?
final
fillWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant CardVariant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited