ArcaneStructuredCard class

Card with header, body, and footer sections.

Inheritance

Constructors

ArcaneStructuredCard({Component? header, required Component body, Component? footer, EdgeInsets? padding, double? radius, bool border = true, int elevation = 0, void onTap()?, void onClick()?, Key? key})
const

Properties

body Component
final
border bool
final
elevation int
final
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding EdgeInsets?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited