build method

  1. @override
Widget build(
  1. BuildContext context
)
override

Describes the part of the user interface represented by this component.

The framework calls this method when this component is inserted into the tree in a given BuildContext and when the dependencies of this component change (e.g., an InheritedComponent referenced by this component changes). This method can potentially be called in every frame and should not have any side effects beyond building a component.

The framework replaces the subtree below this component with the component returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the component returned by this method can update the root of the existing subtree, as determined by calling Component.canUpdate.

Typically implementations return a newly created constellation of components that are configured with information from this component's constructor and from the given BuildContext.

The given BuildContext contains information about the location in the tree at which this component is being built. For example, the context provides the set of inherited components for this location in the tree. A given component might be built with multiple different BuildContext arguments over time if the component is moved around the tree or if the component is inserted into the tree in multiple places at once.

The implementation of this method must only depend on:

If a component's build method is to depend on anything else, use a StatefulComponent instead.

See also:

Implementation

@override
Widget build(BuildContext context) {
  final boxShadow = switch (elevation) {
    0 => 'none',
    1 => '0 1px 2px 0 rgb(0 0 0 / 0.05)',
    2 => '0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1)',
    3 => '0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1)',
    _ => '0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1)',
  };

  return dom.div(
    classes: 'arcane-structured-card',
    styles: dom.Styles(raw: {
      'background-color': 'var(--card)',
      'border-radius': radius != null ? '${radius}px' : '0.75rem',
      if (border) 'border': '1px solid var(--border)',
      'box-shadow': boxShadow,
      'overflow': 'hidden',
      if (_onTap != null) 'cursor': 'pointer',
      if (_onTap != null) 'transition': 'all 150ms ease',
    }),
    events: _onTap != null
        ? {
            'click': (event) => _onTap(),
          }
        : null,
    [
      if (header != null)
        dom.div(
          classes: 'arcane-structured-card-header',
          styles: const dom.Styles(raw: {
            'padding': '1rem',
            'border-bottom': '1px solid var(--border)',
          }),
          [header!],
        ),
      dom.div(
        classes: 'arcane-structured-card-body',
        styles: dom.Styles(raw: {
          'padding': (padding ?? const EdgeInsets.all(16)).padding,
        }),
        [body],
      ),
      if (footer != null)
        dom.div(
          classes: 'arcane-structured-card-footer',
          styles: const dom.Styles(raw: {
            'padding': '0.5rem 1rem',
            'border-top': '1px solid var(--border)',
            'background-color': 'var(--muted)',
          }),
          [footer!],
        ),
    ],
  );
}