ariaLabel property
Accessible name for the card's root element. This is most useful when its visible descendants do not already provide a meaningful name.
Implementation
final String? ariaLabel;
Accessible name for the card's root element. This is most useful when its visible descendants do not already provide a meaningful name.
final String? ariaLabel;