ArcaneFlexiCards class

Interactive card group where hovering magnifies focused card while shrinking others.

Inheritance

Constructors

ArcaneFlexiCards({required List<FlexiCardItem> items, double collapsedFlex = 1.0, double expandedFlex = 2.0, bool scaleHeight = false, double heightScaleFactor = 1.05, String gap = '1.5rem', String minCardWidth = '200px', int transitionDuration = 300, bool expandLongTextOnHover = true, String? heightPreLock, String? heightPostLock, String? widthPreLock, String? widthPostLock, Key? key})
const

Properties

collapsedFlex double
final
expandedFlex double
final
expandLongTextOnHover bool
final
gap String
final
hashCode int
The hash code for this object.
no setterinherited
heightPostLock String?
final
heightPreLock String?
final
heightScaleFactor double
final
items List<FlexiCardItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
minCardWidth String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleHeight bool
final
transitionDuration int
final
widthPostLock String?
final
widthPreLock String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited