ArcaneFlexiCardsSimple class

Simpler flexi cards variant using CSS :hover without state management.

Inheritance

Constructors

ArcaneFlexiCardsSimple({required List<FlexiCardItem> items, String gap = '1.5rem', Key? key})
const

Properties

gap String
final
hashCode int
The hash code for this object.
no setterinherited
items List<FlexiCardItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited