ArcaneIntegrationGrid class
Grid layout for multiple integration cards.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneIntegrationGrid
Constructors
-
ArcaneIntegrationGrid({required List<
IntegrationCardProps> integrations, int columns = 3, double gap = 24, String? title, String? description, Key? key}) -
const
Properties
- columns → int
-
final
- description → String?
-
final
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
integrations
→ List<
IntegrationCardProps> -
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited