component/card/pricing_card library
Classes
- PricingCard
- A plan surface: an optional icon, a title, a price row, an optional subtitle, an included/excluded feature list, an optional spec table, and a call-to-action button. Themed automatically by the active stylesheet.
- PricingGrid
- A responsive grid of pricing cards, one per tiers entry, laid out in columns equal columns (defaulting to one column per tier). Themed automatically by the active stylesheet.