PricingGrid class
A responsive grid of pricing cards, one per tiers entry, laid out in columns equal columns (defaulting to one column per tier). Themed automatically by the active stylesheet.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- PricingGrid
Constructors
-
PricingGrid({required List<
PricingTier> tiers, void onTierSelected(PricingTier tier)?, int? columns, Key? key}) -
const
Properties
- columns → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onTierSelected → void Function(PricingTier tier)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tiers
→ List<
PricingTier> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited