ArcaneSurfaceCard class

Card with surface effects like blur, frosted glass, or gradients.

Inheritance

Constructors

ArcaneSurfaceCard({required Component child, SurfaceEffect effect = SurfaceEffect.none, double blurAmount = 10.0, double backgroundOpacity = 0.8, String? backgroundColor, List<String>? gradientColors, int gradientAngle = 135, String? borderRadius, bool showBorder = true, String? padding, ShadowIntensity shadow = ShadowIntensity.md, Key? key})
const
ArcaneSurfaceCard.blur({required Component child, double blurAmount = 10.0, double backgroundOpacity = 0.8, String? backgroundColor, String? borderRadius, bool showBorder = true, String? padding, ShadowIntensity shadow = ShadowIntensity.md, Key? key})
const
ArcaneSurfaceCard.frosted({required Component child, double blurAmount = 12.0, double backgroundOpacity = 0.6, String? backgroundColor, String? borderRadius, bool showBorder = true, String? padding, ShadowIntensity shadow = ShadowIntensity.md, Key? key})
const
ArcaneSurfaceCard.glass({required Component child, double blurAmount = 16.0, double backgroundOpacity = 0.4, String? backgroundColor, String? borderRadius, bool showBorder = true, String? padding, ShadowIntensity shadow = ShadowIntensity.lg, Key? key})
const
ArcaneSurfaceCard.gradient({required Component child, List<String>? gradientColors, int gradientAngle = 135, String? borderRadius, bool showBorder = false, String? padding, ShadowIntensity shadow = ShadowIntensity.md, Key? key})
const

Properties

backgroundColor String?
final
backgroundOpacity double
final
blurAmount double
final
borderRadius String?
final
child Component
final
effect SurfaceEffect
final
gradientAngle int
final
gradientColors List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow ShadowIntensity
final
showBorder bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited