ArcaneHeroCarousel class

Hero carousel with full-width slides.

Inheritance

Constructors

ArcaneHeroCarousel({Key? key, required List<Widget> children, int autoPlayInterval = 5000, bool showArrows = true, bool showIndicators = true, String height = '400px'})
const

Properties

autoPlayInterval int
final
children List<Widget>
final
hashCode int
The hash code for this object.
no setterinherited
height String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrows bool
final
showIndicators bool
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneHeroCarousel>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final