ArcaneNavigableCarousel class

Carousel with navigation arrows.

Inheritance

Constructors

ArcaneNavigableCarousel({Key? key, required List<Widget> children, double gap = 16, bool showArrows = true, bool showIndicators = true, int visibleItems = 1, String? height})
const

Properties

children List<Widget>
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrows bool
final
showIndicators bool
final
visibleItems int
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneNavigableCarousel>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final