CardCarousel class

Horizontally scrollable widget container with edge fading.

Inheritance

Constructors

CardCarousel({Key? key, List<Widget> children = const [], int? sharpness, String? featherColor, double gap = 16, String? padding, String? height})
const

Properties

children List<Widget>
final
featherColor String?
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharpness int?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final