HeroCarousel class

A hero carousel with full-width slides.

Inheritance

Constructors

HeroCarousel({Key? key, required List<Component> children, int autoPlayInterval = 5000, bool showArrows = true, bool showIndicators = true, String height = '400px'})
const

Properties

autoPlayInterval int
Auto-play interval in milliseconds (0 to disable).
final
children List<Component>
Slides to display.
final
hashCode int
The hash code for this object.
no setterinherited
height String
Height of the carousel.
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrows bool
Whether to show navigation arrows.
final
showIndicators bool
Whether to show dot indicators.
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<HeroCarousel>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final