NavigableCarousel class

A carousel with navigation arrows.

Inheritance

Constructors

const

Properties

children List<Component>
The collection of widgets to render.
final
gap double
Gap between items.
final
hashCode int
The hash code for this object.
no setterinherited
height String?
Height constraint.
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrows bool
Whether to show navigation arrows.
final
showIndicators bool
Whether to show dot indicators.
final
visibleItems int
Items visible at once (for snapping).
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<NavigableCarousel>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final