ArcaneCollection class

Flexible container for rendering lists of components.

Inheritance

Constructors

ArcaneCollection({Key? key, List<Component> children = const [], Axis direction = Axis.vertical, double gap = 0, bool scrollable = false, String? padding})
const
ArcaneCollection.builder({Key? key, required Component builder(BuildContext context, int index)?, required int? childCount, Axis direction = Axis.vertical, double gap = 0, bool scrollable = false, String? padding})
const

Properties

builder Component Function(BuildContext context, int index)?
final
childCount int?
final
children List<Component>
final
direction Axis
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited