ArcaneDataColumn<T> class

Column definition for ArcaneDataTable.

Constructors

ArcaneDataColumn({required String header, required Component builder(T item), DataTableTextAlign align = DataTableTextAlign.left, double? width, bool sortable = false})
const

Properties

align DataTableTextAlign
final
builder Component Function(T item)
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortable bool
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited