ArcaneTimeline class

Timeline component for displaying chronological events or process steps.

Inheritance

Constructors

ArcaneTimeline({required List<ArcaneTimelineItem> items, TimelineLayout layout = TimelineLayout.vertical, TimelineSize size = TimelineSize.md, bool showConnectors = true, Key? key})
const
ArcaneTimeline.alternating({required List<ArcaneTimelineItem> items, TimelineSize size = TimelineSize.md, bool showConnectors = true, Key? key})
const
ArcaneTimeline.horizontal({required List<ArcaneTimelineItem> items, TimelineSize size = TimelineSize.md, bool showConnectors = true, Key? key})
const
ArcaneTimeline.vertical({required List<ArcaneTimelineItem> items, TimelineSize size = TimelineSize.md, bool showConnectors = true, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<ArcaneTimelineItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
layout TimelineLayout
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showConnectors bool
final
size TimelineSize
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited