ArcaneTimelineItem class

Timeline item data.

Constructors

ArcaneTimelineItem({required String title, String? subtitle, String? description, String? date, Component? icon, TimelineStatus status = TimelineStatus.default_, Component? content})
const

Properties

content Component?
final
date String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TimelineStatus
final
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() TimelineItemData
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited