ArcaneTracker class

Dense status grid for time-series or health indicators.

Inheritance

Constructors

ArcaneTracker({required List<TrackerData> data, int columns = 12, int cellSize = 12, int gap = 3, bool showTooltips = true, bool showLegend = false, Map<TrackerLevel, String>? levelColors, void onCellTap(int index, TrackerData data)?, Key? key})
const
ArcaneTracker.monthly({required List<TrackerData> data, int cellSize = 12, int gap = 2, bool showTooltips = true, bool showLegend = true, Map<TrackerLevel, String>? levelColors, void onCellTap(int index, TrackerData data)?, Key? key})
const
ArcaneTracker.weekly({required List<TrackerData> data, int cellSize = 14, int gap = 3, bool showTooltips = true, bool showLegend = true, Map<TrackerLevel, String>? levelColors, void onCellTap(int index, TrackerData data)?, Key? key})
const

Properties

cellSize int
final
columns int
final
data List<TrackerData>
final
gap int
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
levelColors Map<TrackerLevel, String>?
final
onCellTap → void Function(int index, TrackerData data)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLegend bool
final
showTooltips bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited