ArcaneTreeView class

Hierarchical tree view component for displaying nested data.

Inheritance

Constructors

ArcaneTreeView({required List<TreeNode> nodes, void onNodeSelect(TreeNode node)?, void onNodeToggle(TreeNode node, bool expanded)?, TreeViewStyle style = TreeViewStyle.lines, TreeSelectionMode selectionMode = TreeSelectionMode.single, Set<String> initiallyExpanded = const {}, Set<String> selectedNodes = const {}, bool expandAll = false, Key? key})
const

Properties

expandAll bool
final
hashCode int
The hash code for this object.
no setterinherited
initiallyExpanded Set<String>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
nodes List<TreeNode>
final
onNodeSelect → void Function(TreeNode node)?
final
onNodeToggle → void Function(TreeNode node, bool expanded)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedNodes Set<String>
final
selectionMode TreeSelectionMode
final
style TreeViewStyle
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited