TreeNode class

Tree node data.

Constructors

TreeNode({required String id, required String label, Component? icon, List<TreeNode> children = const [], bool disabled = false, dynamic data})
const

Properties

children List<TreeNode>
final
data → dynamic
final
disabled bool
final
hasChildren bool
no setter
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
id String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() TreeNodeData
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited