ConfirmDialog class

A confirmation dialog component.

Inheritance

Constructors

ConfirmDialog({required String title, required String message, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm()?, void onCancel()?, bool destructive = false, Component? icon, Key? key})
const

Properties

cancelText String
Cancel button text
final
confirmText String
Confirm button text
final
destructive bool
Whether this is a destructive action
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
Custom icon
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String
Dialog message
final
onCancel → void Function()?
Cancel callback
final
onConfirm → void Function()?
Confirm callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Dialog title
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited