ConfirmText class

Inheritance

Constructors

ConfirmText({required String title, required String confirmPhrase, void onConfirm(String value)?, void onCancel()?, String? description, Key? key})
const

Properties

confirmPhrase String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onCancel → void Function()?
final
onConfirm → void Function(String value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ConfirmText>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited