DialogDateMulti class

Inheritance

Constructors

DialogDateMulti({required String title, required void onConfirm(List<DateTime>), List<DateTime> values = const <DateTime>[], Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onConfirm → void Function(List<DateTime>)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
values List<DateTime>
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<DialogDateMulti>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited