ArcaneDialog class

Modal dialog component with title, content, and actions.

Inheritance

Constructors

ArcaneDialog({String? title, Widget? child, List<Widget>? children, List<Widget>? actions, bool showCloseButton = true, void onClose()?, double maxWidth = 500, bool barrierDismissible = true, Key? key})
const

Properties

actions List<Widget>?
final
barrierDismissible bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxWidth double
final
onClose → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool
final
title String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited