Sheet class

A sheet/drawer dialog that slides in from the edge.

Inheritance

Constructors

Sheet({required Component child, SheetPosition position = SheetPosition.right, void onClose()?, bool showCloseButton = true, String? title, double? width, double? height, Key? key})
const

Properties

child Component
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onClose → void Function()?
final
position SheetPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool
final
title String?
final
width double?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final