DialogEmail class

Inheritance

Constructors

DialogEmail({required String title, required void onConfirm(String result), String? description, String? initialValue, Key? key})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onConfirm → void Function(String result)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited