DialogText class

Inheritance

Constructors

DialogText({required String title, required void onConfirm(String result), String? description, Widget descriptionWidget = const SizedBox.shrink(), String confirmText = 'Done', String cancelText = 'Cancel', Widget? placeholder, bool obscureText = false, String? initialValue, List<Widget>? actions, int maxLines = 1, int? minLines, int? maxLength, TextInputType keyboardType = TextInputType.text, Key? key})
const

Properties

actions List<Widget>?
final
cancelText String
final
confirmText String
final
description String?
final
descriptionWidget Widget
final
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
keyboardType TextInputType
final
maxLength int?
final
maxLines int
final
minLines int?
final
obscureText bool
final
onConfirm → void Function(String result)
final
placeholder Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<DialogText>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited