ArcaneTimeDialog class

Time picker dialog with hour/minute selection.

Inheritance

Constructors

ArcaneTimeDialog({required String title, String? message, TimeOfDay? initialTime, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(TimeOfDay time)?, void onCancel()?, bool use24Hour = false, int minuteInterval = 1, bool showSeconds = false, Key? key})
const

Properties

cancelText String
final
confirmText String
final
hashCode int
The hash code for this object.
no setterinherited
initialTime TimeOfDay?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String?
final
minuteInterval int
final
onCancel → void Function()?
final
onConfirm → void Function(TimeOfDay time)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSeconds bool
final
title String
final
use24Hour bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited