Toast class
A toast notification component.
- Inheritance
Constructors
Properties
- action → Component?
-
Optional action button
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component?
-
Custom icon
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- message → String
-
Toast message
final
- onClose → void Function()?
-
Close handler
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool
-
Whether to show close button
final
- title → String?
-
Toast title
final
- variant → ToastVariant
-
Toast variant
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited