ArcaneTooltip class

Inheritance

Constructors

ArcaneTooltip({required Widget child, required String? text, FloatingPosition position = FloatingPosition.top, double? maxWidth = 250, Key? key})
const
ArcaneTooltip.custom({required Widget child, required Widget? content, FloatingPosition position = FloatingPosition.top, double? maxWidth, Key? key})
const

Properties

child Widget
final
content Widget?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxWidth double?
final
position FloatingPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited