ArcaneAlertBanner class

Alert/banner component with variant styles.

Inheritance

Constructors

ArcaneAlertBanner({required String message, String? title, AlertBannerVariant variant = AlertBannerVariant.info, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
const
ArcaneAlertBanner.error({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
const
ArcaneAlertBanner.info({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
const
ArcaneAlertBanner.success({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
const
ArcaneAlertBanner.warning({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
const

Properties

action Component?
final
dismissible bool
final
filled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String
final
onDismiss → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
variant AlertBannerVariant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited