ProgressBar class

A progress bar component

Inheritance

Constructors

ProgressBar({double value = 0, bool indeterminate = false, double height = 8, bool showLabel = false, String? color, Key? key})
const

Properties

color String?
Custom color
final
hashCode int
The hash code for this object.
no setterinherited
height double
Bar height
final
indeterminate bool
Whether to show indeterminate animation
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabel bool
Show percentage label
final
value double
Progress value (0-100)
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final