InfoTooltip class

An info icon with tooltip

Inheritance

Constructors

InfoTooltip({required String content, double size = 16, TooltipPosition position = TooltipPosition.top, Key? key})
const

Properties

content String
Tooltip content
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
position TooltipPosition
Tooltip position
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Icon size
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final