AuthButton class

Styled button for authentication forms with loading state.

Inheritance

Constructors

AuthButton({Key? key, required String label, void onPressed()?, AuthButtonVariant variant = AuthButtonVariant.primary, bool loading = false, bool fullWidth = true, bool disabled = false, String type = 'button'})
const

Properties

disabled bool
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
final
loading bool
final
onPressed → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
variant AuthButtonVariant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited