ArcaneField<T> class

Generic form field component with provider-based state management.

Inheritance

Constructors

ArcaneField({required ArcaneFieldMetadata meta, required ArcaneFieldProvider<T> provider, required Widget builder(BuildContext context, T value, void onChanged(T)), Key? key})
const

Properties

builder Widget Function(BuildContext context, T value, void onChanged(T))
final
dataRuntimeType Type
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
meta ArcaneFieldMetadata
final
provider ArcaneFieldProvider<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneField<T>>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited