ArcaneFieldMetadata class

Metadata for an ArcaneField.

Constructors

ArcaneFieldMetadata({String? name, String? key, String? icon, String? description, String? placeholder})
const

Properties

description String?
final
effectiveKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
key String?
final
name String?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited