ArcaneFieldWrapper class

Wrapper for form fields providing consistent styling and layout.

Inheritance

Constructors

ArcaneFieldWrapper({required Widget field, String? labelText, String? description, String? icon, String? error, bool required = false, bool showValidation = true, Widget? leading, Widget? trailing, Key? key})
const

Properties

description String?
final
error String?
final
field Widget
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
labelText String?
final
leading Widget?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValidation bool
final
trailing Widget?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited