ArcaneForm class

Complete form component with built-in state management.

Inheritance

Constructors

ArcaneForm({required List<Component> children, String? submitText = 'Submit', String? cancelText = 'Cancel', void onSubmit()?, void onCancel()?, bool showActions = true, double spacing = 16, Key? key})
const

Properties

cancelText String?
final
children List<Component>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onCancel → void Function()?
final
onSubmit → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showActions bool
final
spacing double
final
submitText String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited