ArcaneWaitlistForm class

Waitlist form with optional name collection.

Inheritance

Constructors

ArcaneWaitlistForm({String? title, String? description, String buttonText = 'Join Waitlist', String successMessage = "You're on the list! We'll be in touch.", void onSubmit(String email, String? name)?, bool collectName = true, Key? key})
const

Properties

buttonText String
final
collectName bool
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onSubmit → void Function(String email, String? name)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successMessage String
final
title String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited