ArcaneFieldMapProvider<T> class

Field provider using nested Map storage with dot notation access.

Inheritance

Constructors

ArcaneFieldMapProvider({required T defaultValue, required Map<String, dynamic> storage})

Properties

currentValue → T
no setterinherited
defaultValue → T
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage Map<String, dynamic>
final
stream Stream<T>
no setterinherited

Methods

dispose() → void
inherited
getValue(String k) Future<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onGetValue(String k) Future<T>
override
onSetValue(String k, T value) Future<void>
override
setValue(String k, T value) Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited