ArcaneFieldProvider<T> class
abstract
Abstract base class for form field providers.
- Implementers
Constructors
- ArcaneFieldProvider({required T defaultValue})
Properties
- currentValue → T
-
no setter
- defaultValue → T
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
T> -
no setter
Methods
-
dispose(
) → void -
getValue(
String k) → Future< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onGetValue(
String k) → Future< T> -
onSetValue(
String k, T value) → Future< void> -
setValue(
String k, T value) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited