ArcaneFormContext class

Form context data for accessing form state.

Constructors

ArcaneFormContext({required Map<String, dynamic> values, required Map<String, String?> errors, required void setValue(String key, dynamic value), required void setError(String key, String? error), required void submit(), required bool isValid})
const

Properties

errors Map<String, String?>
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setError → void Function(String key, String? error)
final
setValue → void Function(String key, dynamic value)
final
submit → void Function()
final
values Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited