ArcaneFormProvider class

Form provider component that manages form state.

Inheritance

Constructors

ArcaneFormProvider({Map<String, dynamic> initialValues = const {}, void onSubmit(Map<String, dynamic> values)?, Map<String, String?> validator(Map<String, dynamic> values)?, required Widget builder(ArcaneFormContext context), Key? key})
const

Properties

builder Widget Function(ArcaneFormContext context)
final
hashCode int
The hash code for this object.
no setterinherited
initialValues Map<String, dynamic>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onSubmit → void Function(Map<String, dynamic> values)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator Map<String, String?> Function(Map<String, dynamic> values)?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneFormProvider>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited