ArcaneRawButton class
Raw button element wrapper.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneRawButton
Constructors
-
ArcaneRawButton({required Component child, ArcaneStyleData? styles, String? classes, String? id, String? type, bool disabled = false, void onClick()?, Map<
String, void Function(dynamic)> ? events, Key? key}) -
const
-
ArcaneRawButton.children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, String? type, bool disabled, void onClick()?, Map<String, void Function(dynamic)> ? events, Key? key}) -
constfactory
Properties
- child → Component
-
final
- classes → String?
-
final
- disabled → bool
-
final
-
events
→ Map<
String, void Function(dynamic)> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onClick → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styles → ArcaneStyleData?
-
final
- type → String?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited