ArcaneCatImage class
A random cat image from cataas.com.
Example usage:
ArcaneCatImage(seed: 'my-cat')
ArcaneCatImage.gif(seed: 'animated-cat')
ArcaneCatImage.says('Hello World', seed: 'talking-cat')
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneCatImage
Constructors
-
ArcaneCatImage({String? seed, String? text, bool gif = false, int? apiWidth, int? apiHeight, ArcaneStyleData? styles, String? classes, String? id, String? width, String? height, String? loading, String? decoding, Map<
String, void Function(dynamic)> ? events, Key? key}) -
const
-
ArcaneCatImage.gif({String? seed, String? text, int? apiWidth, int? apiHeight, ArcaneStyleData? styles, String? classes, String? id, String? width, String? height, String? loading, String? decoding, Map<
String, void Function(dynamic)> ? events, Key? key}) -
Create a GIF cat image.
const
-
ArcaneCatImage.lazy({String? seed, String? text, bool gif = false, int? apiWidth, int? apiHeight, ArcaneStyleData? styles, String? classes, String? id, String? width, String? height, String? decoding, Map<
String, void Function(dynamic)> ? events, Key? key}) -
Create a lazy-loaded cat image.
const
-
ArcaneCatImage.says(String? text, {String? seed, bool gif = false, int? apiWidth, int? apiHeight, ArcaneStyleData? styles, String? classes, String? id, String? width, String? height, String? loading, String? decoding, Map<
String, void Function(dynamic)> ? events, Key? key}) -
Create a cat image with text overlay.
const
Properties
- apiHeight → int?
-
Optional custom height parameter for the API.
final
- apiWidth → int?
-
Optional custom width parameter for the API.
final
- classes → String?
-
CSS classes to apply.
final
- decoding → String?
-
Decoding hint (sync, async, auto).
final
-
events
→ Map<
String, void Function(dynamic)> ? -
Event handlers.
final
- gif → bool
-
Whether to use a GIF instead of a static image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → String?
-
HTML height attribute.
final
- id → String?
-
Element ID.
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- loading → String?
-
Loading strategy (lazy, eager).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → String?
-
Optional seed string for consistent random cats.
The same seed will always return the same cat.
final
- styles → ArcaneStyleData?
-
Custom styles for the image.
final
- text → String?
-
Optional text to display on the cat image.
final
- width → String?
-
HTML width attribute.
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited