seed property
Optional seed string for consistent random cats. The same seed will always return the same cat.
Implementation
final String? seed;
Optional seed string for consistent random cats. The same seed will always return the same cat.
final String? seed;