ArcaneHeading class
Styled heading wrapper for h1-h6 elements.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneHeading
Constructors
- ArcaneHeading({required HeadingLevel level, Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
- ArcaneHeading.h1({Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
-
ArcaneHeading.h1Children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, Key? key}) -
const
- ArcaneHeading.h2({Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
-
ArcaneHeading.h2Children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, Key? key}) -
const
- ArcaneHeading.h3({Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
-
ArcaneHeading.h3Children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, Key? key}) -
const
- ArcaneHeading.h4({Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
-
ArcaneHeading.h4Children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, Key? key}) -
const
- ArcaneHeading.h5({Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
-
ArcaneHeading.h5Children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, Key? key}) -
const
- ArcaneHeading.h6({Component? child, String? text, ArcaneStyleData? styles, String? classes, String? id, Key? key})
-
const
-
ArcaneHeading.h6Children({required List<
Component> children, ArcaneStyleData? styles, String? classes, String? id, Key? key}) -
const
Properties
- classes → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- level → HeadingLevel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styles → ArcaneStyleData?
-
final
- text → String?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited