ArcaneSvg class

SVG container wrapper.

Inheritance

Constructors

ArcaneSvg({String viewBox = '0 0 24 24', String? width, String? height, SvgSize? size, String fill = 'currentColor', String? stroke, String? strokeWidth, Map<String, String>? attributes, required List<Component> children, String? className, Key? key})
const

Properties

attributes Map<String, String>?
final
children List<Component>
final
className String?
final
fill String
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size SvgSize?
final
stroke String?
final
strokeWidth String?
final
viewBox String
final
width String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited