ArcaneSvgLine class

SVG line element wrapper.

Inheritance

Constructors

ArcaneSvgLine({required String x1, required String y1, required String x2, required String y2, String? stroke, String? strokeWidth, String? strokeLinecap, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stroke String?
final
strokeLinecap String?
final
strokeWidth String?
final
x1 String
final
x2 String
final
y1 String
final
y2 String
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited