ArcaneSvgRect class

SVG rect element wrapper.

Inheritance

Constructors

ArcaneSvgRect({required String x, required String y, required String width, required String height, String? rx, String? ry, String? fill, String? stroke, String? strokeWidth, Key? key})
const

Properties

fill String?
final
hashCode int
The hash code for this object.
no setterinherited
height String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rx String?
final
ry String?
final
stroke String?
final
strokeWidth String?
final
width String
final
x String
final
y String
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited