ButtonVariant enum

Button style variants

Inheritance
Available extensions

Values

primary → const ButtonVariant

Primary action button with accent color

secondary → const ButtonVariant

Secondary/muted button

outline → const ButtonVariant

Outline button with border

ghost → const ButtonVariant

Ghost button (transparent background)

destructive → const ButtonVariant

Destructive/danger button

Link-style button

success → const ButtonVariant

Success button (green)

warning → const ButtonVariant

Warning button (amber)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ButtonVariant>
A constant List of the values in this enum, in order of their declaration.