ArcaneCalendar class

A calendar component for date selection.

Inheritance

Constructors

ArcaneCalendar({DateTime? selected, void onSelect(DateTime)?, DateTime? month, void onMonthChange(DateTime)?, DateTime? minDate, DateTime? maxDate, bool disabledDates(DateTime)?, bool showWeekNumbers = false, bool showToday = true, int firstDayOfWeek = 0, CalendarMode mode = CalendarMode.single, DateRange? selectedRange, void onRangeSelect(DateRange)?, Key? key})
const

Properties

disabledDates bool Function(DateTime)?
final
firstDayOfWeek int
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxDate DateTime?
final
minDate DateTime?
final
mode CalendarMode
final
month DateTime?
final
onMonthChange → void Function(DateTime)?
final
onRangeSelect → void Function(DateRange)?
final
onSelect → void Function(DateTime)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected DateTime?
final
selectedRange DateRange?
final
showToday bool
final
showWeekNumbers bool
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneCalendar>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited