ArcaneCheckbox class
Checkbox input component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneCheckbox
Constructors
- ArcaneCheckbox({required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, ColorVariant color = ColorVariant.primary, bool disabled = false, void onChanged(bool)?, void onToggle(bool)?, Key? key})
-
const
- ArcaneCheckbox.destructive({required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, bool disabled = false, void onChanged(bool)?, void onToggle(bool)?, Key? key})
-
const
- ArcaneCheckbox.primary({required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, bool disabled = false, void onChanged(bool)?, void onToggle(bool)?, Key? key})
-
const
- ArcaneCheckbox.success({required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, bool disabled = false, void onChanged(bool)?, void onToggle(bool)?, Key? key})
-
const
- ArcaneCheckbox.warning({required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, bool disabled = false, void onChanged(bool)?, void onToggle(bool)?, Key? key})
-
const
Properties
- checked → bool
-
final
- color → ColorVariant
-
final
- description → String?
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ComponentSize
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited