Checkbox class

Checkbox input component

Use style presets for cleaner code:

Checkbox(
  checked: true,
  style: CheckboxStyle.success,
)
Inheritance

Constructors

Checkbox({required bool checked, String? label, String? description, CheckboxSize size = CheckboxSize.medium, CheckboxStyle? style, bool disabled = false, void onChanged(bool)?, Key? key})
const
Checkbox.primary({required bool checked, String? label, String? description, CheckboxSize size = CheckboxSize.medium, bool disabled = false, void onChanged(bool)?, Key? key})
Primary checkbox
const
Checkbox.success({required bool checked, String? label, String? description, CheckboxSize size = CheckboxSize.medium, bool disabled = false, void onChanged(bool)?, Key? key})
Success checkbox
const

Properties

checked bool
final
description String?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
onChanged → void Function(bool)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size CheckboxSize
final
style CheckboxStyle?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited