ArcaneCombobox<T> class

An autocomplete combobox with search filtering.

Inheritance

Constructors

ArcaneCombobox({required List<ComboboxOption<T>> options, T? value, void onChanged(T?)?, String? placeholder, String? searchPlaceholder, bool searchable = true, String displayValue(T)?, bool filterFn(ComboboxOption<T>, String)?, String emptyMessage = 'No results found', bool disabled = false, String? error, String? label, ComboboxSize size = ComboboxSize.md, Key? key})
const

Properties

disabled bool
final
displayValue String Function(T)?
final
emptyMessage String
final
error String?
final
filterFn bool Function(ComboboxOption<T>, String)?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
onChanged → void Function(T?)?
final
options List<ComboboxOption<T>>
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool
final
searchPlaceholder String?
final
size ComboboxSize
final
value → T?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneCombobox<T>>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited