ArcaneToggleButton class

A toggle button (on/off state).

Inheritance

Constructors

ArcaneToggleButton({required bool value, void onChanged(bool value)?, String? label, Component? icon, CycleButtonSize size = CycleButtonSize.medium, bool disabled = false, String? id, Map<String, String>? attributes, Key? key})
const

Properties

attributes Map<String, String>?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
onChanged → void Function(bool value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size CycleButtonSize
final
value bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited