ArcaneDatePicker class

A date picker input with calendar dropdown.

Inheritance

Constructors

ArcaneDatePicker({DateTime? value, void onChanged(DateTime?)?, String? label, String? placeholder, String formatDate(DateTime)?, DateTime? minDate, DateTime? maxDate, bool disabledDates(DateTime)?, bool disabled = false, String? error, bool clearable = true, DatePickerSize size = DatePickerSize.md, CalendarMode mode = CalendarMode.single, DateRange? rangeValue, void onRangeChanged(DateRange?)?, Key? key})
const
ArcaneDatePicker.range({DateRange? rangeValue, void onRangeChanged(DateRange?)?, String? label, String? placeholder, String formatDate(DateTime)?, DateTime? minDate, DateTime? maxDate, bool disabledDates(DateTime)?, bool disabled = false, String? error, bool clearable = true, DatePickerSize size = DatePickerSize.md, Key? key})
const

Properties

clearable bool
final
disabled bool
final
disabledDates bool Function(DateTime)?
final
error String?
final
formatDate String Function(DateTime)?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
maxDate DateTime?
final
minDate DateTime?
final
mode CalendarMode
final
onChanged → void Function(DateTime?)?
final
onRangeChanged → void Function(DateRange?)?
final
placeholder String?
final
rangeValue DateRange?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size DatePickerSize
final
value DateTime?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneDatePicker>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited