ArcaneDateTimePicker class

A unified date and/or time picker component.

Inheritance

Constructors

ArcaneDateTimePicker({DateTime? value, void onChanged(DateTime?)?, String? label, String? placeholder, bool disabled = false, String? error, bool clearable = true, DateTimePickerSize size = DateTimePickerSize.md, DateTime? minDate, DateTime? maxDate, bool disabledDates(DateTime)?, String formatDate(DateTime)?, bool use24Hour = false, int minuteInterval = 1, bool showSeconds = false, Key? key})
const
ArcaneDateTimePicker.date({DateTime? value, void onDateChanged(DateTime?)?, String? label, String? placeholder, bool disabled = false, String? error, bool clearable = true, DateTimePickerSize size = DateTimePickerSize.md, DateTime? minDate, DateTime? maxDate, bool disabledDates(DateTime)?, String formatDate(DateTime)?, Key? key})
const
ArcaneDateTimePicker.time({TimeOfDay? timeValue, void onTimeChanged(TimeOfDay?)?, String? label, String? placeholder, bool disabled = false, String? error, bool clearable = true, DateTimePickerSize size = DateTimePickerSize.md, bool use24Hour = false, int minuteInterval = 1, bool showSeconds = false, Key? key})
const

Properties

clearable bool
final
disabled bool
final
disabledDates bool Function(DateTime)?
final
error String?
final
formatDate String Function(DateTime)?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
maxDate DateTime?
final
minDate DateTime?
final
minuteInterval int
final
mode DateTimePickerMode
final
onChanged → void Function(DateTime?)?
final
onDateChanged → void Function(DateTime?)?
final
onTimeChanged → void Function(TimeOfDay?)?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSeconds bool
final
size DateTimePickerSize
final
timeValue TimeOfDay?
final
use24Hour bool
final
value DateTime?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneDateTimePicker>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited