ArcaneFAB class

A floating action button component.

Inheritance

Constructors

ArcaneFAB({required Component icon, String? label, void onPressed()?, FABVariant variant = FABVariant.primary, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes, Key? key})
const
ArcaneFAB.destructive({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes, Key? key})
const
ArcaneFAB.primary({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes, Key? key})
const
ArcaneFAB.secondary({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes, Key? key})
const
ArcaneFAB.success({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes, Key? key})
const
ArcaneFAB.surface({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes, Key? key})
const

Properties

attributes Map<String, String>?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component
final
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
onPressed → void Function()?
final
position FABPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size FABSize
final
tooltip String?
final
variant FABVariant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited