FormattedValue class

Value container for formatted input.

Constructors

FormattedValue(List<InputPart> parts)
const

Properties

combinedValue String
no setter
hashCode int
The hash code for this object.
no setterinherited
parts List<InputPart>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String?>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited