ArcaneIconButton class

An icon-only button component.

Inheritance

Constructors

ArcaneIconButton({required Component icon, void onPressed()?, IconButtonStyle style = IconButtonStyle.ghost, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
const
ArcaneIconButton.destructive({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
const
ArcaneIconButton.ghost({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
const
ArcaneIconButton.outline({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
const
ArcaneIconButton.primary({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loading bool
final
onPressed → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size IconButtonSize
final
style IconButtonStyle
final
tooltip String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited