ArcaneMutableText class

A text component that can be clicked to edit inline.

Inheritance
Available extensions

Constructors

ArcaneMutableText({required String value, String? placeholder, void onSave(String value)?, void onCancel()?, void onChange(String value)?, MutableTextTrigger trigger = MutableTextTrigger.click, MutableTextInputType inputType = MutableTextInputType.text, MutableTextStyle displayStyle = MutableTextStyle.subtle, bool disabled = false, bool required = false, String? validator(String value)?, int maxLength = 0, int minLength = 0, int multilineRows = 3, bool saveOnBlur = true, bool showCharCount = false, Map<String, String>? textStyles, String? label, String? helperText, bool startEditing = false, Component? prefix, Component? suffix, bool selectAllOnEdit = false, Key? key})
const

Properties

disabled bool
final
displayStyle MutableTextStyle
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
inputType MutableTextInputType
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
maxLength int
final
minLength int
final
multilineRows int
final
onCancel → void Function()?
final
onChange → void Function(String value)?
final
onSave → void Function(String value)?
final
placeholder String?
final
prefix Component?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveOnBlur bool
final
selectAllOnEdit bool
final
showCharCount bool
final
startEditing bool
final
suffix Component?
final
textStyles Map<String, String>?
final
trigger MutableTextTrigger
final
validator String? Function(String value)?
final
value String
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneMutableText>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final