MutableText class

Inheritance

Constructors

MutableText(String value, {void onChanged(String)?, void onEditingComplete()?, void onEditingStarted()?, int maxLines = 1, int? minLines, String? placeholder, MutableTextTrigger trigger = MutableTextTrigger.click, MutableTextInputType inputType = MutableTextInputType.text, MutableTextStyle style = MutableTextStyle.inline, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputType MutableTextInputType
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxLines int
final
minLines int?
final
onChanged → void Function(String)?
final
onEditingComplete → void Function()?
final
onEditingStarted → void Function()?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style MutableTextStyle
final
trigger MutableTextTrigger
final
value String
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<MutableText>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited