ArcaneNumberInput class

Numeric input with increment/decrement controls.

Inheritance

Constructors

ArcaneNumberInput({required num value, num min = 0, num max = 100, num step = 1, void onChanged(num)?, NumberInputSize size = NumberInputSize.md, bool disabled = false, String? label, String? prefix, String? suffix, int decimals = 0, String? id, Map<String, String>? attributes, Key? key})
const

Properties

attributes Map<String, String>?
final
decimals int
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
max num
final
min num
final
onChanged → void Function(num)?
final
prefix String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size NumberInputSize
final
step num
final
suffix String?
final
value num
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited