ArcaneRadioGroup<T> class

A radio button group component.

Inheritance

Constructors

ArcaneRadioGroup({required List<RadioOption<T>> options, T? value, void onChanged(T value)?, String? name, RadioGroupLayout layout = RadioGroupLayout.vertical, RadioGroupVariant variant = RadioGroupVariant.standard, bool disabled = false, String? label, String? helperText, String? error, bool required = false, String gap = '0.5rem', int gridColumns = 2, Key? key})
const

Properties

disabled bool
final
error String?
final
gap String
final
gridColumns int
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
layout RadioGroupLayout
final
name String?
final
onChanged → void Function(T value)?
final
options List<RadioOption<T>>
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final
variant RadioGroupVariant
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited