RadioOption<T> class
Radio button option model.
Constructors
- RadioOption({required T value, required String label, String? description, bool disabled = false, ArcaneGlyph? icon, String? id})
-
const
Properties
- description → String?
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → ArcaneGlyph?
-
final
- id → String?
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited