ArcaneSearch class

A search input component with optional icon, clear button, and results dropdown.

Inheritance

Constructors

ArcaneSearch({String placeholder = 'Search...', String? value, void onChanged(String value)?, void onSubmitted(String value)?, bool showClear = true, bool showIcon = true, bool loading = false, Component? icon, bool autofocus = false, bool disabled = false, SearchSize size = SearchSize.md, SearchStyle style = SearchStyle.standard, String? id, Map<String, String>? attributes, List<SearchResult>? results, String? resultsId, bool showDropdown = false, String? dropdownMaxHeight, String? width, Key? key})
const
ArcaneSearch.withResults({String placeholder = 'Search...', String? value, void onChanged(String value)?, void onSubmitted(String value)?, bool showClear = true, bool showIcon = true, bool loading = false, Component? icon, bool autofocus = false, bool disabled = false, SearchSize size = SearchSize.md, SearchStyle style = SearchStyle.standard, String? id, Map<String, String>? attributes, List<SearchResult>? results, String? resultsId, String? dropdownMaxHeight = '300px', String? width = '240px', Key? key})
const

Properties

attributes Map<String, String>?
final
autofocus bool
final
disabled bool
final
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loading bool
final
onChanged → void Function(String value)?
final
onSubmitted → void Function(String value)?
final
placeholder String
final
results List<SearchResult>?
final
resultsId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showClear bool
final
showDropdown bool
final
showIcon bool
final
size SearchSize
final
style SearchStyle
final
value String?
final
width String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited