Search class

Inheritance

Constructors

Search({String placeholder = 'Search...', String? value, void onChanged(String)?, void onSubmitted(String)?, List<SearchResult> results = const <SearchResult>[], bool showDropdown = false, bool showClear = true, bool autofocus = false, bool disabled = false, Key? key})
const

Properties

autofocus bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onChanged → void Function(String)?
final
onSubmitted → void Function(String)?
final
placeholder String
final
results List<SearchResult>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showClear bool
final
showDropdown bool
final
value String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited