TextInput class

A text input component

Inheritance

Constructors

TextInput({String? value, String? placeholder, String? label, String? hint, String? error, void onChanged(String value)?, void onSubmitted(String value)?, bool obscureText = false, bool autofocus = false, bool disabled = false, bool readOnly = false, int? maxLength, int? maxLines = 1, Component? prefix, Component? suffix, Key? key})
const

Properties

autofocus bool
final
disabled bool
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
maxLength int?
final
maxLines int?
final
obscureText bool
final
onChanged → void Function(String value)?
final
onSubmitted → void Function(String value)?
final
placeholder String?
final
prefix Component?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix Component?
final
value String?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<TextInput>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited