Selector<T> class

Inheritance

Constructors

Selector({required List<T> values, required String labelBuilder(T), T? value, void onChanged(T?)?, bool canUnselect = false, String? placeholder, Key? key})
const

Properties

canUnselect bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
labelBuilder String Function(T)
final
onChanged → void Function(T?)?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final
values List<T>
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited