ArcaneRangeSlider class

Inheritance
Annotations

Constructors

ArcaneRangeSlider({required double minValue, required double maxValue, double min = 0, double max = 100, double? step, String? label, bool showValues = true, SliderVariant variant = SliderVariant.primary, ComponentSize size = ComponentSize.md, bool disabled = false, void onChanged(double min, double max)?, Key? key})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
max double
final
maxValue double
final
min double
final
minValue double
final
onChanged → void Function(double min, double max)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValues bool
final
size ComponentSize
final
step double?
final
variant SliderVariant
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited