ArcaneSlider class

Slider input component with single value or range mode.

Inheritance

Constructors

ArcaneSlider({required double value, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, SliderVariant variant = SliderVariant.primary, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onChanged(double)?, Key? key})
const
ArcaneSlider.error({required double value, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onChanged(double)?, Key? key})
const
ArcaneSlider.primary({required double value, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onChanged(double)?, Key? key})
const
ArcaneSlider.range({required double minValue, required double maxValue, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, SliderVariant variant = SliderVariant.primary, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onRangeChanged(double min, double max)?, Key? key})
const
ArcaneSlider.success({required double value, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onChanged(double)?, Key? key})
const
ArcaneSlider.warning({required double value, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onChanged(double)?, Key? key})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
isRange bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
max double
final
min double
final
onChanged → void Function(double)?
final
onRangeChanged → void Function(double min, double max)?
final
rangeMax double?
final
rangeMin double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSteps bool
final
showValue bool
final
size ComponentSize
final
step double?
final
value double
final
valueDecimals int
final
valuePrefix String?
final
valueSuffix String?
final
variant SliderVariant
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited