Slider class
Range slider input component
Use style presets for cleaner code:
Slider(
value: 50,
style: SliderStyle.success,
)
- Inheritance
-
- Object
- Component
- StatelessComponent
- Slider
Constructors
- Slider({required double value, double min = 0, double max = 100, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, SliderStyle? style, void onChanged(double)?, Key? key})
-
const
- Slider.primary({required double value, double min = 0, double max = 100, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, void onChanged(double)?, Key? key})
-
Primary slider
const
- Slider.success({required double value, double min = 0, double max = 100, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, void onChanged(double)?, Key? key})
-
Success slider
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- max → double
-
final
- min → double
-
final
- onChanged → void Function(double)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showValue → bool
-
final
- style → SliderStyle?
-
final
- value → double
-
final
- valuePrefix → String?
-
final
- valueSuffix → String?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited