ArcaneSelect class

A select/dropdown input component.

Inheritance

Constructors

ArcaneSelect({required List<ArcaneSelectOption> options, String? value, String? placeholder, ComponentSize size = ComponentSize.md, bool disabled = false, bool required = false, String? name, String? id, String? label, String? error, void onChange(String)?, void onInput(String)?, void onSelect(String)?, bool fullWidth = false, Key? key})
const

Properties

disabled bool
final
error String?
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
name String?
final
options List<ArcaneSelectOption>
final
placeholder String?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
value String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited