ArcaneTextArea class

A textarea component

Inheritance

Constructors

ArcaneTextArea({String? placeholder, int rows = 4, InputStyle? style, bool disabled = false, bool required = false, bool resizable = true, String? value, String? name, String? id, String? label, String? error, String? helperText, void onChange(String)?, bool fullWidth = true, Key? key})
const

Properties

disabled bool
Whether disabled
final
error String?
Error
final
fullWidth bool
Full width
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
Helper text
final
id String?
ID
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
Label
final
name String?
Name
final
onChange → void Function(String)?
Change callback
final
placeholder String?
Placeholder text
final
required bool
Whether required
final
resizable bool
Whether resizable
final
rows int
Number of rows
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style InputStyle?
Style preset
final
value String?
Value
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final