ArcaneTextInput class

A styled text input component.

Inheritance

Constructors

ArcaneTextInput({String? placeholder, InputType type = dom.InputType.text, TextInputSize size = TextInputSize.md, bool disabled = false, bool required = false, bool readOnly = false, String? value, String? name, String? id, Component? prefix, Component? suffix, String? error, String? helperText, String? label, void onChange(String)?, void onInput(String)?, void onFocus()?, void onBlur()?, void onSubmit(String)?, bool fullWidth = false, Key? key})
const

Properties

disabled bool
final
error String?
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
name String?
final
onBlur → void Function()?
final
onFocus → void Function()?
final
onSubmit → void Function(String)?
final
placeholder String?
final
prefix Component?
final
readOnly bool
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size TextInputSize
final
suffix Component?
final
type InputType
final
value String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited