TextArea class

A textarea component.

Inheritance

Constructors

TextArea({String? placeholder, int rows = 4, int? cols, bool disabled = false, bool required = false, TextAreaResize resize = TextAreaResize.vertical, String? minWidth, String? maxWidth, String? minHeight, String? maxHeight, String? value, String? name, String? id, String? label, String? error, String? helperText, void onChange(String)?, void onInput(String)?, bool fullWidth = true, Key? key})
const

Properties

cols int?
final
disabled bool
final
error String?
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
maxHeight String?
final
maxWidth String?
final
minHeight String?
final
minWidth String?
final
name String?
final
placeholder String?
final
required bool
final
resize TextAreaResize
final
rows int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited