ToggleGroupItem class
A toggle group item.
Constructors
- ToggleGroupItem({required String value, required Widget child, bool disabled = false})
-
const
- ToggleGroupItem.text(String value, {String? label, bool disabled = false})
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited