ArcaneToggleButtonGroup class
A toggle button group for switching between options.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneToggleButtonGroup
Constructors
-
ArcaneToggleButtonGroup({required List<
String> options, required int selectedIndex, void onChanged(int)?, ComponentSize size = ComponentSize.md, Key? key}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onChanged → void Function(int)?
-
final
-
options
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex → int
-
final
- size → ComponentSize
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited