ArcaneToggleSwitch class
A toggle switch component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneToggleSwitch
Constructors
- ArcaneToggleSwitch({required bool value, void onChanged(bool)?, void onToggle(bool)?, bool disabled = false, ComponentSize size = ComponentSize.md, ColorVariant color = ColorVariant.primary, String? label, bool labelLeft = false, Key? key})
-
const
- ArcaneToggleSwitch.destructive({required bool value, void onChanged(bool)?, void onToggle(bool)?, bool disabled = false, ComponentSize size = ComponentSize.md, String? label, bool labelLeft = false, Key? key})
-
const
- ArcaneToggleSwitch.primary({required bool value, void onChanged(bool)?, void onToggle(bool)?, bool disabled = false, ComponentSize size = ComponentSize.md, String? label, bool labelLeft = false, Key? key})
-
const
- ArcaneToggleSwitch.success({required bool value, void onChanged(bool)?, void onToggle(bool)?, bool disabled = false, ComponentSize size = ComponentSize.md, String? label, bool labelLeft = false, Key? key})
-
const
- ArcaneToggleSwitch.warning({required bool value, void onChanged(bool)?, void onToggle(bool)?, bool disabled = false, ComponentSize size = ComponentSize.md, String? label, bool labelLeft = false, Key? key})
-
const
Properties
- color → ColorVariant
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- labelLeft → bool
-
final
- onChanged → void Function(bool)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ComponentSize
-
final
- value → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited