ArcaneScrollProgress class

Scroll progress indicator.

Inheritance

Constructors

ArcaneScrollProgress({required double progress, bool top = true, double height = 3, String? color, Key? key})
const

Properties

color String?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited