BackToTop class
A back to top button (Supabase-style)
- Inheritance
-
- Object
- Component
- StatelessComponent
- BackToTop
Constructors
Properties
- bottom → double
-
Position from bottom
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onTap → void Function()?
-
Click handler
final
- right → double
-
Position from right
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
Button size
final
- visible → bool
-
Whether the button is visible
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited