FloatingActionButton class

A floating action button

Inheritance

Constructors

FloatingActionButton({required Component child, void onTap()?, double right = 24, double bottom = 24, double size = 56, String? label, bool accent = true, Key? key})
const

Properties

accent bool
Whether to use accent color
final
bottom double
Position from bottom
final
child Component
Button icon/content
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
Whether extended with label
final
onTap → void Function()?
Click handler
final
Position from right
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Button size
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final