ArcaneDisclosure class

Disclosure widget using native HTML details/summary elements.

Inheritance

Constructors

ArcaneDisclosure({required Widget summary, required Widget child, bool open = false, DisclosureVariant variant = DisclosureVariant.default_, bool showChevron = true, bool showTreeLines = true, String? classes, Key? key})
const
ArcaneDisclosure.bordered({required Widget summary, required Widget child, bool open = false, bool showChevron = true, bool showTreeLines = true, String? classes, Key? key})
const
ArcaneDisclosure.filled({required Widget summary, required Widget child, bool open = false, bool showChevron = true, bool showTreeLines = true, String? classes, Key? key})
const
ArcaneDisclosure.minimal({required Widget summary, required Widget child, bool open = false, bool showChevron = true, bool showTreeLines = true, String? classes, Key? key})
const

Properties

child Widget
final
classes String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
open bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showChevron bool
final
showTreeLines bool
final
summary Widget
final
variant DisclosureVariant
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited