ArcaneAspectRatio class

A container that maintains a specific aspect ratio.

Inheritance

Constructors

ArcaneAspectRatio({required double ratio, required Widget child, String? classes, Map<String, String>? styles, Key? key})
const
ArcaneAspectRatio.golden({required Widget child, String? classes, Map<String, String>? styles, Key? key})
const
ArcaneAspectRatio.photo({required Widget child, String? classes, Map<String, String>? styles, Key? key})
const
ArcaneAspectRatio.portrait({required Widget child, String? classes, Map<String, String>? styles, Key? key})
const
ArcaneAspectRatio.square({required Widget child, String? classes, Map<String, String>? styles, Key? key})
const
ArcaneAspectRatio.ultrawide({required Widget child, String? classes, Map<String, String>? styles, Key? key})
const
ArcaneAspectRatio.video({required Widget child, String? classes, Map<String, String>? styles, Key? key})
const

Properties

child Widget
final
classes String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
ratio double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Map<String, String>?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited