ArcaneAuthLayout class

A layout for authentication screens with centered content and optional background effects.

Inheritance

Constructors

ArcaneAuthLayout({Key? key, required Component child, Component? header, Component? footer, bool showGrid = true, bool showGlows = true, String primaryGlowColor = 'color-mix(in srgb, var(--accent) 15%, transparent)', String secondaryGlowColor = 'color-mix(in srgb, var(--info) 15%, transparent)', String gridColor = 'color-mix(in srgb, var(--border) 30%, transparent)', String maxWidth = '420px', String backgroundColor = 'var(--background)'})
const
ArcaneAuthLayout.themed({Key? key, required Component child, Component? header, Component? footer, bool showGrid = true, bool showGlows = true, String maxWidth = '420px', String backgroundColor = 'var(--background)'})
const

Properties

backgroundColor String
final
child Component
final
final
gridColor String
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxWidth String
final
primaryGlowColor String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryGlowColor String
final
showGlows bool
final
showGrid bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited