Divider class

A divider component

Inheritance

Constructors

Divider({double? thickness, double? indent, double? endIndent, Color? color, bool vertical = false, Key? key})
const

Properties

color Color?
final
endIndent double?
final
hashCode int
The hash code for this object.
no setterinherited
indent double?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double?
final
vertical bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited