ArcaneCtaBanner class

Call-to-action banner with gradient background.

Inheritance

Constructors

ArcaneCtaBanner({required String title, String? subtitle, Component? primaryAction, Component? secondaryAction, String? gradientStart, String? gradientEnd, String? backgroundImage, Key? key})
const

Properties

backgroundImage String?
final
gradientEnd String?
final
gradientStart String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
primaryAction Component?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryAction Component?
final
subtitle String?
final
title String
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited