ArcaneDashboardLayout class

A reusable dashboard layout with sidebar navigation.

Inheritance

Constructors

ArcaneDashboardLayout({Key? key, required Component child, required String currentRoute, required List<DashboardNavGroup> navigation, Component? sidebarHeader, Component? sidebarFooter, Component? topBar, String sidebarWidth = '256px', String backgroundColor = 'var(--background)', String sidebarBackgroundColor = 'var(--card)'})
const

Properties

backgroundColor String
final
child Component
final
currentRoute String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sidebarBackgroundColor String
final
sidebarFooter Component?
final
sidebarHeader Component?
final
sidebarWidth String
final
topBar Component?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited