ArcaneDrawer class

Slide-in drawer/sheet panel.

Inheritance

Constructors

ArcaneDrawer({required bool isOpen, required Widget child, VoidCallback? onClose, DrawerPosition position = DrawerPosition.right, DrawerSize size = DrawerSize.md, Widget? header, Widget? footer, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, String? width, String? height, Key? key})
const
ArcaneDrawer.bottom({required bool isOpen, required Widget child, VoidCallback? onClose, DrawerSize size = DrawerSize.md, Widget? header, Widget? footer, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = false, String? width, String? height, Key? key})
const
ArcaneDrawer.left({required bool isOpen, required Widget child, VoidCallback? onClose, DrawerSize size = DrawerSize.md, Widget? header, Widget? footer, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, String? width, String? height, Key? key})
const
ArcaneDrawer.right({required bool isOpen, required Widget child, VoidCallback? onClose, DrawerSize size = DrawerSize.md, Widget? header, Widget? footer, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, String? width, String? height, Key? key})
const

Properties

child Widget
final
closeOnBackdropClick bool
final
final
hashCode int
The hash code for this object.
no setterinherited
final
height String?
final
isOpen bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onClose VoidCallback?
final
position DrawerPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBackdrop bool
final
showCloseButton bool
final
size DrawerSize
final
width String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited