ArcaneFeatureShowcase class

A feature showcase section using FlexiCards.

Inheritance

Constructors

ArcaneFeatureShowcase({required String title, String? subtitle, required List<FeatureShowcaseItem> items, double expandedFlex = 2.5, double collapsedFlex = 1.0, String gap = '1.5rem', String minCardWidth = '280px', bool expandOnHover = true, String? background, bool centerHeader = true, Key? key})
const

Properties

background String?
final
centerHeader bool
final
collapsedFlex double
final
expandedFlex double
final
expandOnHover bool
final
gap String
final
hashCode int
The hash code for this object.
no setterinherited
items List<FeatureShowcaseItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
minCardWidth String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited