Border class

Border for BoxDecoration.

Constructors

Border({required Color color, double width = 1, String style = 'solid'})
const
Border.all({required Color color, double width = 1})
const

Properties

color Color
final
css String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style String
final
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited