Container class

A container component with styling options.

Inheritance

Constructors

Container({Widget? child, EdgeInsets? padding, EdgeInsets? margin, double? width, double? height, Color? color, BoxDecoration? decoration, Alignment? alignment, Key? key})
const

Properties

alignment Alignment?
final
child Widget?
final
color Color?
final
decoration BoxDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
margin EdgeInsets?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited