Flow class

A flexible flow layout component that wraps children.

Inheritance

Constructors

Flow({required List<Component> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, WrapAlignment wrapAlignment = WrapAlignment.start, double gap = 8, double? rowGap, double? columnGap, bool reverse = false, Key? key})
const

Properties

children List<Component>
The child components
final
columnGap double?
Column gap (overrides gap for columns)
final
crossAxisAlignment CrossAxisAlignment
Cross axis alignment
final
gap double
Gap between children
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
mainAxisAlignment MainAxisAlignment
Main axis alignment
final
reverse bool
Whether to reverse the direction
final
rowGap double?
Row gap (overrides gap for rows)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrapAlignment WrapAlignment
Wrap alignment
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited