Footer class

A website footer component (Supabase-style)

Inheritance

Constructors

Footer({String? description, required List<FooterLinkGroup> linkGroups, List<Component>? socialLinks, String? copyright, List<FooterLink>? bottomLinks, bool showNewsletter = false, String newsletterPlaceholder = 'Enter your email', String newsletterButtonText = 'Subscribe', void onNewsletterSubmit(String)?, Key? key})
const

Properties

Bottom links (privacy, terms, etc.)
final
Copyright text
final
description String?
Description/tagline
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
linkGroups List<FooterLinkGroup>
Link groups (columns)
final
Logo component
final
newsletterButtonText String
Newsletter submit text
final
newsletterPlaceholder String
Newsletter placeholder
final
onNewsletterSubmit → void Function(String)?
Newsletter callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNewsletter bool
Whether to show a newsletter form
final
Social media icons/links
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final