component/layout/footer_column library
Classes
- A brand column for footers with logo, description, and optional status.
- A footer column with title and list of links.
- Footer brand column component properties.
- Footer column component properties.
- Footer link data.