ArcaneFooterColumn class

A footer column with title and list of links.

Inheritance

Constructors

ArcaneFooterColumn({required String title, required List<FooterLink> links, String? titleColor, String? linkColor, String? linkGap, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
linkColor String?
final
linkGap String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
titleColor String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited