component/layout/gutter library

Classes

ArcaneBox
A container component with enum-based styling.
ArcaneGap
A flexible gap component.
Gutter
A spacing component that provides consistent gaps between elements.
Positioned
A positioned child for use within a Stack.
Stack
An Stack component for positioning children on top of each other.