ArcaneBox class

A container component with enum-based styling.

Inheritance

Constructors

ArcaneBox({Widget? child, List<Widget>? children, PaddingPreset? padding, MarginPreset? margin, Background? background, BorderPreset? border, Radius? borderRadius, Shadow? shadow, Size? width, Size? height, String? widthCustom, String? heightCustom, MaxWidth? maxWidth, Overflow? overflow, ArcaneStyleData? style, Key? key})
const
ArcaneBox.card({Widget? child, List<Widget>? children, PaddingPreset? padding = PaddingPreset.lg, MarginPreset? margin, Shadow? shadow = Shadow.md, Size? width, Size? height, String? widthCustom, String? heightCustom, MaxWidth? maxWidth, Overflow? overflow, ArcaneStyleData? style, Key? key})
const
ArcaneBox.glass({Widget? child, List<Widget>? children, PaddingPreset? padding = PaddingPreset.lg, MarginPreset? margin, Shadow? shadow, Size? width, Size? height, String? widthCustom, String? heightCustom, MaxWidth? maxWidth, Overflow? overflow, ArcaneStyleData? style, Key? key})
const

Properties

background Background?
final
border BorderPreset?
final
borderRadius Radius?
final
child Widget?
final
children List<Widget>?
final
hashCode int
The hash code for this object.
no setterinherited
height Size?
final
heightCustom String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
margin MarginPreset?
final
maxWidth MaxWidth?
final
overflow Overflow?
final
padding PaddingPreset?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow Shadow?
final
style ArcaneStyleData?
final
width Size?
final
widthCustom String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited