ArcaneGap class

A flexible gap component.

Inheritance

Constructors

ArcaneGap(double size, {bool horizontal = false, Key? key})
const
ArcaneGap.lg({Key? key})
const
ArcaneGap.md({Key? key})
const
ArcaneGap.sm({Key? key})
const
ArcaneGap.xl({Key? key})
const
ArcaneGap.xs({Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
horizontal bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited