ArcanePositioned class

A positioned child for use within an ArcaneStack.

Inheritance

Constructors

ArcanePositioned({required Component child, String? top, String? right, String? bottom, String? left, String? inset, ArcaneStyleData? style, Key? key})
const
ArcanePositioned.fill({required Component child, ArcaneStyleData? style, Key? key})
const

Properties

bottom String?
final
child Component
final
hashCode int
The hash code for this object.
no setterinherited
inset String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
left String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style ArcaneStyleData?
final
top String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited