ArcaneHeroSection class

A hero section component for landing pages.

Inheritance

Constructors

ArcaneHeroSection({required String headline, String? subheadline, Component? primaryCta, Component? secondaryCta, Component? badge, Component? media, bool centered = true, double verticalPadding = 80, double maxWidth = 800, Key? key})
const

Properties

badge Component?
final
centered bool
final
hashCode int
The hash code for this object.
no setterinherited
headline String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxWidth double
final
media Component?
final
primaryCta Component?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryCta Component?
final
subheadline String?
final
verticalPadding double
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited