CtaBanner class

A CTA banner with gradient background

Inheritance

Constructors

CtaBanner({required String headline, String? description, Component? cta, bool gradient = true, EdgeInsets padding = const EdgeInsets.symmetric(vertical: 48, horizontal: 24), Key? key})
const

Properties

cta Component?
CTA button
final
description String?
Banner description
final
gradient bool
Whether to use gradient background
final
hashCode int
The hash code for this object.
no setterinherited
headline String
Banner headline
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding EdgeInsets
Padding
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited