ArcaneLogoCarousel class

An infinite scrolling logo carousel.

Inheritance

Constructors

ArcaneLogoCarousel({required List<LogoItem> logos, int duration = 30, double logoHeight = 40, double gap = 48, bool pauseOnHover = true, bool reverse = false, bool grayscale = true, String? title, Key? key})
const

Properties

duration int
final
gap double
final
grayscale bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
logoHeight double
final
logos List<LogoItem>
final
pauseOnHover bool
final
reverse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final