LogoGrid class

A static logo grid

Inheritance

Constructors

LogoGrid({required List<LogoItem> logos, double logoHeight = 40, double gap = 32, bool grayscale = true, String? title, int columns = 6, Key? key})
const

Properties

columns int
Number of columns
final
gap double
Gap between logos
final
grayscale bool
Grayscale logos
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
logoHeight double
Logo height
final
logos List<LogoItem>
Logo items
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Optional title
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final