LogoItem class

A logo item for the carousel

Constructors

LogoItem({required String name, String? imageUrl, String? href})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
imageUrl String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited