component/layout/radio_cards library

Classes

Chip
A single chip component
ChipGroup
A group of selectable chips where multiple can be selected
RadioCardItem<T>
An item for RadioCards
RadioCards<T>
A group of selectable cards where only one can be selected at a time.