ArcaneRadioCards<T> class

A group of selectable cards where only one can be selected at a time.

Inheritance

Constructors

ArcaneRadioCards({required List<RadioCardItemData<T>> items, T? value, void onChanged(T value)?, double gap = 12, bool wrap = true, double? cardWidth, Key? key})
const

Properties

cardWidth double?
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
items List<RadioCardItemData<T>>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onChanged → void Function(T value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final
wrap bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited