RadioCardItem<T> class

An item for RadioCards

Constructors

RadioCardItem({required T value, String? title, String? subtitle, Component? icon, Component? child, bool disabled = false})
const

Properties

child Component?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String?
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited