ArcaneScrollArea class

A scrollable area with custom styled scrollbars.

Inheritance

Constructors

ArcaneScrollArea({required Widget child, String? height, String? width, String? maxHeight, String? maxWidth, ScrollDirection direction = ScrollDirection.vertical, ScrollbarVisibility scrollbar = ScrollbarVisibility.hover, ScrollbarStyle scrollbarStyle = ScrollbarStyle.thin, String? trackColor, String? thumbColor, String scrollbarSize = '8px', bool showScrollShadows = false, String? padding, String? className, Key? key})
const
ArcaneScrollArea.horizontal({required Widget child, required String width, String? maxWidth, ScrollbarVisibility scrollbar = ScrollbarVisibility.hover, ScrollbarStyle scrollbarStyle = ScrollbarStyle.thin, String? thumbColor, String? trackColor, bool showScrollShadows = false, String? padding, String? className, Key? key})
const
ArcaneScrollArea.vertical({required Widget child, required String height, String? maxHeight, ScrollbarVisibility scrollbar = ScrollbarVisibility.hover, ScrollbarStyle scrollbarStyle = ScrollbarStyle.thin, String? thumbColor, String? trackColor, bool showScrollShadows = false, String? padding, String? className, Key? key})
const

Properties

child Widget
final
className String?
final
direction ScrollDirection
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxHeight String?
final
maxWidth String?
final
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbar ScrollbarVisibility
final
scrollbarSize String
final
scrollbarStyle ScrollbarStyle
final
showScrollShadows bool
final
thumbColor String?
final
trackColor String?
final
width String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited