ArcaneScrollRail class

A scrollable sidebar rail that maintains position independently of page scroll.

Inheritance

Constructors

ArcaneScrollRail({required List<Widget> children, ScrollRailPosition position = ScrollRailPosition.left, ScrollRailSize size = ScrollRailSize.md, String? width, String topOffset = '0px', String bottomOffset = '0px', bool showBorder = true, String? background, String padding = '1rem', bool customScrollbar = true, String? scrollPersistenceId, Key? key})
const
ArcaneScrollRail.left({required List<Widget> children, ScrollRailSize size = ScrollRailSize.md, String? width, String topOffset = '0px', String bottomOffset = '0px', bool showBorder = true, String? background, String padding = '1rem', bool customScrollbar = true, String? scrollPersistenceId, Key? key})
const
ArcaneScrollRail.right({required List<Widget> children, ScrollRailSize size = ScrollRailSize.md, String? width, String topOffset = '0px', String bottomOffset = '0px', bool showBorder = true, String? background, String padding = '1rem', bool customScrollbar = true, String? scrollPersistenceId, Key? key})
const

Properties

background String?
final
bottomOffset String
final
children List<Widget>
final
customScrollbar bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding String
final
position ScrollRailPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPersistenceId String?
final
showBorder bool
final
size ScrollRailSize
final
topOffset String
final
width String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited