ActionSheetItem class

An action item for ArcaneActionSheet.

Constructors

ActionSheetItem({required String label, String? icon, bool destructive = false, bool disabled = false, VoidCallback? onTap, bool closeOnTap = true, Widget? trailing})
const

Properties

closeOnTap bool
final
destructive bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
label String
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited