ArcaneActionSheet class

Action sheet with a list of actions (mobile-style).

Inheritance

Constructors

ArcaneActionSheet({required bool isOpen, required List<ActionSheetItem> actions, VoidCallback? onClose, String? title, String? message, bool showCancel = true, String cancelLabel = 'Cancel', Key? key})
const

Properties

actions List<ActionSheetItem>
final
cancelLabel String
final
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String?
final
onClose VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCancel bool
final
title String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited