ArcaneSheet class
A modal sheet that slides in from screen edges.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneSheet
Constructors
- ArcaneSheet({required bool isOpen, required Widget child, VoidCallback? onClose, SheetPosition position = SheetPosition.bottom, SheetSize size = SheetSize.auto, String? title, String? description, Widget? header, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, bool showDragHandle = true, String? maxWidth, Key? key})
-
const
- ArcaneSheet.bottom({required bool isOpen, required Widget child, VoidCallback? onClose, SheetSize size = SheetSize.auto, String? title, String? description, Widget? header, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = false, bool showDragHandle = true, String? maxWidth, Key? key})
-
const
- ArcaneSheet.end({required bool isOpen, required Widget child, VoidCallback? onClose, SheetSize size = SheetSize.md, String? title, String? description, Widget? header, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, bool showDragHandle = false, String? maxWidth, Key? key})
-
const
- ArcaneSheet.top({required bool isOpen, required Widget child, VoidCallback? onClose, SheetSize size = SheetSize.auto, String? title, String? description, Widget? header, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, bool showDragHandle = false, String? maxWidth, Key? key})
-
const
Properties
- child → Widget
-
final
- closeOnBackdropClick → bool
-
final
- description → String?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- isOpen → bool
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxWidth → String?
-
final
- onClose → VoidCallback?
-
final
- position → SheetPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBackdrop → bool
-
final
- showCloseButton → bool
-
final
- showDragHandle → bool
-
final
- size → SheetSize
-
final
- title → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited