ArcaneTabBar class

A simple tab bar without content for custom tab handling.

Inheritance

Constructors

ArcaneTabBar({required List<ArcaneTabBarItem> tabs, required int selectedIndex, required void onChanged(int index), bool fill = false, Key? key})
const

Properties

fill bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onChanged → void Function(int index)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex int
final
tabs List<ArcaneTabBarItem>
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited