ArcaneTabs class

A tab component for switching between views.

Inheritance

Constructors

ArcaneTabs({required List<ArcaneTabItem> tabs, int initialIndex = 0, void onChanged(int index)?, bool fill = false, Key? key})
const

Properties

fill bool
final
hashCode int
The hash code for this object.
no setterinherited
initialIndex int
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onChanged → void Function(int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabs List<ArcaneTabItem>
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneTabs>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited