ArcaneContextMenu class

Context menu that appears on right-click.

Inheritance

Constructors

ArcaneContextMenu({String? id, required Widget trigger, required List<ArcaneMenuItem> items, bool keepOpenOnAction = false, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
final
items List<ArcaneMenuItem>
final
keepOpenOnAction bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger Widget
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited