ArcaneDropdownMenu class

Dropdown menu component.

Inheritance

Constructors

ArcaneDropdownMenu({String? id, required Widget trigger, required List<ArcaneMenuItem> items, DropdownAlignment alignment = DropdownAlignment.left, double? width, bool keepOpenOnAction = false, bool initiallyOpen = false, Key? key})
const

Properties

alignment DropdownAlignment
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
initiallyOpen bool
final
items List<ArcaneMenuItem>
final
keepOpenOnAction bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger Widget
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited