ArcaneMegaMenu class

Navigation dropdown with mega-menu style.

Inheritance

Constructors

ArcaneMegaMenu({required String label, required List<ArcaneMegaMenuSection> sections, Widget? footer, Key? key})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<ArcaneMegaMenuSection>
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneMegaMenu>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited