ArcaneMenubar class
Horizontal menu bar component.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneMenubar
Constructors
- ArcaneMenubar({Key? key})
-
const
Properties
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneMenubar> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited