ArcaneMenubarMenu class

Top-level menu in the menubar.

Constructors

ArcaneMenubarMenu({required String label, required List<ArcaneMenuItem> items})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<ArcaneMenuItem>
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited