ArcaneBreadcrumbs class

Navigation breadcrumbs component.

Inheritance

Constructors

ArcaneBreadcrumbs({required List<BreadcrumbItem> items, BreadcrumbSeparator separator = BreadcrumbSeparator.chevron, BreadcrumbSize size = BreadcrumbSize.md, bool showHomeIcon = false, Widget? customSeparator, void onItemClick(BreadcrumbItem item, int index)?, Key? key})
const

Properties

customSeparator Widget?
final
hashCode int
The hash code for this object.
no setterinherited
items List<BreadcrumbItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onItemClick → void Function(BreadcrumbItem item, int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator BreadcrumbSeparator
final
showHomeIcon bool
final
size BreadcrumbSize
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited