ArcaneDotIndicator class

Dot indicator for carousels, steppers, and page indicators.

Inheritance

Constructors

ArcaneDotIndicator({required int index, required int length, void onChanged(int)?, DotIndicatorSize size = DotIndicatorSize.md, String? activeColor, String? inactiveColor, String? spacing, bool interactive = true, Key? key})
const

Properties

activeColor String?
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor String?
final
index int
final
interactive bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
length int
final
onChanged → void Function(int)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size DotIndicatorSize
final
spacing String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited