DropdownMenu class

A dropdown menu component (Supabase-style)

Inheritance

Constructors

const

Properties

alignment DropdownAlignment
Alignment
final
hashCode int
The hash code for this object.
no setterinherited
items List<DropdownItem>
Menu items
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger Component
Trigger element
final
width double?
Width
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<DropdownMenu>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final