MegaMenu class

A navigation dropdown with mega-menu style

Inheritance

Constructors

MegaMenu({required String label, required List<MegaMenuSection> sections, Component? footer, Key? key})
const

Properties

Footer content
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
Trigger label
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<MegaMenuSection>
Menu sections
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<MegaMenu>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final