ArcaneHeader class

Website header/navbar component.

Inheritance

Constructors

ArcaneHeader({required List<ArcaneNavItem> navItems, List<Component>? actions, bool showSearch = false, String searchPlaceholder = 'Search...', void onSearch(String)?, bool sticky = true, bool transparent = false, bool bordered = true, Key? key})
const

Properties

actions List<Component>?
final
bordered bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
final
final
onSearch → void Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholder String
final
showSearch bool
final
sticky bool
final
transparent bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited