Header class

A website header/navbar component (Supabase-style)

Inheritance

Constructors

Header({required List<NavItem> navItems, List<Component>? actions, bool showSearch = false, String searchPlaceholder = 'Search...', void onSearch(String)?, bool sticky = true, bool transparent = false, bool bordered = true, Key? key})
const

Properties

actions List<Component>?
Right-side actions (buttons, etc.)
final
bordered bool
Whether to add border bottom
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
Logo component (usually an image or text)
final
Navigation items
final
onSearch → void Function(String)?
Search callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholder String
Search placeholder text
final
showSearch bool
Whether to show a search bar
final
sticky bool
Whether the header is fixed/sticky
final
transparent bool
Whether to use transparent background
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final