ArcaneDropdownItem class

Dropdown item component with multiple style variants.

Supports icon badge style with colored containers, simple style with inline icons, and compact style for dense lists.

Inheritance

Constructors

ArcaneDropdownItem({required String label, required String href, required Widget icon, String? description, String? accentColor, bool isExternal = false, ArcaneDropdownItemStyle style = ArcaneDropdownItemStyle.iconBadge, Key? key})
const

Properties

accentColor String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
href String
final
icon Widget
final
isExternal bool
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style ArcaneDropdownItemStyle
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneDropdownItem>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited