Sidebar class

A sidebar navigation component.

Inheritance

Constructors

Sidebar({required List<Component> children, Component? header, Component? footer, bool collapsed = false, void onCollapseChanged(bool collapsed)?, double width = 280, double collapsedWidth = 64, bool showCollapseToggle = true, bool rightSide = false, Key? key})
const

Properties

children List<Component>
The sidebar content
final
collapsed bool
Whether the sidebar is collapsed
final
collapsedWidth double
Width when collapsed
final
Footer component
final
hashCode int
The hash code for this object.
no setterinherited
Header component
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onCollapseChanged → void Function(bool collapsed)?
Callback when collapse state changes
final
rightSide bool
Whether the sidebar is on the right side
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCollapseToggle bool
Whether to show the collapse toggle
final
width double
Width of the sidebar
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<Sidebar>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final