ArcaneMinimizablePromo class

A promo drawer that slides in from the right edge.

When minimized, only a slim tab is visible. Click to expand the full panel.

Inheritance

Constructors

ArcaneMinimizablePromo({required String title, required String message, String? promoCode, String? discount, String? ctaText, String? ctaHref, void onCtaClick()?, void onDismiss()?, String tabLabel = 'DEAL', int delayMs = 2000, Key? key})
const

Properties

ctaHref String?
final
ctaText String?
final
delayMs int
final
discount String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String
final
onCtaClick → void Function()?
final
onDismiss → void Function()?
final
promoCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabLabel String
final
title String
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneMinimizablePromo>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited