ArcaneProgressClaimBanner class

A banner showing how many people have claimed an offer.

Creates urgency through social proof and scarcity.

Inheritance

Constructors

ArcaneProgressClaimBanner({required String title, required String message, required int claimedCount, required int totalCount, String? promoCode, String? ctaText, String? ctaHref, void onCtaClick()?, void onDismiss()?, int delayMs = 2000, bool simulateProgress = true, Key? key})
const

Properties

claimedCount int
final
ctaHref String?
final
ctaText String?
final
delayMs int
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String
final
onCtaClick → void Function()?
final
onDismiss → void Function()?
final
promoCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simulateProgress bool
final
title String
final
totalCount int
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneProgressClaimBanner>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited