component/promo/promo library
Flat announcement components.
Includes a top announcement row and an in-flow announcement row.
Classes
- ArcaneInlineHeroBanner
- A flat inline announcement that integrates with the hero section.
- ArcaneTopAnnouncementBar
- A thin sticky announcement bar at the top of the page.
- InlineHeroBannerProps
- Props for a flat, in-flow announcement row.
- TopAnnouncementBarProps
- Props for the single flat announcement surface supported by Arcane.