Screen class

Inheritance

Constructors

Screen({Widget child = const SizedBox.shrink(), Widget? sidebar, Widget? header, Widget? footer, Widget? fab, Widget? foreground, Widget? background, bool gutter = true, String? title, String? subtitle, List<Widget> actions = const <Widget>[], BarBackButtonMode backButtonMode = BarBackButtonMode.never, void onBack()?, Key? key})
const

Properties

actions List<Widget>
final
backButtonMode BarBackButtonMode
final
background Widget?
final
child Widget
final
fab Widget?
final
final
foreground Widget?
final
gutter bool
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onBack → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
subtitle String?
final
title String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited