ArcaneChatScreen<M extends AbstractChatMessage, U extends AbstractChatUser> class

Chat screen component.

Inheritance

Constructors

ArcaneChatScreen({required ChatProvider<M, U> provider, required String currentUserId, ChatStyle style = ChatStyle.bubbles, Component? header, bool showInput = true, String inputPlaceholder = 'Type a message...', bool showTimestamps = true, bool showAvatars = true, Component? sendButton, bool gutter = true, Key? key})
const

Properties

currentUserId String
final
gutter bool
final
hashCode int
The hash code for this object.
no setterinherited
final
inputPlaceholder String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
provider ChatProvider<M, U>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendButton Component?
final
showAvatars bool
final
showInput bool
final
showTimestamps bool
final
style ChatStyle
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneChatScreen<M, U>>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final