ChatProvider<M extends AbstractChatMessage, U extends AbstractChatUser> class
abstract
Chat provider interface.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getUser(
String id) → Future< U> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
String text) → Future< void> -
streamLastMessages(
) → Stream< List< M> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited