SimpleChatMessage class

Simple chat message implementation.

Implemented types

Constructors

SimpleChatMessage({required String id, required String content, required DateTime timestamp, required String senderId})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
messageWidget Component
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited