ArcaneFillScreen class

Screen that fills the entire viewport.

Inheritance

Constructors

ArcaneFillScreen({required Component child, Component? header, String? title, String? subtitle, List<Component>? actions, Component? footer, Component? sidebar, bool sidebarRight = false, Component? background, double? loadingProgress, bool loadingIndeterminate = false, void onBack()?, bool scrollable = true, Key? key})
const

Properties

actions List<Component>?
final
background Component?
final
child Component
final
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loadingIndeterminate bool
final
loadingProgress double?
final
onBack → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
final
final
sidebarRight bool
final
subtitle String?
final
title String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited