FillScreen class

Inheritance

Constructors

FillScreen({required Widget child, Widget? sidebar, Widget? header, Widget? footer, Widget? fab, Widget? foreground, Widget? background, bool gutter = true, Key? key})
const

Properties

background Widget?
finalinherited
child Widget
final
fab Widget?
finalinherited
finalinherited
foreground Widget?
finalinherited
gutter bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
finalinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited