ArcaneNavigationScreen class

Screen with built-in navigation (sidebar or bottom nav).

Inheritance

Constructors

ArcaneNavigationScreen({required List<ArcaneNavigationDestination> destinations, int initialIndex = 0, void onNavigationChanged(int index)?, NavigationMode mode = NavigationMode.auto, double breakpoint = 768, Component? sidebarHeader, Component? sidebarFooter, bool sidebarCollapsible = true, bool sidebarCollapsed = false, Key? key})
const

Properties

breakpoint double
final
destinations List<ArcaneNavigationDestination>
final
hashCode int
The hash code for this object.
no setterinherited
initialIndex int
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
mode NavigationMode
final
onNavigationChanged → void Function(int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sidebarCollapsed bool
final
sidebarCollapsible bool
final
sidebarFooter Component?
final
sidebarHeader Component?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneNavigationScreen>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited