ResponsiveScaffold class

A responsive scaffold that adapts to screen size

Inheritance

Constructors

ResponsiveScaffold({required Component mobile, Component? tablet, Component? desktop, double tabletBreakpoint = 768, double desktopBreakpoint = 1024, Key? key})
const

Properties

desktop Component?
Content for large screens (desktop) - defaults to tablet or mobile
final
desktopBreakpoint double
Breakpoint for desktop (min-width)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
mobile Component
Content for small screens (mobile)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet Component?
Content for medium screens (tablet) - defaults to mobile
final
tabletBreakpoint double
Breakpoint for tablet (min-width)
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final