ArcaneNotFoundAction class

A recovery link rendered by ArcaneNotFoundPage.

Constructors

ArcaneNotFoundAction({required String label, required String href, bool primary = false, String? ariaLabel})
const

Properties

ariaLabel String?
final
hashCode int
The hash code for this object.
no setterinherited
href String
final
label String
final
primary bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited