ArcaneNotFoundPage constructor

const ArcaneNotFoundPage({
  1. String? id,
  2. String applicationName = 'Application',
  3. String code = '404',
  4. String title = 'Page not found',
  5. String description = 'The page you requested does not exist or is no longer available.',
  6. String? requestedPath,
  7. String? diagnosticCode,
  8. List<ArcaneNotFoundAction> actions = const <ArcaneNotFoundAction>[ArcaneNotFoundAction(label: 'Return home', href: '/', primary: true)],
  9. bool standalone = true,
  10. String classes = '',
  11. Map<String, String> attributes = const <String, String>{},
  12. Key? key,
})

Implementation

const ArcaneNotFoundPage({
  this.id,
  this.applicationName = 'Application',
  this.code = '404',
  this.title = 'Page not found',
  this.description =
      'The page you requested does not exist or is no longer available.',
  this.requestedPath,
  this.diagnosticCode,
  this.actions = const <ArcaneNotFoundAction>[
    ArcaneNotFoundAction(label: 'Return home', href: '/', primary: true),
  ],
  this.standalone = true,
  this.classes = '',
  this.attributes = const <String, String>{},
  super.key,
});