ArcaneScreen class

Base screen component that provides consistent layout structure.

Inheritance

Constructors

ArcaneScreen({required Component child, Component? header, String? title, String? subtitle, List<Component>? actions, Component? footer, Component? sidebar, bool sidebarRight = false, Component? fab, Component? background, Component? foreground, double? loadingProgress, bool loadingIndeterminate = false, EdgeInsets? padding, void onBack()?, Key? key})
const

Properties

actions List<Component>?
final
background Component?
final
child Component
final
fab Component?
final
final
foreground Component?
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loadingIndeterminate bool
final
loadingProgress double?
final
onBack → void Function()?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
sidebarRight bool
final
subtitle String?
final
title String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final