SliverScreen class

Inheritance

Constructors

SliverScreen({required Widget sliver, Widget? sidebar, Widget? header, Widget? footer, Widget? fab, Widget? foreground, Widget? background, bool gutter = true, Key? key})
const

Properties

background Widget?
finalinherited
fab Widget?
finalinherited
finalinherited
foreground Widget?
finalinherited
gutter bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
finalinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
sliver Widget
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<SliverScreen>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited