component/support/app library

Classes

AccordionItemProps
Accordion item data.
AccordionProps
Accordion component properties.
AlertBannerProps
Alert banner component properties.
AlertDialogProps
Alert dialog component properties.
AlertProps
Alert component properties.
AnimatedCounterProps
Animated counter component properties.
AnimatedGradientTextProps
Animated gradient text component properties.
ArcaneApp
Root application component for Arcane Jaspr apps.
ArcaneChipProps
Selectable chip component properties.
ArcaneDividerProps
Arcane divider component properties.
ArcaneMenuItem
Unified menu item for dropdown menus, context menus, and menubars.
ArcaneStylesheet
Base class for stylesheets.
ArcaneThemeProvider
Provides the current stylesheet and brightness to the component tree.
ArcaneWindow
Web wrapper for ArcaneApp with optional background styling.
ArrowLinkProps
Arrow link component properties.
AspectRatioProps
Aspect ratio container component properties.
AuthBackLinkProps
Auth back link component properties.
AuthBrandingPanelProps
Auth branding panel component properties.
AuthLayoutProps
Auth layout component properties.
AuthorCardProps
Author card component properties.
AuthSplitLayoutProps
Auth split layout component properties.
AvatarProps
Avatar component properties.
BadgeProps
Badge component properties.
BarProps
Bar/app bar component properties.
BottomBarProps
Bottom bar container component properties.
BottomNavigationBarProps
Bottom navigation bar component properties.
BottomNavItem
Bottom navigation item data.
Breadcrumb item data.
Breadcrumbs component properties.
ButtonGroupProps
Button group component properties.
ButtonPanelProps
Button panel component properties.
ButtonProps
Button component properties.
CalendarProps
Calendar component properties.
CalloutProps
Callout component properties.
CardProps
Card component properties.
CardSectionProps
Card section component properties.
CarpetProps
Carpet/surface container component properties.
CenterBodyProps
Center body component properties.
CenterProps
Center alignment component properties.
CheckboxProps
Checkbox component properties.
CheckItemProps
Check item component properties.
CheckListProps
Check list component properties.
ChipGroupProps
Chip group component properties.
ChipProps
Chip component properties.
CircularProgressProps
Circular progress component properties.
CodePreviewProps
Code preview component properties.
CodeSnippetProps
Code snippet component properties.
CodeWindowProps
Code window component properties.
CodexStylesheet
Codex stylesheet - Gamer-inspired theme with neon glows.
ColorInputProps
Color input component properties.
ColumnProps
Column layout component properties.
CommandGroupProps
Command group data.
CommandItemProps
Command item data.
CommandProps
Command palette component properties.
ComponentRenderers
Interface that all stylesheets must implement.
ConfirmDialogProps
Confirm dialog component properties.
ContextMenuProps
Context menu component properties.
CounterRowProps
Counter row component properties.
CtaBannerProps
CTA banner component properties.
CtaGroupProps
CTA group component properties.
CycleButtonProps<T>
Cycle button component properties.
CycleOption<T>
Cycle option data.
DashboardLayoutProps
Dashboard layout component properties.
DashboardNavGroup
Dashboard navigation group data.
DashboardNavItem
Dashboard navigation item data.
DashboardTopBarProps
Dashboard top bar component properties.
DataColumnProps<T>
Data column definition.
DataTableProps<T>
Data table component properties.
DatePickerProps
Date picker component properties.
DateRangeValue
Date range value.
DialogBarProps
Dialog bar component properties.
DialogProps
Dialog component properties.
DisclosureGroupProps
Disclosure group component properties.
DisclosureItemProps
Disclosure item data.
DisclosureProps
Disclosure component properties.
DividerProps
Divider component properties.
DotIndicatorProps
Dot indicator component properties.
DrawerProps
Drawer component properties.
Dropdown menu component properties.
EmptyStateProps
Empty state component properties.
ErrorStateProps
Error state component properties.
ExpandedProps
Expanded component properties.
ExpanderProps
Expander component properties.
FABProps
FAB (Floating Action Button) component properties.
FadeEdgeProps
Fade edge component properties.
FeatureCardProps
Feature card component properties.
FeatureRowProps
Feature row component properties.
FeatureShowcaseItem
Feature showcase item data.
FeatureShowcaseProps
Feature showcase component properties.
FieldWrapperProps
Field wrapper component properties.
FileUploadProps
File upload component properties.
FlexiCardItem
Flexi card item data.
FlexiCardsProps
FlexiCards component properties.
FlexiCardsSimpleProps
FlexiCards simple component properties.
FlowProps
Flow layout component properties.
FooterBrandColumnProps
Footer brand column component properties.
FooterColumnProps
Footer column component properties.
Footer link data.
FooterLinkGroup
Footer link group data.
FooterProps
Footer component properties.
FooterSocialIconProps
Footer social icon component properties.
FormProps
Form component properties.
FormSectionProps
Form section component properties.
GameCardProps
Game card component properties.
GameSelectorProps
Game selector component properties.
GameTileProps
Game tile component properties.
GapProps
Gap component properties.
GlassCardProps
Glass card component properties.
GlassProps
Glass container component properties.
GlowTextProps
Glow text component properties.
GradientGlassProps
Gradient glass component properties.
GradientTextProps
Gradient text component properties.
GutterProps
Gutter/spacing component properties.
HamburgerButtonProps
Hamburger button component properties.
HeaderProps
Header/navbar component properties.
HeroSectionProps
Hero section component properties.
HovercardProps
Hovercard component properties.
IconButtonProps
Icon button component properties.
IconCardProps
Icon card component properties.
IndexedStackProps
Indexed stack component properties.
InlineCodeProps
Inline code component properties.
InputDialogProps
Input dialog component properties.
InputGroupProps
Input group component properties.
IntegrationCardProps
Integration card component properties.
IntegrationGridProps
Integration grid component properties.
ItemPickerProps<T>
Item picker dialog component properties.
KbdProps
Keyboard shortcut display component properties.
KeyValueRowData
Key-value row data.
KeyValueTableProps
Key-value table component properties.
ListCardProps
List card component properties.
LoaderProps
Loader component properties.
LoadingOverlayProps
Loading overlay component properties.
LoadingSpinnerProps
Loading spinner component properties.
LoadingStateProps
Loading state component properties.
LogoCarouselProps
Logo carousel component properties.
LogoGridProps
Logo grid component properties.
LogoItem
Logo item data.
MarqueeProps
Marquee component properties.
Menubar menu data.
Menubar component properties.
MeterProps
Meter/gauge component properties.
MetricDisplayProps
Metric display component properties.
MobileMenuProps
Mobile menu component properties.
MobileNavItem
Mobile navigation item data.
Navigation item data.
Navigation link component properties.
Navigation tile component properties.
NewsletterFormProps
Newsletter form component properties.
NumberInputProps
Number input component properties.
OtpInputProps
OTP input component properties.
OutlineTextProps
Outline text component properties.
PaddingWrapperProps
Padding wrapper component properties.
PageBodyProps
Page body component properties.
PaginationProps
Pagination component properties.
PopoverProps
Popover component properties.
PricingCardProps
Pricing card component properties.
PricingGridProps
Pricing grid component properties.
PricingTier
Pricing tier data.
ProgressProps
Progress bar component properties.
RadioCardItemData<T>
Radio card item data.
RadioCardsProps<T>
Radio cards component properties.
RadioGroupProps<T>
Radio group component properties.
RadioOptionProps<T>
Radio option data.
RatingStarsProps
Rating stars component properties.
RatingStarsSimpleProps
Simple rating stars component properties.
ResizablePanelData
Resizable panel data.
ResizableProps
Resizable panel group component properties.
RowProps
Row layout component properties.
ScrollAreaProps
Scroll area component properties.
ScrollRailLayoutProps
Scroll rail layout component properties.
ScrollRailProps
Scroll rail component properties.
SearchProps
Search input component properties.
SearchResult
Search result item data.
SectionHeaderProps
Section header component properties.
SectionProps
Section component properties.
SelectableChipGroupProps
Selectable chip group component properties.
SelectOptionProps<T>
Select option data.
SelectProps<T>
Select component properties.
SeparatorProps
Separator component properties.
SettingsInfoRowProps
Settings info row component properties.
SettingsNoteProps
Settings note component properties.
SettingsSectionProps
Settings section component properties.
SettingsSubheaderProps
Settings subheader component properties.
SettingsToggleRowProps
Settings toggle row component properties.
ShadcnStylesheet
ShadCN UI stylesheet.
SheetProps
Sheet/drawer component properties.
SidebarGroupProps
Sidebar group component properties.
SidebarItemProps
Sidebar item component properties.
SidebarProps
Sidebar component properties.
SidebarSubMenuProps
Sidebar submenu component properties.
SimpleStatusBadgeProps
Simple status badge component properties.
SizedBoxProps
SizedBox component properties.
SkeletonProps
Skeleton component properties.
SliderProps
Slider component properties.
SlotCounterCardProps
Slot counter card component properties.
SlotCounterProps
Slot counter component properties.
SlotCounterRowProps
Slot counter row component properties.
SocialIconGroupProps
Social icon group component properties.
SocialIconProps
Social icon component properties.
SocialLinkItem
Social link item data.
SocialLinksProps
Social links component properties.
SpacerProps
Spacer component properties.
StatCardProps
Stat card component properties.
StatCardRowProps
Stat card row component properties.
StatDisplayProps
Stat display component properties.
StaticTableProps
Static table component properties.
StatRowProps
Stat row component properties.
StatusBadgeProps
Status badge component properties.
StatusIndicatorProps
Status indicator component properties.
StepIndicatorProps
Step indicator component properties.
StepItemData
Step item data.
StepperProps
Stepper component properties.
SurfaceCardProps
Surface card component properties.
SurfaceProps
Surface component properties.
SwitcherProps
Switcher component properties.
TabBarItemProps
Tab bar item data.
TabBarProps
Tab bar component properties.
TabItemProps
Tab item data.
TabsProps
Tabs component properties.
TagInputProps
Tag input component properties.
TerminalProps
Terminal component properties.
TestimonialCardProps
Testimonial card component properties.
TextInputProps
Text input component properties.
ThumbHashCardProps
ThumbHash card component properties.
TileProps
Tile component properties.
TimeDialogProps
Time dialog component properties.
TimelineItemData
Timeline item data.
TimelineProps
Timeline component properties.
TimeOfDay
Represents a time of day with hour and minute.
TimePickerProps
Time picker component properties.
ToastAction
Toast action button data.
ToastContainerProps
Toast container component properties.
ToastProps
Toast component properties.
ToggleButtonProps
Toggle button component properties.
ToggleGroupItemProps
Toggle group item data.
ToggleGroupProps
Toggle group component properties.
ToggleSwitchProps
Toggle switch component properties.
ToolbarProps
Toolbar component properties.
TooltipProps
Tooltip component properties.
TrackerData
Tracker cell data.
TrackerProps
Tracker component properties.
TreeNodeData
Tree node data.
TreeViewProps
Tree view component properties.
UploadedFile
Uploaded file data.
UptimeDay
Uptime day data.
UptimeTrackerProps
Uptime tracker component properties.
VirtualScrollProps<T>
Virtual scroll component properties.
WaitlistFormProps
Waitlist form component properties.

Enums

AlertBannerVariant
AlertSeverity
AlertVariant
ArrowLinkSize
AuthorCardSize
AvatarShape
AvatarSize
BadgeSize
BadgeVariant
BarBackButtonMode
Brightness
Brightness mode for the application.
ButtonSize
ButtonVariant
CalendarModeVariant
CalloutVariant
CardVariant
CheckboxSize
CheckboxVariant
CheckStyle
ChipSize
ChipVariant
CodeWindowStyle
CodexAccent
Available accent themes for Codex.
ColorInputSize
CycleButtonSize
CycleButtonVariant
DataTableTextAlign
DatePickerSizeVariant
DisclosureVariant
DividerOrientation
DividerVariant
DotIndicatorSize
DrawerPosition
DrawerSize
EmptyStateSizeVariant
EmptyStateStyleVariant
FABPosition
FABSize
FABVariant
FadeDirection
FileUploadSize
FileUploadStyle
GutterSize
HovercardPositionVariant
IconButtonSize
IconButtonVariant
InputDialogType
KbdSize
KbdStyle
LoaderVariant
MarqueeDirection
MeterColorVariant
MeterSizeVariant
MeterStyleVariant
NumberInputSize
OtpInputSizeVariant
PaginationSizeVariant
PaginationStyleVariant
PopoverPosition
PopoverTrigger
ProgressSize
ProgressVariant
RadioGroupLayout
RadioGroupVariant
ResizeDirection
ScrollbarStyleVariant
ScrollbarVisibilityVariant
ScrollDirectionVariant
ScrollRailPosition
ScrollRailSize
SearchSize
SearchStyle
SectionHeaderAlign
SelectDropdownDirection
SelectSize
SeparatorOrientation
SettingsNoteVariant
ShadcnTheme
Color themes for ShadCN stylesheet.
SheetSizeVariant
SkeletonShape
SliderSize
SliderVariant
SlotCounterColor
SlotCounterSize
SocialPlatform
StatDisplayLayout
StatusBadgeSize
StatusType
StepIndicatorSize
StepsLayout
StepsSize
StepStatus
SurfaceEffect
SurfaceShadow
SwitcherDirection
TagInputStyleVariant
TextInputSize
TextInputType
TextInputVariant
ThemeMode
Theme mode selection.
TimelineLayout
TimelineSize
TimelineStatus
TimePickerSize
ToastPosition
ToastVariant
ToggleGroupSelectionType
ToggleGroupSizeVariant
ToggleGroupVariantStyle
ToggleSwitchSize
ToggleSwitchVariant
TooltipPosition
TrackerLevel
TreeSelectionMode
TreeViewStyle

Extensions

ArcaneThemeContext on BuildContext
Extension for easy access to theme properties from context.