ArcaneWindow class

Web wrapper for ArcaneApp with optional background styling.

Inheritance

Constructors

ArcaneWindow({ArcaneStylesheet stylesheet = const ShadcnStylesheet(), Brightness brightness = Brightness.dark, required Component child, Key? key})
const

Properties

brightness Brightness
final
child Component
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stylesheet ArcaneStylesheet
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited