head static method
Inject elements into the document head using data objects
Implementation
static Component head({List<HeadElementData>? elements}) {
throw UnsupportedError('Cannot use DocumentHelper without a platform implementation');
}
Inject elements into the document head using data objects
static Component head({List<HeadElementData>? elements}) {
throw UnsupportedError('Cannot use DocumentHelper without a platform implementation');
}