Text class

Text component with enum-based styling.

Inheritance

Constructors

Text(String text, {FontSize? size, FontWeight? weight, TextColor? color, String? colorCustom, TextAlign? align, LineHeight? lineHeight, LetterSpacing? letterSpacing, TextDecoration? decoration, TextTransform? transform, FontFamily? family, FontStyle? fontStyle, TextOverflow? overflow, WhiteSpace? whiteSpace, int? maxLines, bool selectable = true, ArcaneStyleData? style, String element = 'span', Key? key})
const
Text.body(String text, {TextColor? color = TextColor.muted, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.bodyLarge(String text, {TextColor? color = TextColor.muted, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.bodySmall(String text, {TextColor? color = TextColor.muted, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.caption(String text, {TextColor? color = TextColor.subtle, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.code(String text, {TextColor? color = TextColor.accent, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.heading(String text, {TextColor? color = TextColor.primary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.heading2(String text, {TextColor? color = TextColor.primary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.heading3(String text, {TextColor? color = TextColor.primary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.label(String text, {TextColor? color = TextColor.primary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
const
Text.pageTitle(String text, {TextColor? color = TextColor.primary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.sectionTitle(String text, {TextColor? color = TextColor.primary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.subheading(String text, {TextColor? color = TextColor.secondary, TextAlign? align, ArcaneStyleData? style, Key? key})
const
Text.truncated(String text, {FontSize? size, FontWeight? weight, TextColor? color, TextAlign? align, ArcaneStyleData? style, Key? key})
const

Properties

align TextAlign?
final
color TextColor?
final
colorCustom String?
final
decoration TextDecoration?
final
element String
final
family FontFamily?
final
fontStyle FontStyle?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
letterSpacing LetterSpacing?
final
lineHeight LineHeight?
final
maxLines int?
final
overflow TextOverflow?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool
final
size FontSize?
final
style ArcaneStyleData?
final
text String
final
transform TextTransform?
final
weight FontWeight?
final
whiteSpace WhiteSpace?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited