TextSpan class
Text span for use within RichText.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- TextSpan
Constructors
- TextSpan(String text, {FontSize? size, FontWeight? weight, TextColor? color, String? colorCustom, TextDecoration? decoration, FontFamily? family, FontStyle? fontStyle, ArcaneStyleData? style, Key? key})
-
const
Properties
- color → TextColor?
-
final
- colorCustom → String?
-
final
- decoration → TextDecoration?
-
final
- family → FontFamily?
-
final
- fontStyle → FontStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → FontSize?
-
final
- style → ArcaneStyleData?
-
final
- text → String
-
final
- weight → FontWeight?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited