ArcaneAlert class
Inline alert component for important messages that need user attention.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneAlert
Constructors
- ArcaneAlert({required ColorVariant color, String? title, String? message, Widget? child, AlertStyle style = AlertStyle.subtle, Widget? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Widget? action, Key? key})
-
const
- ArcaneAlert.error({String? title, String? message, Widget? child, AlertStyle style = AlertStyle.subtle, Widget? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Widget? action, Key? key})
-
const
- ArcaneAlert.info({String? title, String? message, Widget? child, AlertStyle style = AlertStyle.subtle, Widget? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Widget? action, Key? key})
-
const
- ArcaneAlert.success({String? title, String? message, Widget? child, AlertStyle style = AlertStyle.subtle, Widget? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Widget? action, Key? key})
-
const
- ArcaneAlert.warning({String? title, String? message, Widget? child, AlertStyle style = AlertStyle.subtle, Widget? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Widget? action, Key? key})
-
const
Properties
- action → Widget?
-
final
- child → Widget?
-
final
- color → ColorVariant
-
final
- dismissible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- message → String?
-
final
- onDismiss → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
- style → AlertStyle
-
final
- title → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited