AnimatedCounter class

Animated counter display for statistics

Inheritance

Constructors

AnimatedCounter({required String value, String? prefix, String? suffix, String? label, String fontSize = '48px', String? color, String? gradientStart, String? gradientEnd, Key? key})
const

Properties

color String?
Custom color
final
fontSize String
Font size
final
gradientEnd String?
Gradient end color (use with gradientStart)
final
gradientStart String?
Gradient start color (use with gradientEnd)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
Label text
final
prefix String?
Prefix (e.g., "$")
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix String?
Suffix (e.g., "+", "%")
final
value String
The value to display
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited