ArcaneAvatarGroup class

Avatar group for stacking multiple avatars with overlap.

Inheritance

Constructors

ArcaneAvatarGroup({required List<ArcaneAvatar> avatars, int maxVisible = 4, AvatarSize size = AvatarSize.md, AvatarGroupDirection direction = AvatarGroupDirection.toRight, int overlap = 12, Key? key})
const
ArcaneAvatarGroup.toBottom({required List<ArcaneAvatar> avatars, int maxVisible = 4, AvatarSize size = AvatarSize.md, int overlap = 12, Key? key})
const
ArcaneAvatarGroup.toLeft({required List<ArcaneAvatar> avatars, int maxVisible = 4, AvatarSize size = AvatarSize.md, int overlap = 12, Key? key})
const
ArcaneAvatarGroup.toRight({required List<ArcaneAvatar> avatars, int maxVisible = 4, AvatarSize size = AvatarSize.md, int overlap = 12, Key? key})
const
ArcaneAvatarGroup.toTop({required List<ArcaneAvatar> avatars, int maxVisible = 4, AvatarSize size = AvatarSize.md, int overlap = 12, Key? key})
const

Properties

avatars List<ArcaneAvatar>
final
direction AvatarGroupDirection
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxVisible int
final
overlap int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size AvatarSize
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited