AvatarGroup class

Avatar group for stacking multiple avatars

Inheritance

Constructors

AvatarGroup({required List<ArcaneAvatar> avatars, int maxVisible = 4, AvatarSize size = AvatarSize.md, Key? key})
const

Properties

avatars List<ArcaneAvatar>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxVisible int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size AvatarSize
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited