Badge class

A pill-shaped badge/label component

Use style presets for cleaner code:

Badge('Active', style: BadgeStyle.success)
Inheritance

Constructors

Badge(String label, {Component? icon, BadgeStyle? style, @Deprecated('Use style parameter instead') BadgeVariant? variant, BadgeSize size = BadgeSize.md, Key? key})
const
Badge.destructive(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Alias for error
const
Badge.error(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Error/destructive badge
const
Badge.info(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Info badge
const
Badge.outline(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Outline badge
const
Badge.primary(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Primary badge
const
Badge.success(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Success badge
const
Badge.warning(String label, {Component? icon, BadgeSize size = BadgeSize.md, Key? key})
Warning badge
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Component?
Optional leading icon
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
The badge text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size BadgeSize
Badge size
final
style BadgeStyle?
Style preset (preferred over variant)
final
variant BadgeVariant?
Badge variant (legacy - use style instead)
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited