BadgeVariant enum

Badge variants (legacy - prefer using BadgeStyle presets)

Inheritance
Available extensions
Annotations
  • @Deprecated('Use style parameter with BadgeStyle presets instead')

Values

default_ → const BadgeVariant

Default/neutral badge

primary → const BadgeVariant

Primary/accent colored badge

secondary → const BadgeVariant

Secondary/muted badge

success → const BadgeVariant

Success badge (green)

warning → const BadgeVariant

Warning badge (amber)

destructive → const BadgeVariant

Destructive/error badge (red)

outline → const BadgeVariant

Outline badge

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BadgeVariant>
A constant List of the values in this enum, in order of their declaration.