ArcaneBar class

An app bar / header component.

Inheritance

Constructors

ArcaneBar({String? titleText, Component? title, String? subtitleText, Component? subtitle, List<Component>? leading, List<Component>? trailing, BarBackButtonMode backButton = BarBackButtonMode.auto, void onBack()?, bool transparent = false, bool centerTitle = false, double? height, EdgeInsets? padding, Key? key})
const

Properties

backButton BarBackButtonMode
final
centerTitle bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
leading List<Component>?
final
onBack → void Function()?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle Component?
final
subtitleText String?
final
title Component?
final
titleText String?
final
trailing List<Component>?
final
transparent bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited