Bar class
- Inheritance
Constructors
-
Bar({List<
Widget> trailing = const <Widget>[], List<Widget> leading = const <Widget>[], Widget? child, Widget? title, Widget? barHeader, String? titleText, String? headerText, String? subtitleText, Widget? header, Widget? subtitle, bool trailingExpanded = false, bool useGlass = true, bool centerTitle = false, BarBackButtonMode backButton = BarBackButtonMode.never, void onBack()?, Key? key}) -
const
Properties
- backButton → BarBackButtonMode
-
final
-
final
- barHeader → Widget?
-
final
- centerTitle → bool
-
final
- child → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- headerText → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
leading
→ List<
Widget> -
final
- onBack → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → Widget?
-
final
- subtitleText → String?
-
final
- title → Widget?
-
final
- titleText → String?
-
final
-
trailing
→ List<
Widget> -
final
- trailingExpanded → bool
-
final
- useGlass → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited