ArcaneCallout class
Inline callout/notice component for highlighting important information.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneCallout
Constructors
- ArcaneCallout({String? title, String? content, Component? child, CalloutVariant variant = CalloutVariant.info, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.error({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.info({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.neutral({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.note({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.success({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.tip({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
- ArcaneCallout.warning({String? title, String? content, Component? child, Component? icon, bool showIcon = true, bool dismissible = false, VoidCallback? onDismiss, Key? key})
-
const
Properties
- child → Component?
-
final
- content → String?
-
final
- dismissible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onDismiss → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
- title → String?
-
final
- variant → CalloutVariant
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited