ImageCard class

An image card with overlay text

Inheritance

Constructors

ImageCard({required String imageUrl, String? title, String? subtitle, Component? overlay, double? height, double? radius, void onTap()?, BoxFit fit = BoxFit.cover, Key? key})
const

Properties

fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
imageUrl String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onTap → void Function()?
final
overlay Component?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final