CardSection class

A card with section-style content organization.

Inheritance

Constructors

CardSection({String? header, Component? headerComponent, required List<Component> children, EdgeInsets? padding, double? radius, double gap = 12, List<Component>? trailing, Key? key})
const

Properties

children List<Component>
The child components
final
gap double
Gap between children
final
hashCode int
The hash code for this object.
no setterinherited
Section header
final
headerComponent Component?
Header component (overrides header string)
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
padding EdgeInsets?
Custom padding
final
radius double?
Border radius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing List<Component>?
Trailing actions for the header
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited