component/view/check_list library

Classes

ArcaneCheckItem
A single check item with icon and text.
ArcaneCheckList
A list of check items.
ArcaneFeatureRow
A feature/benefit row commonly used in pricing or comparison sections.
CheckItemProps
Check item component properties.
CheckListProps
Check list component properties.
FeatureRowProps
Feature row component properties.

Enums

CheckStyle

Mixins

CheckListRendererContract
Mixin defining the renderer methods for check list components.