ArcaneCheckItem class

A single check item with icon and text.

Inheritance

Constructors

ArcaneCheckItem({required String text, CheckStyle icon = CheckStyle.check, String? iconColor, String? textColor, String? fontSize, String? gap, Key? key})
const
ArcaneCheckItem.brand({required String text, CheckStyle icon = CheckStyle.check, String? textColor, String? fontSize, String? gap, Key? key})
const
ArcaneCheckItem.success({required String text, CheckStyle icon = CheckStyle.check, String? textColor, String? fontSize, String? gap, Key? key})
const

Properties

fontSize String?
final
gap String?
final
hashCode int
The hash code for this object.
no setterinherited
icon CheckStyle
final
iconColor String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textColor String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited