ArcaneCheckList class

A list of check items.

Inheritance

Constructors

ArcaneCheckList({required List<String> items, CheckStyle icon = CheckStyle.check, String? iconColor, String? textColor, String? fontSize, String? itemGap, String? listGap, String? alignItems, Key? key})
const
ArcaneCheckList.brand({required List<String> items, CheckStyle icon = CheckStyle.check, String? textColor, String? fontSize, String? itemGap, String? listGap, String? alignItems, Key? key})
const
ArcaneCheckList.success({required List<String> items, CheckStyle icon = CheckStyle.check, String? textColor, String? fontSize, String? itemGap, String? listGap, String? alignItems, Key? key})
const

Properties

alignItems String?
final
fontSize String?
final
hashCode int
The hash code for this object.
no setterinherited
icon CheckStyle
final
iconColor String?
final
itemGap String?
final
items List<String>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
listGap String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited