ArcaneChip class

Chip/tag component for labels and filters.

Inheritance

Constructors

ArcaneChip({required String label, Component? icon, ChipVariant variant = ChipVariant.standard, ChipSize size = ChipSize.medium, bool removable = false, void onRemove()?, void onTap()?, Key? key})
const
ArcaneChip.error({required String label, Component? icon, ChipSize size = ChipSize.medium, bool removable = false, void onRemove()?, void onTap()?, Key? key})
const
ArcaneChip.outline({required String label, Component? icon, ChipSize size = ChipSize.medium, bool removable = false, void onRemove()?, void onTap()?, Key? key})
const
ArcaneChip.primary({required String label, Component? icon, ChipSize size = ChipSize.medium, bool removable = false, void onRemove()?, void onTap()?, Key? key})
const
ArcaneChip.success({required String label, Component? icon, ChipSize size = ChipSize.medium, bool removable = false, void onRemove()?, void onTap()?, Key? key})
const
ArcaneChip.warning({required String label, Component? icon, ChipSize size = ChipSize.medium, bool removable = false, void onRemove()?, void onTap()?, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
final
onRemove → void Function()?
final
onTap → void Function()?
final
removable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ChipSize
final
variant ChipVariant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited