component/view/code_snippet library

Classes

ArcaneCodeSnippet
A code snippet component with copy button overlaid in top-right corner.
ArcaneInlineCode
An inline code component.
ArcaneTerminal
A terminal/command line component with copy button overlaid in top-right.
CodeSnippetProps
Code snippet component properties.
InlineCodeProps
Inline code component properties.
TerminalProps
Terminal component properties.