ArcaneDivider class
A horizontal divider component
Use style presets for cleaner code:
ArcaneDivider(
style: DividerStyle.subtle,
)
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneDivider
Constructors
- ArcaneDivider({double? margin, DividerStyle? style, String? label, bool dashed = false, Key? key})
-
const
- ArcaneDivider.bold({double? margin, String? label, bool dashed = false, Key? key})
-
Bold divider
const
- ArcaneDivider.standard({double? margin, String? label, bool dashed = false, Key? key})
-
Standard divider
const
- ArcaneDivider.subtle({double? margin, String? label, bool dashed = false, Key? key})
-
Subtle divider
const
Properties
- dashed → bool
-
Whether to use a dashed style
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
Optional label in the middle
final
- margin → double?
-
Vertical margin
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → DividerStyle?
-
Style preset
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited