ArcaneEmptyState class

Empty state placeholder component displaying a message when there's no content.

Inheritance

Constructors

ArcaneEmptyState({required String title, Widget? icon, String? description, Widget? action, Widget? secondaryAction, EmptyStateStyle style = EmptyStateStyle.centered, EmptyStateSize size = EmptyStateSize.md, Key? key})
const
ArcaneEmptyState.error({String title = 'Something went wrong', String? description = 'An error occurred while loading the content.', Widget? action, Widget? secondaryAction, EmptyStateStyle style = EmptyStateStyle.centered, EmptyStateSize size = EmptyStateSize.md, Key? key})
ArcaneEmptyState.noData({String title = 'No data yet', String? description = 'Start by adding your first item.', Widget? action, Widget? secondaryAction, EmptyStateStyle style = EmptyStateStyle.centered, EmptyStateSize size = EmptyStateSize.md, Key? key})
ArcaneEmptyState.noResults({String title = 'No results found', String? description = 'Try adjusting your search or filter criteria.', Widget? action, Widget? secondaryAction, EmptyStateStyle style = EmptyStateStyle.centered, EmptyStateSize size = EmptyStateSize.md, Key? key})
ArcaneEmptyState.offline({String title = 'You\'re offline', String? description = 'Check your internet connection and try again.', Widget? action, Widget? secondaryAction, EmptyStateStyle style = EmptyStateStyle.centered, EmptyStateSize size = EmptyStateSize.md, Key? key})

Properties

action Widget?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryAction Widget?
final
size EmptyStateSize
final
style EmptyStateStyle
final
title String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited