Accordion class

An accordion component (multiple expanders where only one can be open)

Inheritance

Constructors

Accordion({required List<AccordionItem> items, int? initialOpenIndex, bool allowMultiple = false, double gap = 0, Key? key})
const

Properties

allowMultiple bool
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
initialOpenIndex int?
final
items List<AccordionItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<Accordion>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited