IconCard class

A simple icon card for feature grids

Inheritance

Constructors

IconCard({required String title, required Component icon, String? subtitle, void onTap()?, String? href, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
href String?
Optional link
final
icon Component
Icon component
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onTap → void Function()?
Click handler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
Optional subtitle
final
title String
The card title
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final