ArcaneHoverCard.hovercard constructor

const ArcaneHoverCard.hovercard({
  1. required Component trigger,
  2. required Component content,
  3. FloatingPosition position = FloatingPosition.top,
  4. bool showArrow = true,
  5. int offset = 8,
  6. int openDelay = 200,
  7. int closeDelay = 300,
  8. bool? isOpen,
  9. void onOpenChange(
    1. bool isOpen
    )?,
  10. Key? key,
})

Creates a hover-triggered card with smart delays.

Best for preview cards that show additional info on hover, like user profile previews or link previews.

Implementation

const ArcaneHoverCard.hovercard({
  required this.trigger,
  required Component this.content,
  this.position = FloatingPosition.top,
  this.showArrow = true,
  this.offset = 8,
  this.openDelay = 200,
  this.closeDelay = 300,
  this.isOpen,
  this.onOpenChange,
  super.key,
})  : textContent = null,
      triggerType = FloatingTrigger.hover,
      maxWidth = null,
      closeOnOutsideClick = true,
      closeOnEscape = true;