ArcaneGameTile class

A game tile component for game server selection.

Inheritance

Constructors

ArcaneGameTile({required String name, String? iconUrl, Component? icon, bool selected = false, void onTap()?, bool popular = false, String? badge, String? subtitle, Key? key})
const

Properties

badge String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
iconUrl String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
name String
final
onTap → void Function()?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
subtitle String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited