GameCard class

A game card with more details

Inheritance

Constructors

GameCard({required String name, String? description, String? iconUrl, Component? icon, String? backgroundUrl, String? status, List<String>? features, void onTap()?, String? ctaText, Key? key})
const

Properties

backgroundUrl String?
Background image URL
final
ctaText String?
CTA button text
final
description String?
Game description
final
features List<String>?
Features list
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
Custom icon
final
iconUrl String?
Icon URL
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
name String
Game name
final
onTap → void Function()?
Click handler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
Player count or status
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final