Glass class

A glassmorphism container component.

Creates a frosted glass effect using CSS backdrop-filter.

Inheritance

Constructors

Glass({required Component child, double blur = 12.0, double opacity = 0.7, EdgeInsets? padding, double? radius, bool border = true, Key? key})
const

Properties

blur double
Blur amount
final
border bool
Whether to show a border
final
child Component
The child component
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
opacity double
Opacity of the glass surface
final
padding EdgeInsets?
Custom padding
final
radius double?
Border radius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited