GlassCard class

A glass card with standard card styling

Inheritance

Constructors

GlassCard({required Component child, double blur = 12.0, double opacity = 0.7, EdgeInsets? padding, double? radius, bool border = true, void onTap()?, Key? key})
const

Properties

blur double
final
border bool
final
child Component
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onTap → void Function()?
final
opacity double
final
padding EdgeInsets?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final