component/view/gradient_text library

Classes

AnimatedGradientTextProps
Animated gradient text component properties.
ArcaneAnimatedGradientText
Animated gradient text with color shift.
ArcaneGlowText
Glow text effect.
ArcaneGradientText
Text with gradient color.
ArcaneOutlineText
Outline text effect.
GlowTextProps
Glow text component properties.
GradientBuilder
Builds a CSS linear-gradient from a list of colors.
GradientStop
A color stop in a gradient, supporting both ArcaneColor and raw CSS values.
GradientTextProps
Gradient text component properties.
OutlineTextProps
Outline text component properties.

Enums

ArcaneColor
Semantic color values that map to theme CSS custom properties.

Extensions

ArcaneColorGradient on List<ArcaneColor>
Extension for creating gradients from a list of ArcaneColors.