GlowText class

Glow text effect

Inheritance

Constructors

GlowText({required String content, String? glowColor, String fontSize = '32px', String fontWeight = '700', double intensity = 1.0, Key? key})
const

Properties

content String
Text content
final
fontSize String
Font size
final
fontWeight String
Font weight
final
glowColor String?
Glow color
final
hashCode int
The hash code for this object.
no setterinherited
intensity double
Glow intensity
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited