GradientText class

Text with gradient color

Inheritance

Constructors

GradientText({required String content, String gradientStart = '#10B981', String gradientEnd = '#06B6D4', String? gradientAngle = '135deg', String fontSize = '32px', String fontWeight = '700'})
const

Properties

content String
final
fontSize String
final
fontWeight String
final
gradientAngle String?
final
gradientEnd String
final
gradientStart String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited