OutlineText class

Outline text effect

Inheritance

Constructors

OutlineText({required String content, String? strokeColor, String? fillColor, String fontSize = '32px', String fontWeight = '700', double strokeWidth = 2, Key? key})
const

Properties

content String
Text content
final
fillColor String?
Fill color (null for transparent)
final
fontSize String
Font size
final
fontWeight String
Font weight
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor String?
Stroke color
final
strokeWidth double
Stroke width
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited