IconSize enum

Icon size presets for consistent sizing.

Inheritance
Available extensions

Values

xs → const IconSize
sm → const IconSize
md → const IconSize
lg → const IconSize
xl → const IconSize
xl2 → const IconSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pixels double

Available on IconSize, provided by the IconSizeExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IconSize>
A constant List of the values in this enum, in order of their declaration.