Image class

Inheritance

Constructors

Image({required String src, required String alt, double? width, double? height, bool fillWidth = false, bool cover = false, Key? key})
const
Image.network(String src, {required String alt, double? width, double? height, bool fillWidth = false, bool cover = false, Key? key})
const

Properties

alt String
final
cover bool
final
fillWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited