IntegrationCard class
An integration/partner card (Supabase-style)
- Inheritance
-
- Object
- Component
- StatelessComponent
- IntegrationCard
Constructors
Properties
- category → String?
-
Category/tag
final
- description → String?
-
Description
final
- featured → bool
-
Whether it's featured
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
Link URL
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- logo → Component?
-
Custom logo component
final
- logoUrl → String?
-
Logo image URL
final
- name → String
-
Integration name
final
- onTap → void Function()?
-
Click handler
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited