ArcaneKbd class

Keyboard shortcut display component.

Inheritance

Constructors

ArcaneKbd(String? keyText, {KbdStyle style = KbdStyle.raised, ComponentSize size = ComponentSize.md, Key? key})
const
ArcaneKbd.combo(List<String>? keys, {String separator = '+', KbdStyle style = KbdStyle.raised, ComponentSize size = ComponentSize.md, Key? key})
const
ArcaneKbd.shortcut(String shortcut, {KbdStyle style = KbdStyle.raised, ComponentSize size = ComponentSize.md})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
keys List<String>?
final
keyText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator String
final
size ComponentSize
final
style KbdStyle
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited