icon property
Brand artwork may be a composed logo, wordmark, or image rather than one
semantic UI glyph. This is intentionally the only public Widget icon
slot in the curated component surface.
Implementation
final Widget? icon;
Brand artwork may be a composed logo, wordmark, or image rather than one
semantic UI glyph. This is intentionally the only public Widget icon
slot in the curated component surface.
final Widget? icon;