MapStyle class

Style configuration for ArcaneMap.

Supports both CSS variables (for theme integration) and explicit hex colors. By default, uses CSS variables that work with ShadCN and Codex stylesheets.

Constructors

MapStyle({String backgroundColor = 'var(--arcane-map-background, var(--card))', String regionFill = 'var(--arcane-map-region, var(--muted))', String regionStroke = 'var(--arcane-map-stroke, var(--border))', String strokeWidth = '0.5', String regionHoverFill = 'var(--arcane-map-region-hover, var(--accent))', String regionActiveFill = 'var(--arcane-map-region-active, var(--primary))', String pinColor = 'var(--arcane-map-pin, var(--primary))', String pinHoverColor = 'var(--arcane-map-pin-hover, var(--primary))', String pinActiveColor = 'var(--arcane-map-pin-active, var(--success, #22c55e))', double pinSize = 6, double pinGlowIntensity = 0.18, String pinGlowColor = 'var(--arcane-map-pin-glow, var(--primary))', String tooltipBackground = 'var(--arcane-map-tooltip-bg, var(--popover))', String tooltipBorder = 'var(--arcane-map-tooltip-border, var(--border))', String tooltipTextColor = 'var(--arcane-map-tooltip-text, var(--popover-foreground))', String tooltipSecondaryColor = 'var(--arcane-map-tooltip-secondary, var(--muted-foreground))'})
const

Properties

backgroundColor String
Background/ocean color.
final
hashCode int
The hash code for this object.
no setterinherited
pinActiveColor String
Pin color when active.
final
pinColor String
Default pin color.
final
pinGlowColor String
Pin highlight color.
final
pinGlowIntensity double
Pin highlight intensity (0.0 to 1.0).
final
pinHoverColor String
Pin color on hover.
final
pinSize double
Pin size in SVG units.
final
regionActiveFill String
Fill color for active/selected regions.
final
regionFill String
Default fill color for regions (land/states).
final
regionHoverFill String
Fill color when hovering over a region.
final
regionStroke String
Stroke color for region borders.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth String
Stroke width for region borders.
final
tooltipBackground String
Tooltip background color.
final
tooltipBorder String
Tooltip border color.
final
tooltipSecondaryColor String
Tooltip secondary/muted text color.
final
tooltipTextColor String
Tooltip primary text color.
final

Methods

copyWith({String? backgroundColor, String? regionFill, String? regionStroke, String? strokeWidth, String? regionHoverFill, String? regionActiveFill, String? pinColor, String? pinHoverColor, String? pinActiveColor, double? pinSize, double? pinGlowIntensity, String? pinGlowColor, String? tooltipBackground, String? tooltipBorder, String? tooltipTextColor, String? tooltipSecondaryColor}) MapStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dark → const MapStyle
Dark theme preset with explicit hex colors.
light → const MapStyle
Light theme preset with explicit hex colors.
prominent → const MapStyle
Prominent preset with thicker lines and larger pins.
subtle → const MapStyle
Subtle preset with thinner lines and smaller pins.
themed → const MapStyle
Default theme-aware preset (uses CSS variables).