ArcaneUSAMapPaths class

SVG path data for US states.

Contains all state paths from SimpleMaps us.svg. MIT licensed for commercial use.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

stateCodes List<String>
Get all state codes.
no setter

Static Methods

getStateName(String code) String?
Get state name by code.
getStatePath(String code) String?
Get state path by code.

Constants

states → const Map<String, (String, String)>
All state paths as a map of state code to (name, path).