ArcaneWorldMapPaths class

SVG path data for the world map.

Contains all country/region paths from SimpleMaps world.svg. MIT licensed.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

allPaths → const List<String>
All country/region paths (642 total).