ArcaneMeter class

Progress meter/gauge component displaying a value within a range.

Inheritance

Constructors

ArcaneMeter({required double value, double min = 0, double max = 100, double? low, double? high, double? optimum, String? label, bool showValue = true, String? valueSuffix, MeterStyle style = MeterStyle.bar, MeterColor color = MeterColor.primary, MeterSize size = MeterSize.md, int segments = 10, Key? key})
const
ArcaneMeter.battery({required double value, String? label, bool showValue = true, MeterSize size = MeterSize.md, Key? key})
const
ArcaneMeter.storage({required double value, double max = 100, String? label = 'Storage', bool showValue = true, MeterSize size = MeterSize.md, Key? key})
const

Properties

color MeterColor
final
hashCode int
The hash code for this object.
no setterinherited
high double?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
low double?
final
max double
final
min double
final
optimum double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments int
final
showValue bool
final
size MeterSize
final
style MeterStyle
final
value double
final
valueSuffix String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited