PricingGrid class

A pricing grid for displaying multiple tiers

Inheritance

Constructors

PricingGrid({required List<PricingTier> tiers, void onTierSelected(PricingTier tier)?, int? columns, Key? key})
const

Properties

columns int?
Number of columns (auto-calculated if null)
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onTierSelected → void Function(PricingTier tier)?
Callback when a tier's CTA is pressed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiers List<PricingTier>
The pricing tiers to display
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited