ArcaneProgressBar class

Progress bar component with various styles.

Inheritance

Constructors

ArcaneProgressBar({required double value, ComponentSize size = ComponentSize.md, ProgressVariant variant = ProgressVariant.primary, bool indeterminate = false, bool showValue = false, String? trackColor, String? indicatorColor, Key? key})
const
ArcaneProgressBar.error({required double value, ComponentSize size = ComponentSize.md, bool showValue = false, Key? key})
const
ArcaneProgressBar.standard({required double value, ComponentSize size = ComponentSize.md, bool showValue = false, Key? key})
const
ArcaneProgressBar.success({required double value, ComponentSize size = ComponentSize.md, bool showValue = false, Key? key})
const
ArcaneProgressBar.warning({required double value, ComponentSize size = ComponentSize.md, bool showValue = false, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
indeterminate bool
final
indicatorColor String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValue bool
final
size ComponentSize
final
trackColor String?
final
value double
final
variant ProgressVariant
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited