Skeleton class

Skeleton loading placeholder component

Inheritance

Constructors

Skeleton({String? width, String? height, String? borderRadius, bool circle = false, Key? key})
const
Skeleton.circle({String? height, Key? key})
Circle skeleton
const
Skeleton.line({String? width, Key? key})
Text line skeleton
const

Properties

borderRadius String?
final
circle bool
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final