ArcaneSlotCounter class
A slot-machine style animated counter that spins through random values.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneSlotCounter
Constructors
- ArcaneSlotCounter({int minValue = 0, int maxValue = 9999, int? fixedValue, String? prefix, String? suffix, String? label, int spinDurationMs = 1500, int spinIntervalMs = 50, int basePauseSeconds = 4, int randomPauseSeconds = 5, bool autoStart = true, SlotCounterSize valueSize = SlotCounterSize.xl, SlotCounterSize affixSize = SlotCounterSize.sm, SlotCounterSize labelSize = SlotCounterSize.xs, SlotCounterColor valueColor = SlotCounterColor.accent, SlotCounterColor affixColor = SlotCounterColor.muted, SlotCounterColor labelColor = SlotCounterColor.muted, bool valueBold = true, bool monospace = true, int? minDigits, void onValueChange(int value)?, Key? key})
-
const
- ArcaneSlotCounter.currency({int minValue = 0, int maxValue = 10000, String currencySymbol = '\$', String? label, SlotCounterSize valueSize = SlotCounterSize.xl, SlotCounterColor valueColor = SlotCounterColor.accent, Key? key})
-
factory
- ArcaneSlotCounter.latency({int minLatency = 5, int maxLatency = 150, String? label, SlotCounterSize valueSize = SlotCounterSize.lg, SlotCounterColor valueColor = SlotCounterColor.accent, bool autoStart = true, Key? key})
-
factory
- ArcaneSlotCounter.percentage({int minValue = 0, int maxValue = 100, String? label, SlotCounterSize valueSize = SlotCounterSize.xl, SlotCounterColor valueColor = SlotCounterColor.accent, Key? key})
-
factory
Properties
- affixColor → SlotCounterColor
-
final
- affixSize → SlotCounterSize
-
final
- autoStart → bool
-
final
- basePauseSeconds → int
-
final
- fixedValue → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- labelColor → SlotCounterColor
-
final
- labelSize → SlotCounterSize
-
final
- maxValue → int
-
final
- minDigits → int?
-
final
- minValue → int
-
final
- monospace → bool
-
final
- onValueChange → void Function(int value)?
-
final
- prefix → String?
-
final
- randomPauseSeconds → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spinDurationMs → int
-
final
- spinIntervalMs → int
-
final
- suffix → String?
-
final
- valueBold → bool
-
final
- valueColor → SlotCounterColor
-
final
- valueSize → SlotCounterSize
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited