ArcaneSocialIcon class

Social media icon link

Inheritance

Constructors

ArcaneSocialIcon({required SocialPlatform platform, String? url, String size = '24px', String? color, bool showBackground = true, Key? key})
const
ArcaneSocialIcon.discord({String? url, String size = '24px', String? color, bool showBackground = true, Key? key})
Named constructor for Discord
const
ArcaneSocialIcon.github({String? url, String size = '24px', String? color, bool showBackground = true, Key? key})
Named constructor for GitHub
const
ArcaneSocialIcon.linkedin({String? url, String size = '24px', String? color, bool showBackground = true, Key? key})
Named constructor for LinkedIn
const
ArcaneSocialIcon.twitter({String? url, String size = '24px', String? color, bool showBackground = true, Key? key})
Named constructor for Twitter/X
const
ArcaneSocialIcon.youtube({String? url, String size = '24px', String? color, bool showBackground = true, Key? key})
Named constructor for YouTube
const

Properties

color String?
Custom color
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
platform SocialPlatform
Platform to display
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBackground bool
Whether to show background
final
size String
Icon size
final
url String?
Link URL (optional)
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final