ArcaneSpecRow class
A specification row displaying a label-value pair.
Commonly used in pricing cards for displaying specifications like RAM, storage, CPU, etc.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneSpecRow
Constructors
- ArcaneSpecRow({required String label, required String value, bool highlight = false, String? labelColor, String? valueColor, String? fontSize, Key? key})
-
const
- ArcaneSpecRow.highlight({required String label, required String value, String? labelColor, String? valueColor, String? fontSize, Key? key})
-
Creates a highlighted spec row (value uses primary color).
const
Properties
- fontSize → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight → bool
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String
-
final
- labelColor → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
- valueColor → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited