StatCard class

Stat card for displaying metrics with optional trend indicator

Inheritance

Constructors

StatCard({required String label, required String value, String? icon, String? trend, bool trendPositive = true, String? description, String? iconBackground, Key? key})
const

Properties

description String?
Additional description
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
Optional icon
final
iconBackground String?
Custom icon background
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
Label text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trend String?
Trend value (e.g., "+12.5%")
final
trendPositive bool
Whether the trend is positive
final
value String
Value to display
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited