ArcaneStatDisplay class

A metric/stat display with large value and label.

Inheritance

Constructors

ArcaneStatDisplay({required String value, required String label, StatDisplayLayout layout = StatDisplayLayout.vertical, String? valueColor, String? labelColor, String? valueFontSize, String? labelFontSize, String? textAlign, Key? key})
const
ArcaneStatDisplay.accent({required String value, required String label, StatDisplayLayout layout = StatDisplayLayout.vertical, String? labelColor, String? valueFontSize, String? labelFontSize, String? textAlign, Key? key})
const
ArcaneStatDisplay.brand({required String value, required String label, StatDisplayLayout layout = StatDisplayLayout.vertical, String? labelColor, String? valueFontSize, String? labelFontSize, String? textAlign, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
final
labelColor String?
final
labelFontSize String?
final
layout StatDisplayLayout
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlign String?
final
value String
final
valueColor String?
final
valueFontSize String?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited