KeyValueRow class

A row for KeyValueTable

Constructors

KeyValueRow({required String key, required Component value})
const
KeyValueRow.text(String key, String value)
Create from a string value
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Component
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited