StatusBadge class
Status badge combining status indicator with text
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatusBadge
Constructors
- StatusBadge({required StatusType status, required String label, Key? key})
-
const
- StatusBadge.error({required String label, Key? key})
-
Error status badge
const
- StatusBadge.info({required String label, Key? key})
-
Info status badge
const
- StatusBadge.success({required String label, Key? key})
-
Success status badge
const
- StatusBadge.warning({required String label, Key? key})
-
Warning status badge
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → StatusType
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited