StatusIndicator class

Status indicator dot with optional label

Inheritance

Constructors

StatusIndicator({required StatusType status, String? label, String? size, bool pulse = false, Key? key})
const
StatusIndicator.away({String? label, String? size, Key? key})
Away status
const
StatusIndicator.busy({String? label, String? size, Key? key})
Busy status
const
StatusIndicator.offline({String? label, String? size, Key? key})
Offline status
const
StatusIndicator.online({String? label, String? size, bool pulse = true, Key? key})
Online status
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
pulse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String?
final
status StatusType
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited