ArcaneSteps class

A numbered steps component for showing progress through a process.

Inheritance

Constructors

ArcaneSteps({required List<ArcaneStepItem> items, StepsLayout layout = StepsLayout.horizontal, StepsSize size = StepsSize.md, bool showConnectors = true, int? currentStep, void onStepTap(int index)?, Key? key})
const
ArcaneSteps.horizontal({required List<ArcaneStepItem> items, StepsSize size = StepsSize.md, bool showConnectors = true, int? currentStep, void onStepTap(int index)?, Key? key})
const
ArcaneSteps.vertical({required List<ArcaneStepItem> items, StepsSize size = StepsSize.md, bool showConnectors = true, int? currentStep, void onStepTap(int index)?, Key? key})
const

Properties

currentStep int?
final
hashCode int
The hash code for this object.
no setterinherited
items List<ArcaneStepItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
layout StepsLayout
final
onStepTap → void Function(int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showConnectors bool
final
size StepsSize
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited