StepItem class

Step item data

Constructors

StepItem({required String title, String? description, bool completed = false, bool active = false})
const

Properties

active bool
Whether this is the active step
final
completed bool
Whether this step is completed
final
description String?
Step description
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Step title
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited