Stepper class

Horizontal stepper for multi-step processes

Inheritance

Constructors

Stepper({required List<StepItem> steps, String? activeColor, String? completedColor, String? inactiveColor, Key? key})
const

Properties

activeColor String?
Color for active step
final
completedColor String?
Color for completed step
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor String?
Color for inactive step
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<StepItem>
Steps to display
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited