component/view/switcher library

Classes

ArcaneIndexedStack
An indexed stack that preserves state of all children.
ArcaneKeyedSwitcher<T>
A keyed switcher that uses keys to determine which child to show.
ArcaneSwitcher
Animated content switcher that transitions between children.
IndexedStackProps
Indexed stack component properties.
SwitcherProps
Switcher component properties.