ArcaneKeyedSwitcher<T> class

A keyed switcher that uses keys to determine which child to show.

Inheritance

Constructors

ArcaneKeyedSwitcher({required T currentKey, required Map<T, Component> children, SwitcherDirection direction = SwitcherDirection.fade, int duration = 300, Component? fallback, Key? key})
const

Properties

children Map<T, Component>
final
currentKey → T
final
direction SwitcherDirection
final
duration int
final
fallback Component?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited