ArcaneSwitcher class

Animated content switcher that transitions between children.

Inheritance

Constructors

ArcaneSwitcher({required int index, required List<Component> children, SwitcherDirection direction = SwitcherDirection.fade, int duration = 300, void onIndexChanged(int)?, Key? key})
const
ArcaneSwitcher.fade({required int index, required List<Component> children, int duration = 300, void onIndexChanged(int)?, Key? key})
const
ArcaneSwitcher.horizontal({required int index, required List<Component> children, int duration = 300, void onIndexChanged(int)?, Key? key})
const
ArcaneSwitcher.vertical({required int index, required List<Component> children, int duration = 300, void onIndexChanged(int)?, Key? key})
const

Properties

children List<Component>
final
direction SwitcherDirection
final
duration int
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onIndexChanged → void Function(int)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited