RatingStars class

Rating stars component

Inheritance

Constructors

RatingStars({required double rating, int maxStars = 5, double size = 16, bool interactive = false, void onRatingChanged(int)?, Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
interactive bool
Whether the rating is interactive
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxStars int
Maximum stars
final
onRatingChanged → void Function(int)?
Callback when rating changes (for interactive mode)
final
rating double
Rating value (0-5)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
Star size
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited