Tile class

Inheritance

Constructors

Tile({Widget? title, Widget? subtitle, Widget? leading, Widget? trailing, String? titleText, String? subtitleText, void onPressed()?, String? href, bool selected = false, bool disabled = false, Key? key})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
leading Widget?
final
onPressed → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
subtitle Widget?
final
subtitleText String?
final
title Widget?
final
titleText String?
final
trailing Widget?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited