Timeline class

Timeline component for showing progression or history

Inheritance

Constructors

Timeline({required List<TimelineItem> items, String lineColor = '#3F3F46', String activeColor = '#10B981'})
const

Properties

activeColor String
final
hashCode int
The hash code for this object.
no setterinherited
items List<TimelineItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
lineColor String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited