ArcaneInteraction class abstract

Constructors

ArcaneInteraction()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(ArcaneInteraction next) ArcaneInteraction
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

activateTab(String groupId, String tabId) ArcaneInteraction
calendarNext(String calendarId) ArcaneInteraction
calendarPrev(String calendarId) ArcaneInteraction
calendarSelect(String calendarId, String iso) ArcaneInteraction
calendarToday(String calendarId) ArcaneInteraction
carouselGoTo(String groupId, int index) ArcaneInteraction
carouselNext(String groupId) ArcaneInteraction
carouselPrev(String groupId) ArcaneInteraction
clearValue(String groupId) ArcaneInteraction
closeCommand([String? id]) ArcaneInteraction
closeContextMenu([String? id]) ArcaneInteraction
closeDialog([String? id]) ArcaneInteraction
closeDrawer([String? id]) ArcaneInteraction
closeMenu([String? id]) ArcaneInteraction
closeMobileMenu([String? id]) ArcaneInteraction
closePopover([String? id]) ArcaneInteraction
closeSheet([String? id]) ArcaneInteraction
closeTooltip([String? id]) ArcaneInteraction
collapsePanel(String groupId, String panelId) ArcaneInteraction
compose(List<ArcaneInteraction> actions) ArcaneInteraction
copy(String text, {String? feedback}) ArcaneInteraction
cycleNext(String groupId) ArcaneInteraction
cyclePrev(String groupId) ArcaneInteraction
dispatch(String eventName, {Map<String, String> detail = const <String, String>{}}) ArcaneInteraction
expandPanel(String groupId, String panelId) ArcaneInteraction
goToPage(String groupId, int page) ArcaneInteraction
goToStep(String groupId, int step) ArcaneInteraction
nextPage(String groupId) ArcaneInteraction
nextStep(String groupId) ArcaneInteraction
openCommand(String id) ArcaneInteraction
openContextMenu(String id) ArcaneInteraction
openDialog(String id) ArcaneInteraction
openDrawer(String id) ArcaneInteraction
openMenu(String id) ArcaneInteraction
openMobileMenu(String id) ArcaneInteraction
openPopover(String id) ArcaneInteraction
openSheet(String id) ArcaneInteraction
openTooltip(String id) ArcaneInteraction
prevPage(String groupId) ArcaneInteraction
prevStep(String groupId) ArcaneInteraction
resetForm(String formId) ArcaneInteraction
script(String fnName, [List<String> args = const <String>[]]) ArcaneInteraction
selectValue(String groupId, String value) ArcaneInteraction
setField(String formId, String field, String value) ArcaneInteraction
setPalette(String stylesheetId, String paletteId) ArcaneInteraction
setSlider(String sliderId, double value, [String role = 'value']) ArcaneInteraction
setStylesheet(String id) ArcaneInteraction
setThemeMode(String mode) ArcaneInteraction
showToast(String message, {String variant = 'info', int? durationMs, String? title}) ArcaneInteraction
submitForm(String formId) ArcaneInteraction
toggleCommand(String id) ArcaneInteraction
toggleDialog(String id) ArcaneInteraction
toggleDrawer(String id) ArcaneInteraction
toggleMenu(String id) ArcaneInteraction
toggleMobileMenu(String id) ArcaneInteraction
togglePanel(String groupId, String panelId) ArcaneInteraction
togglePopover(String id) ArcaneInteraction
toggleSheet(String id) ArcaneInteraction
toggleValue(String groupId, String value) ArcaneInteraction