AccordionItemProps class

Accordion item data.

Constructors

AccordionItemProps({required String title, String content = '', Component? customContent, String? category, String? accentColor})
const

Properties

accentColor String?
Optional accent color for category badge and chevron (CSS color value).
final
category String?
Optional category label (displayed as badge).
final
content String
final
customContent Component?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited