AccordionProps class

Accordion component properties.

Constructors

AccordionProps({required List<AccordionItemProps> items, required Set<int> openItems, void onToggle(int index)?, bool allowMultiple = false, bool bordered = false})
const

Properties

allowMultiple bool
final
bordered bool
final
hashCode int
The hash code for this object.
no setterinherited
items List<AccordionItemProps>
final
onToggle → void Function(int index)?
final
openItems Set<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<AccordionItemProps>? items, Set<int>? openItems, void onToggle(int index)?, bool? allowMultiple, bool? bordered}) AccordionProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited