AuthLayoutProps class

Auth layout component properties.

Constructors

AuthLayoutProps({required Widget child, Widget? header, Widget? footer, bool showGrid = true, bool showGlows = true, String primaryGlowColor = 'color-mix(in srgb, var(--accent) 15%, transparent)', String secondaryGlowColor = 'color-mix(in srgb, var(--info) 15%, transparent)', String gridColor = 'color-mix(in srgb, var(--border) 30%, transparent)', String maxWidth = '420px', String backgroundColor = 'var(--background)'})
const

Properties

backgroundColor String
final
child Widget
final
final
gridColor String
final
hashCode int
The hash code for this object.
no setterinherited
final
maxWidth String
final
primaryGlowColor String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryGlowColor String
final
showGlows bool
final
showGrid bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited