AuthSplitLayoutProps class

Auth split layout component properties.

Constructors

AuthSplitLayoutProps({required Widget brandingContent, required Widget formContent, Widget? mobileHeader, bool reverseSides = false})
const

Properties

brandingContent Widget
final
formContent Widget
final
hashCode int
The hash code for this object.
no setterinherited
mobileHeader Widget?
final
reverseSides bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited