BadgeProps class

Badge component properties.

Constructors

BadgeProps({required String label, Component? icon, BadgeVariant variant = BadgeVariant.standard, BadgeSize size = BadgeSize.medium})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size BadgeSize
final
variant BadgeVariant
final

Methods

copyWith({String? label, Component? icon, BadgeVariant? variant, BadgeSize? size}) BadgeProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited