DialogBarProps class

Dialog bar component properties.

Constructors

DialogBarProps({String? title, void onClose()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onClose → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited