BottomNavigationBarProps class

Bottom navigation bar component properties.

Constructors

BottomNavigationBarProps({required List<BottomNavItem> items, required int selectedIndex, void onChanged(int index)?, bool showLabels = true, bool showSelectedLabels = false, double height = 64})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
final
items List<BottomNavItem>
final
onChanged → void Function(int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex int
final
showLabels bool
final
showSelectedLabels bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited