ButtonPanelRendererContract mixin

Mixin defining the renderer methods for button panel components.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buttonGroup(ButtonGroupProps props) Widget
buttonPanel(ButtonPanelProps props) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toolbar(ToolbarProps props) Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited