href property
If provided, renders the button as an anchor tag (<a>) instead of <button>.
Useful for CTA buttons that navigate to other pages.
Implementation
final String? href;
If provided, renders the button as an anchor tag (<a>) instead of <button>.
Useful for CTA buttons that navigate to other pages.
final String? href;