showArrow property
Whether to show an arrow indicator after the label. Useful for CTA buttons to indicate navigation.
Implementation
final bool showArrow;
Whether to show an arrow indicator after the label. Useful for CTA buttons to indicate navigation.
final bool showArrow;