CardSectionProps class

Card section component properties.

Constructors

CardSectionProps({String? header, Component? headerComponent, required List<Component> children, String? padding, String? radius, String? gap, List<Component>? trailing})
const

Properties

children List<Component>
final
gap String?
final
hashCode int
The hash code for this object.
no setterinherited
final
headerComponent Component?
final
padding String?
final
radius String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing List<Component>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited