ArcaneDividerProps class

Arcane divider component properties.

Constructors

ArcaneDividerProps({double? thickness, double? indent, double? endIndent, String? color, bool vertical = false})
const

Properties

color String?
final
endIndent double?
final
hashCode int
The hash code for this object.
no setterinherited
indent double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thickness double?
final
vertical bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited