SurfaceProps class

Surface component properties.

Constructors

SurfaceProps({required Component child, EdgeInsets? padding, double? radius, int elevation = 1, String? color, bool border = true})
const

Properties

border bool
final
child Component
final
color String?
final
elevation int
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited