ChartProps class

Constructors

ChartProps({required List<ChartPointProps> points, String? title, String? description, String color = 'var(--primary)'})
const

Properties

color String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
points List<ChartPointProps>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

copyWith({List<ChartPointProps>? points, String? title, String? description, String? color}) ChartProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited