CheckboxProps class
Checkbox component properties.
Constructors
- CheckboxProps({required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, ColorVariant color = ColorVariant.primary, bool disabled = false, void onChanged(bool)?})
-
const
Properties
- checked → bool
-
final
- color → ColorVariant
-
final
- description → String?
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- onChanged → void Function(bool)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ComponentSize
-
final
Methods
-
copyWith(
{bool? checked, String? label, String? description, ComponentSize? size, ColorVariant? color, bool? disabled, void onChanged(bool)?}) → CheckboxProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited