ChipProps class

Chip component properties.

Constructors

ChipProps({required String label, Widget? icon, ColorVariant color = ColorVariant.secondary, StyleVariant style = StyleVariant.solid, ComponentSize size = ComponentSize.md, bool removable = false, void onRemove()?, void onTap()?})
const

Properties

color ColorVariant
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
label String
final
onRemove → void Function()?
final
onTap → void Function()?
final
removable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
style StyleVariant
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited