ChipRendererContract mixin

Mixin defining the renderer methods for chip components.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chip(ChipProps props) Widget
Renders a chip component.
chipGroup(ChipGroupProps props) Widget
Renders a group of chips.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited