CodeSnippetRendererContract mixin
Mixin defining the renderer methods for code snippet components.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
codeSnippet(
CodeSnippetProps props) → Component -
inlineCode(
InlineCodeProps props) → Component -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
terminal(
TerminalProps props) → Component -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited