CodeWindowProps class
Code window component properties.
Constructors
- CodeWindowProps({required String code, String? title, CodeWindowStyle style = CodeWindowStyle.dark, bool showButtons = true, String? codeColor, String? headerBackground, String? bodyBackground})
-
const
Properties
- bodyBackground → String?
-
final
- code → String
-
final
- codeColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackground → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showButtons → bool
-
final
- style → CodeWindowStyle
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited