CommandGroupProps class

Command group data.

Constructors

CommandGroupProps({String? heading, required List<CommandItemProps> items})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
heading String?
final
items List<CommandItemProps>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited