href property
Optional href for JavaScript-based navigation. When set, clicking the item will navigate to this URL. Use '_blank' target by setting hrefTarget.
Implementation
final String? href;
Optional href for JavaScript-based navigation. When set, clicking the item will navigate to this URL. Use '_blank' target by setting hrefTarget.
final String? href;