ConfirmDialogProps class
Confirm dialog component properties.
Constructors
Properties
- cancelText → String
-
final
- confirmText → String
-
final
- destructive → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- message → String
-
final
- onCancel → void Function()?
-
final
- onConfirm → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited