CycleButtonRendererContract mixin

Mixin defining the renderer methods for cycle button and toggle button components.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cycleButton<T>(CycleButtonProps<T> props) Widget
Render a cycle button component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toggleButton(ToggleButtonProps props) Widget
Render a toggle button component.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited