ToggleButtonProps class

Toggle button component properties.

Constructors

ToggleButtonProps({required bool value, void onChanged(bool value)?, String? label, Component? icon, CycleButtonSize size = CycleButtonSize.medium, bool disabled = false, String? id, Map<String, String>? attributes})
const

Properties

attributes Map<String, String>?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
id String?
final
label String?
final
onChanged → void Function(bool value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size CycleButtonSize
final
value bool
final

Methods

copyWith({bool? value, void onChanged(bool value)?, String? label, Component? icon, CycleButtonSize? size, bool? disabled, String? id, Map<String, String>? attributes}) ToggleButtonProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited