DashboardLayoutProps class

Dashboard layout component properties.

Constructors

DashboardLayoutProps({required Component child, required String currentRoute, required List<DashboardNavGroup> navigation, Component? sidebarHeader, Component? sidebarFooter, Component? topBar, String sidebarWidth = '256px', String backgroundColor = 'var(--background)', String sidebarBackgroundColor = 'var(--card)'})
const

Properties

backgroundColor String
final
child Component
final
currentRoute String
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sidebarBackgroundColor String
final
sidebarFooter Component?
final
sidebarHeader Component?
final
sidebarWidth String
final
topBar Component?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited