DashboardTopBarProps class

Dashboard top bar component properties.

Constructors

DashboardTopBarProps({Widget? leading, Widget? trailing, String backgroundColor = 'var(--card)'})
const

Properties

backgroundColor String
final
hashCode int
The hash code for this object.
no setterinherited
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited