DataTableProps<T> class

Data table component properties.

Constructors

DataTableProps({required List<T> items, required List<DataColumnProps<T>> columns, void onRowTap(T item)?, bool selectable = false, Set<T> selectedItems = const {}, bool showDividers = true, bool showHeader = true, bool stickyHeader = false, String emptyMessage = 'No data available', void onToggleSelection(T item)?, void onToggleSelectAll()?})
const

Properties

columns List<DataColumnProps<T>>
final
emptyMessage String
final
hashCode int
The hash code for this object.
no setterinherited
items List<T>
final
onRowTap → void Function(T item)?
final
onToggleSelectAll → void Function()?
final
onToggleSelection → void Function(T item)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool
final
selectedItems Set<T>
final
showDividers bool
final
showHeader bool
final
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited