DatePickerProps class
Date picker component properties.
Constructors
- DatePickerProps({DateTime? value, String? label, String? placeholder, DateTime? minDate, DateTime? maxDate, bool disabled = false, String? error, bool clearable = true, DatePickerSizeVariant size = DatePickerSizeVariant.md, CalendarModeVariant mode = CalendarModeVariant.single, DateRangeValue? rangeValue, bool isOpen = false, String displayText = 'Select date...', void onToggle()?, void onSelect(DateTime date)?, void onRangeSelect(DateRangeValue range)?, void onClear()?, CalendarProps? calendarProps})
-
const
Properties
- calendarProps → CalendarProps?
-
final
- clearable → bool
-
final
- disabled → bool
-
final
- displayText → String
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
final
- label → String?
-
final
- maxDate → DateTime?
-
final
- minDate → DateTime?
-
final
- mode → CalendarModeVariant
-
final
- onClear → void Function()?
-
final
- onRangeSelect → void Function(DateRangeValue range)?
-
final
- onSelect → void Function(DateTime date)?
-
final
- onToggle → void Function()?
-
final
- placeholder → String?
-
final
- rangeValue → DateRangeValue?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → DatePickerSizeVariant
-
final
- value → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited