DirectionProps class

Constructors

DirectionProps({required List<Widget> children, DirectionValue value = DirectionValue.ltr, String? classes})
const

Properties

children List<Widget>
final
classes String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DirectionValue
final

Methods

copyWith({DirectionValue? value, List<Widget>? children, String? classes}) DirectionProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited