DisclosureGroupProps class

Disclosure group component properties.

Constructors

DisclosureGroupProps({required List<DisclosureItemProps> items, String gap = '0.5rem', DisclosureVariant variant = DisclosureVariant.default_, int? initialOpenIndex})
const

Properties

gap String
final
hashCode int
The hash code for this object.
no setterinherited
initialOpenIndex int?
final
items List<DisclosureItemProps>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant DisclosureVariant
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited