DisclosureItemProps class

Disclosure item data.

Constructors

DisclosureItemProps({required Widget summary, required Widget content, bool showChevron = true})
const

Properties

content Widget
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showChevron bool
final
summary Widget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited