DrawerProps class

Drawer component properties.

Constructors

DrawerProps({required bool isOpen, required Widget child, void onClose()?, DrawerPosition position = DrawerPosition.right, DrawerSize size = DrawerSize.md, Widget? header, Widget? footer, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showCloseButton = true, String? width, String? height})
const

Properties

child Widget
final
closeOnBackdropClick bool
final
final
hashCode int
The hash code for this object.
no setterinherited
final
height String?
final
isOpen bool
final
onClose → void Function()?
final
position DrawerPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBackdrop bool
final
showCloseButton bool
final
size DrawerSize
final
width String?
final

Methods

copyWith({bool? isOpen, void onClose()?, DrawerPosition? position, DrawerSize? size, Widget? child, Widget? header, Widget? footer, bool? showBackdrop, bool? closeOnBackdropClick, bool? showCloseButton, String? width, String? height}) DrawerProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited