DropdownMenuProps class

Dropdown menu component properties.

Constructors

const

Properties

alignment DropdownAlignment
final
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
final
items List<ArcaneMenuItem>
final
onClose → void Function()?
final
onToggle → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger Widget
final
width double?
final

Methods

copyWith({Widget? trigger, List<ArcaneMenuItem>? items, bool? isOpen, void onToggle()?, void onClose()?, DropdownAlignment? alignment, double? width}) DropdownMenuProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited