FABProps class

FAB (Floating Action Button) component properties.

Constructors

FABProps({required Widget icon, String? label, void onPressed()?, ColorVariant color = ColorVariant.primary, ComponentSize size = ComponentSize.md, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, String? id, Map<String, String>? attributes})
const

Properties

attributes Map<String, String>?
final
color ColorVariant
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
final
id String?
final
label String?
final
onPressed → void Function()?
final
position FABPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
tooltip String?
final

Methods

copyWith({Widget? icon, String? label, void onPressed()?, ColorVariant? color, ComponentSize? size, bool? disabled, FABPosition? position, String? tooltip, String? id, Map<String, String>? attributes}) FABProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited