IconCardProps class

Icon card component properties.

Constructors

IconCardProps({required String title, required Widget icon, String? subtitle, void onTap()?, String? href})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
href String?
final
icon Widget
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited