FeatureShowcaseItem class

Feature showcase item data.

Constructors

FeatureShowcaseItem({required Component icon, required String title, required String description, Component? header, Component? footer, void onTap()?, String? href})
const

Properties

description String
final
final
hashCode int
The hash code for this object.
no setterinherited
final
href String?
final
icon Component
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited