FormProps class

Form component properties.

Constructors

FormProps({required List<Widget> children, String? submitText = 'Submit', String? cancelText = 'Cancel', void onSubmit()?, void onCancel()?, bool showActions = true, double spacing = 16})
const

Properties

cancelText String?
final
children List<Widget>
final
hashCode int
The hash code for this object.
no setterinherited
onCancel → void Function()?
final
onSubmit → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showActions bool
final
spacing double
final
submitText String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited