FileUploadProps class

File upload component properties.

Constructors

FileUploadProps({required FileUploadStyle style, required FileUploadSize size, required bool isDragOver, required List<UploadedFile> selectedFiles, required bool disabled, required String dropzoneText, required String browseText, required String acceptString, required bool multiple, String? label, String? helperText, void onClick()?, void onDragOver(dynamic event)?, void onDragLeave(dynamic event)?, void onDrop(dynamic event)?, void onInputChange(dynamic event)?})
const

Properties

acceptString String
final
browseText String
final
disabled bool
final
dropzoneText String
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
isDragOver bool
final
label String?
final
multiple bool
final
onClick → void Function()?
final
onDragLeave → void Function(dynamic event)?
final
onDragOver → void Function(dynamic event)?
final
onDrop → void Function(dynamic event)?
final
onInputChange → void Function(dynamic event)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedFiles List<UploadedFile>
final
size FileUploadSize
final
style FileUploadStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited