FlexiCardItem class

Flexi card item data.

Constructors

FlexiCardItem({required Component icon, required String shortText, required String longText, Component? header, Component? footer, void onTap()?, String? href})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
final
href String?
final
icon Component
final
longText String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortText String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited