FlexiCardsProps class

FlexiCards component properties.

Constructors

FlexiCardsProps({required List<FlexiCardItem> items, double collapsedFlex = 1.0, double expandedFlex = 2.0, bool scaleHeight = false, double heightScaleFactor = 1.05, String gap = '1.5rem', String minCardWidth = '200px', int transitionDuration = 300, bool expandLongTextOnHover = true, String? heightPreLock, String? heightPostLock, String? widthPreLock, String? widthPostLock})
const

Properties

collapsedFlex double
final
expandedFlex double
final
expandLongTextOnHover bool
final
gap String
final
hashCode int
The hash code for this object.
no setterinherited
heightPostLock String?
final
heightPreLock String?
final
heightScaleFactor double
final
items List<FlexiCardItem>
final
minCardWidth String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleHeight bool
final
transitionDuration int
final
widthPostLock String?
final
widthPreLock String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited