FlowProps class

Flow layout component properties.

Constructors

FlowProps({required List<Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, WrapAlignment wrapAlignment = WrapAlignment.start, double gap = 8, double? rowGap, double? columnGap, bool reverse = false})
const

Properties

children List<Widget>
final
columnGap double?
final
crossAxisAlignment CrossAxisAlignment
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
mainAxisAlignment MainAxisAlignment
final
reverse bool
final
rowGap double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrapAlignment WrapAlignment
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited