RowProps class

Row layout component properties.

Constructors

RowProps({required List<Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisSize mainAxisSize = MainAxisSize.max, double gap = 0})
const

Properties

children List<Widget>
final
crossAxisAlignment CrossAxisAlignment
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
mainAxisAlignment MainAxisAlignment
final
mainAxisSize MainAxisSize
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited