FooterColumnProps class

Footer column component properties.

Constructors

FooterColumnProps({required String title, required List<FooterLink> links, String? titleColor, String? linkColor, String? linkGap})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
linkColor String?
final
linkGap String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
titleColor String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited