GameCardProps class

Game card component properties.

Constructors

GameCardProps({required String name, String? description, String? iconUrl, Component? icon, String? backgroundUrl, String? status, List<String>? features, void onTap()?, String? ctaText})
const

Properties

backgroundUrl String?
final
ctaText String?
final
description String?
final
features List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
iconUrl String?
final
name String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited