GlassCardProps class

Glass card component properties.

Constructors

GlassCardProps({required Widget child, double blur = 12.0, double opacity = 0.7, String? padding, String? radius, bool border = true, void onTap()?})
const

Properties

blur double
final
border bool
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
onTap → void Function()?
final
opacity double
final
padding String?
final
radius String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited