GradientGlassProps class

Gradient glass component properties.

Constructors

GradientGlassProps({required Widget child, double blur = 12.0, String? gradientStart, String? gradientEnd, double opacity = 0.2, String? padding, String? radius, String direction = 'to bottom right'})
const

Properties

blur double
final
child Widget
final
direction String
final
gradientEnd String?
final
gradientStart String?
final
hashCode int
The hash code for this object.
no setterinherited
opacity double
final
padding String?
final
radius String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited