AnimatedGradientTextProps class
Animated gradient text component properties.
Constructors
- AnimatedGradientTextProps({required String content, String fontSize = '32px', String fontWeight = '700'})
-
const
Properties
- content → String
-
final
- fontSize → String
-
final
- fontWeight → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited