GlowTextProps class

Glow text component properties.

Constructors

GlowTextProps({required String content, String? glowColor, String fontSize = '32px', String fontWeight = '700', double intensity = 1.0})
const

Properties

content String
final
fontSize String
final
fontWeight String
final
glowColor String?
final
hashCode int
The hash code for this object.
no setterinherited
intensity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited