GradientTextProps class

Gradient text component properties.

Constructors

GradientTextProps({required String content, String? gradient, String? gradientStart, String? gradientEnd, String? gradientAngle, List<GradientStop>? colorStops, String fontSize = 'inherit', String fontWeight = 'inherit'})
const

Properties

colorStops List<GradientStop>?
List of color stops for multi-color gradients.
final
content String
final
fontSize String
final
fontWeight String
final
gradient String?
Full CSS gradient string. Takes precedence over other gradient properties.
final
gradientAngle String?
Gradient angle (e.g., '135deg', 'to right').
final
gradientEnd String?
End color (for simple two-color gradients).
final
gradientStart String?
Start color (for simple two-color gradients).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildGradient() String
Builds the CSS gradient string from the properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited