OutlineTextProps class

Outline text component properties.

Constructors

OutlineTextProps({required String content, String? strokeColor, String? fillColor, String fontSize = '32px', String fontWeight = '700', double strokeWidth = 2})
const

Properties

content String
final
fillColor String?
final
fontSize String
final
fontWeight String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor String?
final
strokeWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited