HeaderProps class

Header/navbar component properties.

Constructors

HeaderProps({List<NavItemProps> navItems = const [], Widget? customNav, List<Widget>? actions, bool showSearch = false, String searchPlaceholder = 'Search...', void onSearch(String)?, bool sticky = true, bool transparent = false, bool bordered = true, double? height})
const

Properties

actions List<Widget>?
final
bordered bool
final
customNav Widget?
Custom navigation content (takes precedence over navItems if provided). Use this to pass complex navigation components like dropdowns.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Header height in pixels. Defaults to 72 for Codex, 64 for Shadcn.
final
final
Simple navigation items (rendered by the header renderer).
final
onSearch → void Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholder String
final
showSearch bool
final
sticky bool
final
transparent bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited