InputDialogProps class

Input dialog component properties.

Constructors

InputDialogProps({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, InputDialogType type = InputDialogType.text, int? maxLength, int maxLines = 1, bool requireWorkEmail = false, List<String>? blockedDomains, num? minValue, num? maxValue})
const

Properties

blockedDomains List<String>?
final
cancelText String
final
confirmText String
final
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
final
maxLength int?
final
maxLines int
final
maxValue num?
final
message String?
final
minValue num?
final
onCancel → void Function()?
final
onConfirm → void Function(String value)?
final
placeholder String
final
requireWorkEmail bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
type InputDialogType
final
validator String? Function(String value)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited