IntegrationCardProps class

Integration card component properties.

Constructors

IntegrationCardProps({required String name, String? description, String? logoUrl, String? href, void onTap()?, String? category, bool featured = false})
const

Properties

category String?
final
description String?
final
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
final
logoUrl String?
final
name String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited