IntegrationGridProps class

Integration grid component properties.

Constructors

IntegrationGridProps({required List<IntegrationCardProps> integrations, int columns = 3, double gap = 24, String? title, String? description})
const

Properties

columns int
final
description String?
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
integrations List<IntegrationCardProps>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited