ItemProps class

Constructors

ItemProps({required Widget child, String? href, bool external = false, ArcaneStyleData? styles, String? classes})
const

Properties

child Widget
final
classes String?
final
external bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles ArcaneStyleData?
final

Methods

copyWith({Widget? child, String? href, bool? external, ArcaneStyleData? styles, String? classes}) ItemProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited