KbdProps class

Keyboard shortcut display component properties.

Constructors

KbdProps({String? keyText, List<String>? keys, String separator = '+', KbdStyle style = KbdStyle.raised, ComponentSize size = ComponentSize.md})
const
KbdProps.combo(List<String> keys, {String separator = '+', KbdStyle style = KbdStyle.raised, ComponentSize size = ComponentSize.md})
const
KbdProps.key(String key, {KbdStyle style = KbdStyle.raised, ComponentSize size = ComponentSize.md})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keys List<String>?
final
keyText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator String
final
size ComponentSize
final
style KbdStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited