LoaderProps class
Loader component properties.
Constructors
- LoaderProps({LoaderVariant variant = LoaderVariant.spinner, String size = '32px', String? color, String strokeWidth = '3px', String dotSize = '8px'})
-
const
- LoaderProps.dots({String? color, String dotSize = '8px'})
-
const
- LoaderProps.pulse({String size = '40px', String? color})
-
const
- LoaderProps.spinner({String size = '32px', String? color, String strokeWidth = '3px'})
-
const
Properties
- color → String?
-
final
- dotSize → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → String
-
final
- strokeWidth → String
-
final
- variant → LoaderVariant
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited