LogoCarouselProps class

Logo carousel component properties.

Constructors

LogoCarouselProps({required List<LogoItem> logos, int duration = 30, double logoHeight = 40, double gap = 48, bool pauseOnHover = true, bool reverse = false, bool grayscale = true, String? title})
const

Properties

duration int
final
gap double
final
grayscale bool
final
hashCode int
The hash code for this object.
no setterinherited
logoHeight double
final
logos List<LogoItem>
final
pauseOnHover bool
final
reverse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited