MapRegionConfig class

Region configuration for map section grouping and coloring.

Not to be confused with MapRegion from map_data.dart which represents SVG path data for rendering states/countries.

Constructors

MapRegionConfig({required String name, required String color})
const

Properties

color String
CSS color for region markers and accents.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Display name of the region.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited