MarqueeProps class

Marquee component properties.

Constructors

MarqueeProps({required List<Widget> children, String duration = '30s', MarqueeDirection direction = MarqueeDirection.left, String? gap, bool showFadeEdges = true, String? fadeWidth, String? fadeColor, bool pauseOnHover = true, String? id})
const

Properties

children List<Widget>
final
direction MarqueeDirection
final
duration String
final
fadeColor String?
final
fadeWidth String?
final
gap String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
pauseOnHover bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showFadeEdges bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited