MenuItemAction class

Standard clickable menu item.

Inheritance

Constructors

const

Properties

description String?
final
destructive bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
icon Widget?
final
label String
final
onSelect → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcut String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited