MenuItemRadio class
Radio menu item (part of a group).
- Inheritance
-
- Object
- ArcaneMenuItem
- MenuItemRadio
Constructors
Properties
- disabled → bool
-
final
- group → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- label → String
-
final
- onChanged → void Function(String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited