MenubarProps class
Menubar component properties.
Constructors
- MenubarProps({int? openMenuIndex, void onMenuChange(int? index)?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- onMenuChange → void Function(int? index)?
-
final
- openMenuIndex → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited