MeterProps class

Meter/gauge component properties.

Constructors

MeterProps({required double value, double min = 0, double max = 100, double? low, double? high, double? optimum, String? label, bool showValue = true, String? valueSuffix, MeterStyleVariant style = MeterStyleVariant.bar, MeterColorVariant color = MeterColorVariant.primary, MeterSizeVariant size = MeterSizeVariant.md, int segments = 10})
const

Properties

color MeterColorVariant
final
hashCode int
The hash code for this object.
no setterinherited
high double?
final
label String?
final
low double?
final
max double
final
min double
final
optimum double?
final
percentage double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments int
final
showValue bool
final
size MeterSizeVariant
final
style MeterStyleVariant
final
value double
final
valueSuffix String?
final

Methods

copyWith({double? value, double? min, double? max, double? low, double? high, double? optimum, String? label, bool? showValue, String? valueSuffix, MeterStyleVariant? style, MeterColorVariant? color, MeterSizeVariant? size, int? segments}) MeterProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited