HamburgerButtonProps class

Hamburger button component properties.

Constructors

HamburgerButtonProps({bool isOpen = false, void onTap()?, double size = 24})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isOpen bool
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited