MobileMenuProps class

Mobile menu component properties.

Constructors

MobileMenuProps({required String id, required List<MobileNavItem> items, Widget? cta, void onClose()?, bool isOpen = false, bool escapeCloses = true, bool focusTrap = true, bool restoreFocus = true})
const

Properties

cta Widget?
final
escapeCloses bool
final
focusTrap bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isOpen bool
final
items List<MobileNavItem>
final
final
onClose → void Function()?
final
restoreFocus bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited