NativeSelectProps class

Constructors

NativeSelectProps({required List<NativeSelectOptionProps> options, String? value, String? placeholder, ComponentSize size = ComponentSize.md, bool disabled = false, bool required = false, String? name, String? id, String? label, String? error, bool fullWidth = false, void onChange(String)?})
const

Properties

disabled bool
final
error String?
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
label String?
final
name String?
final
onChange → void Function(String)?
final
options List<NativeSelectOptionProps>
final
placeholder String?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
value String?
final

Methods

copyWith({List<NativeSelectOptionProps>? options, String? value, String? placeholder, ComponentSize? size, bool? disabled, bool? required, String? name, String? id, String? label, String? error, bool? fullWidth, void onChange(String)?}) NativeSelectProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited