NumberInputProps class

Number input component properties.

Constructors

NumberInputProps({required num value, num min = 0, num max = 100, num step = 1, void onChanged(num)?, ComponentSize size = ComponentSize.md, bool disabled = false, String? label, String? prefix, String? suffix, int decimals = 0, String? id, Map<String, String>? attributes})
const

Properties

attributes Map<String, String>?
final
decimals int
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
label String?
final
max num
final
min num
final
onChanged → void Function(num)?
final
prefix String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
step num
final
suffix String?
final
value num
final

Methods

copyWith({num? value, num? min, num? max, num? step, void onChanged(num)?, ComponentSize? size, bool? disabled, String? label, String? prefix, String? suffix, int? decimals, String? id, Map<String, String>? attributes}) NumberInputProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited