PricingCardProps class
Pricing card component properties.
Constructors
- PricingCardProps({required PricingTier tier, void onCtaPressed()?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCtaPressed → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tier → PricingTier
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited