PricingGridProps class

Pricing grid component properties.

Constructors

PricingGridProps({required List<PricingTier> tiers, void onTierSelected(PricingTier tier)?, int? columns})
const

Properties

columns int?
final
hashCode int
The hash code for this object.
no setterinherited
onTierSelected → void Function(PricingTier tier)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiers List<PricingTier>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited