PricingTier class

Pricing tier data.

Constructors

PricingTier({required String name, double? price, String period = 'month', String currency = '\$', required String description, required List<String> features, String ctaText = 'Get Started', bool isPopular = false, bool isHighlighted = false})
const

Properties

ctaText String
final
currency String
final
description String
final
features List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isHighlighted bool
final
isPopular bool
final
name String
final
period String
final
price double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited