ProgressProps class

Progress bar component properties.

Constructors

ProgressProps({double value = 0.0, ProgressSize size = ProgressSize.medium, ProgressVariant variant = ProgressVariant.primary, bool indeterminate = false, bool showValue = false, String? trackColor, String? indicatorColor})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
indeterminate bool
final
indicatorColor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showValue bool
final
size ProgressSize
final
trackColor String?
final
value double
final
variant ProgressVariant
final

Methods

copyWith({double? value, ProgressSize? size, ProgressVariant? variant, bool? indeterminate, bool? showValue, String? trackColor, String? indicatorColor}) ProgressProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited