InlineHeroBannerProps class

Props for the inline hero banner.

An inline promotional banner that integrates with the hero section. Can be displayed as a badge, ribbon, pill, or card style.

Constructors

InlineHeroBannerProps({required String message, String? promoCode, String? ctaText, String? ctaHref, void onCtaClick()?, void onDismiss()?, PromoInlineHeroBannerStyle style = PromoInlineHeroBannerStyle.pill, bool dismissible = true, Widget? icon})
const

Properties

ctaHref String?
CTA button URL.
final
ctaText String?
CTA button text.
final
dismissible bool
Whether the banner can be dismissed.
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
Optional icon to display.
final
message String
Banner message.
final
onCtaClick → void Function()?
Callback when CTA is clicked.
final
onDismiss → void Function()?
Callback when dismissed.
final
promoCode String?
Optional promo code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style PromoInlineHeroBannerStyle
Visual style variant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited