PromoRendererContract mixin

Mixin defining the renderer methods for promo components.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bottomFloatingBanner(BottomFloatingBannerProps props) Widget
Render a bottom floating banner component.
cornerPromoToast(CornerPromoToastProps props) Widget
Render a corner promo toast component.
expandingFabPromo(ExpandingFabPromoProps props) Widget
Render an expanding FAB promo component.
fullscreenTakeover(FullscreenTakeoverProps props) Widget
Render a fullscreen takeover component.
inlineHeroBanner(InlineHeroBannerProps props) Widget
Render an inline hero banner component.
marqueeTickerBar(MarqueeTickerBarProps props) Widget
Render a marquee ticker bar component.
minimizablePromo(MinimizablePromoProps props) Widget
Render a minimizable promo component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
progressClaimBanner(ProgressClaimBannerProps props) Widget
Render a progress claim banner component.
promoModal(PromoModalProps props) Widget
Render a promo modal component.
slidingSidebarBanner(SlidingSidebarBannerProps props) Widget
Render a sliding sidebar banner component.
topAnnouncementBar(TopAnnouncementBarProps props) Widget
Render a top announcement bar component.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited