RadioCardItemData<T> class

Radio card item data.

Constructors

RadioCardItemData({required T value, String? title, String? subtitle, Widget? icon, Widget? child, bool disabled = false})
const

Properties

child Widget?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String?
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited