RadioCardsProps<T> class

Radio cards component properties.

Constructors

RadioCardsProps({required List<RadioCardItemData<T>> items, T? value, void onChanged(T value)?, double gap = 12, bool wrap = true, double? cardWidth})
const

Properties

cardWidth double?
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
items List<RadioCardItemData<T>>
final
onChanged → void Function(T value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final
wrap bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited