SelectableChipGroupProps class

Selectable chip group component properties.

Constructors

SelectableChipGroupProps({required List<Component> children, double gap = 8, bool wrap = true})
const

Properties

children List<Component>
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrap bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited