ResizablePanelData class

Resizable panel data.

Constructors

ResizablePanelData({required Widget child, double? defaultSize, double? minSize, double? maxSize, bool collapsible = false})
const

Properties

child Widget
final
collapsible bool
final
defaultSize double?
final
hashCode int
The hash code for this object.
no setterinherited
maxSize double?
final
minSize double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited