ArcaneScaffoldProps class

Constructors

ArcaneScaffoldProps({String? title, Widget? navigation, Widget? actions, Widget? sidebar, required Widget body, Widget? secondary, Widget? footer, Widget? floatingAction})
const

Properties

actions Widget?
final
body Widget
final
floatingAction Widget?
final
final
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Widget?
final
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited