ScrollAreaProps class

Scroll area component properties.

Constructors

ScrollAreaProps({required Component child, String? height, String? width, String? maxHeight, String? maxWidth, ScrollDirectionVariant direction = ScrollDirectionVariant.vertical, ScrollbarVisibilityVariant scrollbar = ScrollbarVisibilityVariant.hover, ScrollbarStyleVariant scrollbarStyle = ScrollbarStyleVariant.thin, String? trackColor, String? thumbColor, String scrollbarSize = '8px', bool showScrollShadows = false, String? padding, String? className, int instanceId = 0})
const

Properties

child Component
final
className String?
final
direction ScrollDirectionVariant
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
instanceId int
final
maxHeight String?
final
maxWidth String?
final
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollbar ScrollbarVisibilityVariant
final
scrollbarSize String
final
scrollbarStyle ScrollbarStyleVariant
final
showScrollShadows bool
final
thumbColor String?
final
trackColor String?
final
width String?
final

Methods

copyWith({Component? child, String? height, String? width, String? maxHeight, String? maxWidth, ScrollDirectionVariant? direction, ScrollbarVisibilityVariant? scrollbar, ScrollbarStyleVariant? scrollbarStyle, String? trackColor, String? thumbColor, String? scrollbarSize, bool? showScrollShadows, String? padding, String? className, int? instanceId}) ScrollAreaProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited