VirtualScrollProps<T> class

Virtual scroll component properties.

Constructors

VirtualScrollProps({required List<T> items, required Widget itemBuilder(BuildContext context, T item, int index), required double itemHeight, required String height, int overscan = 3, double scrollTop = 0, void onScroll(double)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height String
final
itemBuilder Widget Function(BuildContext context, T item, int index)
final
itemHeight double
final
items List<T>
final
onScroll → void Function(double)?
final
overscan int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollTop double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited