ScrollRailLayoutProps class

Scroll rail layout component properties.

Constructors

ScrollRailLayoutProps({required Widget rail, required Widget child, ScrollRailPosition railPosition = ScrollRailPosition.left, ScrollRailSize railSize = ScrollRailSize.md, String? railWidth, String headerHeight = '0px', bool showBorder = true, String? railBackground, String? contentBackground})
const

Properties

child Widget
final
contentBackground String?
final
hashCode int
The hash code for this object.
no setterinherited
headerHeight String
final
rail Widget
final
railBackground String?
final
railPosition ScrollRailPosition
final
railSize ScrollRailSize
final
railWidth String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBorder bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited