ScrollRailProps class

Scroll rail component properties.

Constructors

ScrollRailProps({required List<Widget> children, ScrollRailPosition position = ScrollRailPosition.left, ScrollRailSize size = ScrollRailSize.md, String? width, String topOffset = '0px', String bottomOffset = '0px', bool showBorder = true, String? background, String padding = '1rem', bool customScrollbar = true, String? scrollPersistenceId})
const

Properties

background String?
final
bottomOffset String
final
children List<Widget>
final
customScrollbar bool
final
hashCode int
The hash code for this object.
no setterinherited
padding String
final
position ScrollRailPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPersistenceId String?
final
showBorder bool
final
size ScrollRailSize
final
topOffset String
final
width String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited