SearchProps class

Search input component properties.

Constructors

SearchProps({String placeholder = 'Search...', String? value, void onChanged(String value)?, void onSubmitted(String value)?, bool showClear = true, bool showIcon = true, bool loading = false, Widget? icon, bool autofocus = false, bool disabled = false, ComponentSize size = ComponentSize.md, SearchStyle style = SearchStyle.standard, String? id, Map<String, String>? attributes, List<SearchResult>? results, String? resultsId, bool showDropdown = false, String? dropdownMaxHeight, String? width})
const

Properties

attributes Map<String, String>?
final
autofocus bool
final
disabled bool
final
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
id String?
final
loading bool
final
onChanged → void Function(String value)?
final
onSubmitted → void Function(String value)?
final
placeholder String
final
results List<SearchResult>?
final
resultsId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showClear bool
final
showDropdown bool
final
showIcon bool
final
size ComponentSize
final
style SearchStyle
final
value String?
final
width String?
final

Methods

copyWith({String? placeholder, String? value, void onChanged(String value)?, void onSubmitted(String value)?, bool? showClear, bool? showIcon, bool? loading, Widget? icon, bool? autofocus, bool? disabled, ComponentSize? size, SearchStyle? style, String? id, Map<String, String>? attributes, List<SearchResult>? results, String? resultsId, bool? showDropdown, String? dropdownMaxHeight, String? width}) SearchProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited