SectionHeaderProps class

Section header component properties.

Constructors

SectionHeaderProps({String? label, required String heading, String? description, SectionHeaderAlign align = SectionHeaderAlign.center, String? descriptionMaxWidth, String? marginBottom, String? labelColor, String? headingColor, String? descriptionColor})
const

Properties

align SectionHeaderAlign
final
description String?
final
descriptionColor String?
final
descriptionMaxWidth String?
final
hashCode int
The hash code for this object.
no setterinherited
heading String
final
headingColor String?
final
label String?
final
labelColor String?
final
marginBottom String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited