SectionProps class

Section component properties.

Constructors

SectionProps({String? header, Widget? headerComponent, required List<Widget> children, bool showDivider = false, String? padding, String? gap, bool card = false})
const

Properties

card bool
final
children List<Widget>
final
gap String?
final
hashCode int
The hash code for this object.
no setterinherited
final
headerComponent Widget?
final
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDivider bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited