SelectOptionProps<T> class

Select option data.

Constructors

SelectOptionProps({required T value, required String label, String? subtitle, String? description, Widget? icon, bool disabled = false, List<String>? searchKeywords})
const

Properties

description String?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchKeywords List<String>?
final
subtitle String?
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited