SelectProps<T> class

Select component properties.

Constructors

SelectProps({required List<SelectOptionProps<T>> options, T? value, List<T>? values, String placeholder = 'Select...', bool disabled = false, bool clearable = false, bool searchable = false, bool multiSelect = false, String? label, String? helperText, String? error, SelectSize size = SelectSize.md, bool required = false, String? maxDropdownHeight, bool loading = false, String loadingText = 'Loading...', String emptyMessage = 'No options found', String searchPlaceholder = 'Search...', SelectDropdownDirection dropdownDirection = SelectDropdownDirection.down, bool closeOnSelect = true, bool showSelectedCount = true, Component? prefix, int? maxSelections, bool showCheckboxes = true, bool isOpen = false, String searchQuery = '', List<SelectOptionProps<T>> filteredOptions = const [], void onToggle()?, void onSelect(T value)?, void onClear()?, void onSearchChange(String query)?})
const

Properties

clearable bool
final
closeOnSelect bool
final
disabled bool
final
final
emptyMessage String
final
error String?
final
filteredOptions List<SelectOptionProps<T>>
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
isOpen bool
final
label String?
final
loading bool
final
loadingText String
final
maxDropdownHeight String?
final
maxSelections int?
final
multiSelect bool
final
onClear → void Function()?
final
onSearchChange → void Function(String query)?
final
onSelect → void Function(T value)?
final
onToggle → void Function()?
final
options List<SelectOptionProps<T>>
final
placeholder String
final
prefix Component?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool
final
searchPlaceholder String
final
searchQuery String
final
showCheckboxes bool
final
showSelectedCount bool
final
size SelectSize
final
value → T?
final
values List<T>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited