SettingsInfoRowProps class

Settings info row component properties.

Constructors

SettingsInfoRowProps({required String label, required String value, bool monospace = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
monospace bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited