SettingsSectionProps class

Settings section component properties.

Constructors

SettingsSectionProps({required String title, String? description, required List<Widget> children, bool danger = false})
const

Properties

children List<Widget>
final
danger bool
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited