SettingsSectionRendererContract mixin

Mixin defining the renderer methods for settings section components.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
settingsInfoRow(SettingsInfoRowProps props) Widget
settingsNote(SettingsNoteProps props) Widget
settingsSection(SettingsSectionProps props) Widget
settingsSubheader(SettingsSubheaderProps props) Widget
settingsToggleRow(SettingsToggleRowProps props) Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited