SettingsToggleRowProps class

Settings toggle row component properties.

Constructors

SettingsToggleRowProps({required String title, String? description, required bool enabled, void onChanged(bool)?, bool disabled = false})
const

Properties

description String?
final
disabled bool
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
onChanged → void Function(bool)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited