CardMediaProps mixin

Mixin for components with icon or image media.

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Widget?
no setter
imageUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited