SidebarGroupProps class

Sidebar group component properties.

Constructors

SidebarGroupProps({String? label, required List<Widget> children, bool collapsed = false})
const

Properties

children List<Widget>
final
collapsed bool
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited