SidebarItemProps class

Sidebar item component properties.

Constructors

SidebarItemProps({required String label, Widget? icon, void onTap()?, String? href, bool selected = false, bool disabled = false, String? badge, bool collapsed = false, String? tooltip})
const

Properties

badge String?
final
collapsed bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
icon Widget?
final
label String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
tooltip String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited