SkeletonProps class

Skeleton component properties.

Constructors

SkeletonProps({String? width, String? height, String? borderRadius, SkeletonShape shape = SkeletonShape.rectangle, bool animate = true})
const

Properties

animate bool
final
borderRadius String?
final
hashCode int
The hash code for this object.
no setterinherited
height String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape SkeletonShape
final
width String?
final

Methods

copyWith({String? width, String? height, String? borderRadius, SkeletonShape? shape, bool? animate}) SkeletonProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited