SliderProps class

Slider component properties.

Constructors

SliderProps({double value = 0, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, SliderVariant variant = SliderVariant.primary, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onChanged(double)?, bool isRange = false, double? rangeMin, double? rangeMax, void onRangeChanged(double min, double max)?})
const
SliderProps.range({required double minValue, required double maxValue, double min = 0, double max = 100, double? step, String? label, bool showValue = true, String? valuePrefix, String? valueSuffix, int valueDecimals = 0, SliderVariant variant = SliderVariant.primary, ComponentSize size = ComponentSize.md, bool showSteps = false, bool disabled = false, void onRangeChanged(double min, double max)?})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
isRange bool
final
label String?
final
max double
final
min double
final
onChanged → void Function(double)?
final
onRangeChanged → void Function(double min, double max)?
final
rangeMax double?
final
rangeMin double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSteps bool
final
showValue bool
final
size ComponentSize
final
step double?
final
value double
final
valueDecimals int
final
valuePrefix String?
final
valueSuffix String?
final
variant SliderVariant
final

Methods

copyWith({double? value, double? min, double? max, double? step, String? label, bool? showValue, String? valuePrefix, String? valueSuffix, int? valueDecimals, SliderVariant? variant, ComponentSize? size, bool? showSteps, bool? disabled, void onChanged(double)?, bool? isRange, double? rangeMin, double? rangeMax, void onRangeChanged(double min, double max)?}) SliderProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited