SlotCounterCardProps class

Slot counter card component properties.

Constructors

SlotCounterCardProps({required SlotCounterProps counter, String padding = '1rem', String borderRadius = '0.375rem', bool showBorder = false, bool showBackground = false})
const

Properties

borderRadius String
final
counter SlotCounterProps
final
hashCode int
The hash code for this object.
no setterinherited
padding String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBackground bool
final
showBorder bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited