StatCardRowProps class

Stat card row component properties.

Constructors

StatCardRowProps({required List<Widget> cards, int columns = 4, String? gap})
const

Properties

cards List<Widget>
final
columns int
final
gap String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited