StatDisplayProps class

Stat display component properties.

Constructors

StatDisplayProps({required String value, required String label, StatDisplayLayout layout = StatDisplayLayout.vertical, String? valueColor, String? labelColor, String? valueFontSize, String? labelFontSize, String? textAlign})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
labelColor String?
final
labelFontSize String?
final
layout StatDisplayLayout
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlign String?
final
value String
final
valueColor String?
final
valueFontSize String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited