StatRowProps class

Stat row component properties.

Constructors

StatRowProps({required List<Widget> stats, String? gap, bool wrap = true, String? justifyContent})
const

Properties

gap String?
final
hashCode int
The hash code for this object.
no setterinherited
justifyContent String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats List<Widget>
final
wrap bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited