BadgePosition class

Position configuration for absolutely positioned badges.

Constructors

BadgePosition({String? top, String? right, String? bottom, String? left})
const
BadgePosition.topLeft({String? top = '12px', String? right, String? bottom, String? left = '12px'})
Top-left corner positioning.
const
BadgePosition.topRight({String? top = '12px', String? right = '12px', String? bottom, String? left})
Top-right corner positioning (common for card badges).
const

Properties

bottom String?
final
hashCode int
The hash code for this object.
no setterinherited
left String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited