StepItemData class

Step item data.

Constructors

StepItemData({required String title, String? description, StepStatus status = StepStatus.pending, Component? content})
const

Properties

content Component?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StepStatus
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited