ThumbHashCardProps class

ThumbHash card component properties.

Constructors

ThumbHashCardProps({required String hash, required Widget child, String? borderRadius, String? padding, double overlayOpacity = 0.3})
const

Properties

borderRadius String?
final
child Widget
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
overlayOpacity double
final
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited