TabItemProps class

Tab item data.

Constructors

TabItemProps({required String label, required Widget content, Widget? icon, String? badge, bool disabled = false})
const

Properties

badge String?
final
content Widget
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited