TabsRendererContract mixin
Mixin defining the renderer methods for tab components.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tabBar(
TabBarProps props) → Widget - Renders a standalone tab bar without content panels.
-
tabs(
TabsProps props) → Widget - Renders a tabbed interface with content panels.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited