RatingStarsSimpleProps class

Simple rating stars component properties.

Constructors

RatingStarsSimpleProps({required double rating, int maxStars = 5, double size = 16, bool interactive = false, void onRatingChanged(int)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
interactive bool
final
maxStars int
final
onRatingChanged → void Function(int)?
final
rating double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited