TestimonialCardProps class

Testimonial card component properties.

Constructors

TestimonialCardProps({required String quote, required String authorName, String? authorTitle, String? authorCompany, String? avatarUrl, int? rating, bool showQuotes = true, bool showRatingBadge = false, bool showAccentBorder = false, String? accentColor})
const

Properties

accentColor String?
Custom accent color override (CSS color value). If null and rating is provided, color is derived from rating.
final
authorCompany String?
final
authorName String
final
authorTitle String?
final
avatarUrl String?
final
effectiveAccentColor String
Returns the accent color based on rating (5=green, 4=cyan, 3=yellow, 2=orange, 1=red). Returns primary color if no rating or custom accent color is provided.
no setter
hashCode int
The hash code for this object.
no setterinherited
quote String
final
rating int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAccentBorder bool
Whether to show a colored accent border at the top based on rating.
final
showQuotes bool
final
showRatingBadge bool
Whether to show the rating badge (e.g., "5/5") next to stars.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited