TextInputProps class

Text input component properties.

Constructors

TextInputProps({String? placeholder, TextInputType type = TextInputType.text, String? value, String? name, String? id, ComponentSize size = ComponentSize.md, TextInputVariant variant = TextInputVariant.outline, bool disabled = false, bool required = false, bool readOnly = false, bool fullWidth = false, String? label, String? helperText, String? error, Widget? prefix, Widget? suffix, void onChanged(String)?, void onFocus()?, void onBlur()?, void onSubmit(String)?})
const

Properties

disabled bool
final
error String?
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
id String?
final
label String?
final
name String?
final
onBlur → void Function()?
final
onChanged → void Function(String)?
final
onFocus → void Function()?
final
onSubmit → void Function(String)?
final
placeholder String?
final
prefix Widget?
final
readOnly bool
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
suffix Widget?
final
type TextInputType
final
value String?
final
variant TextInputVariant
final

Methods

copyWith({String? placeholder, TextInputType? type, String? value, String? name, String? id, ComponentSize? size, TextInputVariant? variant, bool? disabled, bool? required, bool? readOnly, bool? fullWidth, String? label, String? helperText, String? error, Widget? prefix, Widget? suffix, void onChanged(String)?, void onFocus()?, void onBlur()?, void onSubmit(String)?}) TextInputProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited