NavTileProps class

Navigation tile component properties.

Constructors

const

Properties

badge String?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
label String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited