TileProps class

Tile component properties.

Constructors

TileProps({String? title, Widget? titleWidget, String? subtitle, Widget? subtitleWidget, Widget? leading, Widget? trailing, bool selected = false, bool disabled = false, bool dense = false, void onTap()?, String? padding})
const

Properties

dense bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
leading Widget?
final
onTap → void Function()?
final
padding String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
subtitle String?
final
subtitleWidget Widget?
final
title String?
final
titleWidget Widget?
final
trailing Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited