TimeOfDay class

Represents a time of day with hour and minute.

Constructors

TimeOfDay({required int hour, required int minute})
const
TimeOfDay.fromDateTime(DateTime dateTime)
factory
TimeOfDay.now()
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
hour int
final
hourOfPeriod int
no setter
isPM bool
no setter
minute int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? hour, int? minute}) TimeOfDay
format({bool use24Hour = false}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override