TimelineItemData class
Timeline item data.
Constructors
- TimelineItemData({required String title, String? subtitle, String? description, String? date, Widget? icon, TimelineStatus status = TimelineStatus.default_, Widget? content})
-
const
Properties
- content → Widget?
-
final
- date → String?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TimelineStatus
-
final
- subtitle → String?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited