TimelineProps class

Timeline component properties.

Constructors

TimelineProps({required List<TimelineItemData> items, TimelineLayout layout = TimelineLayout.vertical, ComponentSize size = ComponentSize.md, bool showConnectors = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<TimelineItemData>
final
layout TimelineLayout
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showConnectors bool
final
size ComponentSize
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited