ToastProps class

Toast component properties.

Constructors

ToastProps({required String message, String? title, String? description, ToastVariant variant = ToastVariant.info, ToastPosition position = ToastPosition.bottomRight, int duration = 4000, bool dismissible = true, ToastAction? action, Widget? icon, String? id, bool isExiting = false, bool isHovered = false, void onMouseEnter()?, void onMouseLeave()?, void onDismiss()?})
const

Properties

action ToastAction?
final
description String?
final
dismissible bool
final
duration int
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
id String?
final
isExiting bool
final
isHovered bool
final
message String
final
onDismiss → void Function()?
final
onMouseEnter → void Function()?
final
onMouseLeave → void Function()?
final
position ToastPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
variant ToastVariant
final

Methods

copyWith({String? message, String? title, String? description, ToastVariant? variant, ToastPosition? position, int? duration, bool? dismissible, ToastAction? action, Widget? icon, String? id, bool? isExiting, bool? isHovered, void onMouseEnter()?, void onMouseLeave()?, void onDismiss()?}) ToastProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited