ToggleSwitchProps class

Toggle switch component properties.

Constructors

ToggleSwitchProps({required bool value, void onChanged(bool)?, bool disabled = false, ComponentSize size = ComponentSize.md, ColorVariant color = ColorVariant.primary, String? label, bool labelLeft = false})
const

Properties

color ColorVariant
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
labelLeft bool
final
onChanged → void Function(bool)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
value bool
final

Methods

copyWith({bool? value, void onChanged(bool)?, bool? disabled, ComponentSize? size, ColorVariant? color, String? label, bool? labelLeft}) ToggleSwitchProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited