TooltipProps class

Tooltip component properties.

Constructors

TooltipProps({required Component child, String? content, Component? customContent, TooltipPosition position = TooltipPosition.top, double maxWidth = 250})
const

Properties

child Component
final
content String?
final
customContent Component?
final
hashCode int
The hash code for this object.
no setterinherited
maxWidth double
final
position TooltipPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Component? child, String? content, Component? customContent, TooltipPosition? position, double? maxWidth}) TooltipProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited