TrackerData class

Tracker cell data.

Constructors

TrackerData({String? tooltip, required TrackerLevel level, double? value, String? label})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
final
level TrackerLevel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String?
final
value double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited