TrackerProps class

Tracker component properties.

Constructors

TrackerProps({required List<TrackerData> data, int columns = 12, int cellSize = 12, int gap = 3, bool showTooltips = true, bool showLegend = false, Map<TrackerLevel, String>? levelColors, void onCellTap(int index, TrackerData data)?})
const

Properties

cellSize int
final
columns int
final
data List<TrackerData>
final
gap int
final
hashCode int
The hash code for this object.
no setterinherited
levelColors Map<TrackerLevel, String>?
final
onCellTap → void Function(int index, TrackerData data)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLegend bool
final
showTooltips bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited