UptimeTrackerProps class

Uptime tracker component properties.

Constructors

UptimeTrackerProps({required List<UptimeDay> days, int barHeight = 32, int barWidth = 4, int gap = 2, bool showDates = false, bool showPercentage = true})
const

Properties

barHeight int
final
barWidth int
final
days List<UptimeDay>
final
gap int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDates bool
final
showPercentage bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited