ComponentRenderers class abstract

Mixed-in types
Implementers

Constructors

ComponentRenderers()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accordion(AccordionProps props) Widget
Renders an accordion with collapsible sections.
inherited
alert(AlertProps props) Widget
Renders an alert notification component.
inherited
alertDialog(AlertDialogProps props) Widget
inherited
aspectRatio(AspectRatioProps props) Widget
inherited
avatar(AvatarProps props) Component
Renders an avatar component.
inherited
bottomFloatingBanner(BottomFloatingBannerProps props) Widget
Render a bottom floating banner component.
inherited
Renders a breadcrumb navigation trail.
inherited
button(ButtonProps props) Widget
Render a button component.
inherited
buttonGroup(ButtonGroupProps props) Widget
inherited
buttonPanel(ButtonPanelProps props) Widget
inherited
calendar(CalendarProps props) Component
inherited
card(CardProps props) Widget
Renders a card container component.
inherited
center(CenterProps props) Widget
inherited
chart(ChartProps props) Component
inherited
checkbox(CheckboxProps props) Component
Render a checkbox component.
inherited
checkItem(CheckItemProps props) Component
inherited
checkList(CheckListProps props) Component
inherited
circularProgress(CircularProgressProps props) Component
Renders a circular progress indicator component.
inherited
column(ColumnProps props) Widget
inherited
command(CommandProps props) Widget
inherited
confirmDialog(ConfirmDialogProps props) Widget
inherited
contextMenu(ContextMenuProps props) Widget
inherited
cornerPromoToast(CornerPromoToastProps props) Widget
Render a corner promo toast component.
inherited
cycleButton<T>(CycleButtonProps<T> props) Widget
Render a cycle button component.
inherited
dataTable<T>(DataTableProps<T> props) Widget
inherited
datePicker(DatePickerProps props) Component
inherited
dialog(DialogProps props) Widget
inherited
direction(DirectionProps props) Widget
inherited
disclosure(DisclosureProps props) Widget
inherited
disclosureGroup(DisclosureGroupProps props) Widget
inherited
drawer(DrawerProps props) Widget
inherited
inherited
emptyState(EmptyStateProps props) Widget
Renders an empty state placeholder component.
inherited
expanded(ExpandedProps props) Widget
inherited
expandingFabPromo(ExpandingFabPromoProps props) Widget
Render an expanding FAB promo component.
inherited
fadeEdge(FadeEdgeProps props) Component
inherited
featureRow(FeatureRowProps props) Component
inherited
fieldWrapper(FieldWrapperProps props) Widget
inherited
flexiCards(FlexiCardsProps props) Widget
inherited
flexiCardsSimple(FlexiCardsSimpleProps props) Widget
inherited
floating(FloatingProps props) Widget
inherited
flow(FlowProps props) Widget
inherited
form(FormProps props) Widget
inherited
formSection(FormSectionProps props) Widget
inherited
fullscreenTakeover(FullscreenTakeoverProps props) Widget
Render a fullscreen takeover component.
inherited
gap(GapProps props) Component
inherited
gutter(GutterProps props) Component
inherited
inlineHeroBanner(InlineHeroBannerProps props) Widget
Render an inline hero banner component.
inherited
inputGroup(InputGroupProps props) Widget
inherited
item(ItemProps props) Widget
inherited
kbd(KbdProps props) Component
Renders a keyboard shortcut display component.
inherited
keyValueTable(KeyValueTableProps props) Widget
inherited
loadingSpinner(LoadingSpinnerProps props) Component
Renders a loading spinner component.
inherited
marqueeTickerBar(MarqueeTickerBarProps props) Widget
Render a marquee ticker bar component.
inherited
inherited
minimizablePromo(MinimizablePromoProps props) Widget
Render a minimizable promo component.
inherited
nativeSelect(NativeSelectProps props) Component
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
otpInput(OtpInputProps props) Component
Render an OTP input component.
inherited
paddingWrapper(PaddingWrapperProps props) Widget
inherited
pagination(PaginationProps props) Component
Renders a pagination control.
inherited
progress(ProgressProps props) Component
Renders a linear progress bar component.
inherited
progressClaimBanner(ProgressClaimBannerProps props) Widget
Render a progress claim banner component.
inherited
promoModal(PromoModalProps props) Widget
Render a promo modal component.
inherited
radioGroup<T>(RadioGroupProps<T> props) Widget
Render a radio group component.
inherited
resizable(ResizableProps props) Widget
inherited
row(RowProps props) Widget
inherited
scrollArea(ScrollAreaProps props) Widget
Renders a scroll area component.
inherited
scrollRail(ScrollRailProps props) Widget
inherited
scrollRailLayout(ScrollRailLayoutProps props) Widget
inherited
select<T>(SelectProps<T> props) Widget
inherited
separator(SeparatorProps props) Widget
Renders a separator/divider component.
inherited
sheet(SheetProps props) Widget
inherited
Renders the main sidebar container.
inherited
sidebarCollapsed(List<Widget> children) Widget
Renders content shown when sidebar is collapsed.
inherited
sidebarExpanded(List<Widget> children) Widget
Renders content shown when sidebar is expanded.
inherited
sidebarGroup(SidebarGroupProps props) Widget
Renders a sidebar group with optional label.
inherited
sidebarItem(SidebarItemProps props) Widget
Renders a sidebar navigation item.
inherited
sidebarSection(SidebarSectionProps props) Widget
Renders a fixed (non-collapsible) sidebar section.
inherited
sidebarSeparator() Widget
Renders a sidebar separator.
inherited
sidebarSubMenu(SidebarSubMenuProps props) Widget
Renders a collapsible sidebar submenu.
inherited
sizedBox(SizedBoxProps props) Widget
inherited
skeleton(SkeletonProps props) Component
Renders a skeleton loading placeholder component.
inherited
slider(SliderProps props) Component
Render a slider component.
inherited
slidingSidebarBanner(SlidingSidebarBannerProps props) Widget
Render a sliding sidebar banner component.
inherited
slotCounter(SlotCounterProps props) Component
inherited
slotCounterCard(SlotCounterCardProps props) Component
inherited
slotCounterRow(SlotCounterRowProps props) Component
inherited
spacer(SpacerProps props) Widget
inherited
specRow(SpecRowProps props) Component
Renders a spec row component.
inherited
staticTable(StaticTableProps props) Widget
inherited
statusBadge(StatusBadgeProps props) Widget
inherited
tabBar(TabBarProps props) Widget
Renders a standalone tab bar without content panels.
inherited
tabs(TabsProps props) Widget
Renders a tabbed interface with content panels.
inherited
textInput(TextInputProps props) Widget
Render a text input component.
inherited
timePicker(TimePickerProps props) Component
Render a time picker component.
inherited
toast(ToastProps props) Widget
inherited
toastContainer(ToastContainerProps props) Widget
inherited
toggleButton(ToggleButtonProps props) Widget
Render a toggle button component.
inherited
toggleGroup(ToggleGroupProps props) Widget
inherited
toggleSwitch(ToggleSwitchProps props) Component
Render a toggle switch component.
inherited
toolbar(ToolbarProps props) Widget
inherited
topAnnouncementBar(TopAnnouncementBarProps props) Widget
Render a top announcement bar component.
inherited
toString() String
A string representation of this object.
inherited
virtualScroll<T>(VirtualScrollProps<T> props) Widget
Renders a virtualized scroll list component.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited