core/rendering/base/text_area_render_base library

Classes

DefaultTextAreaRenderer
Backward-compatible text-area renderer used by custom themes that have not provided a dedicated renderer and by standalone TextArea components outside an Arcane theme provider.
TextAreaRenderBase
Shared structural base for themed text-area renderers.