AuthGuard class

Stub route protection for non-web platforms.

Inheritance

Constructors

AuthGuard({required Widget child, Widget? loadingIndicator, String redirectTo = '/login', bool requireAdmin = false, bool isAdmin(AuthUser user)?, Key? key})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
isAdmin bool Function(AuthUser user)?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loadingIndicator Widget?
final
redirectTo String
final
requireAdmin bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited