ArcaneAuthProvider class

Provides authentication state throughout the component tree.

Inheritance

Constructors

ArcaneAuthProvider({required Widget child, void onAuthStateChanged(AuthState)?, String? redirectOnLogin, String? redirectOnLogout, String? serverApiUrl, Key? key})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onAuthStateChanged → void Function(AuthState)?
final
redirectOnLogin String?
final
redirectOnLogout String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverApiUrl String?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneAuthProvider>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited