CodexMinimizablePromo class

Codex Minimizable Promo renderer.

A promo drawer that slides in from the right edge. When minimized, only a slim tab is visible.

Inheritance

Constructors

CodexMinimizablePromo(MinimizablePromoProps props, {Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
props MinimizablePromoProps
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<CodexMinimizablePromo>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited