ShadcnCard class
ShadCN Card renderer.
Reference: https://ui.shadcn.com/docs/components/card
- Inheritance
-
- Object
- Component
- StatelessComponent
- ShadcnCard
Constructors
- ShadcnCard(CardProps props, {Key? key})
-
const
Properties
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited