ShadcnDialog class

ShadCN Dialog renderer.

Outputs the exact HTML structure and CSS from ui.shadcn.com. Reference: https://ui.shadcn.com/docs/components/dialog

ShadCN Dialog:

  • Overlay: fixed inset-0 z-50 bg-black/80
  • Content: fixed left-50% top-50% z-50 grid w-full max-w-lg translate-x--50% translate-y--50% gap-4 border bg-background p-6 shadow-lg duration-200
Inheritance

Constructors

ShadcnDialog(DialogProps props, {Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
props DialogProps
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited