ShadcnTextInput class

ShadCN Text Input renderer.

Outputs the exact HTML structure and CSS from ui.shadcn.com. Reference: https://ui.shadcn.com/docs/components/input

ShadCN Input:

  • flex h-10 w-full rounded-md border border-input bg-background
  • px-3 py-2 text-base
  • ring-offset-background
  • file:border-0 file:bg-transparent file:text-sm file:font-medium file:text-foreground
  • placeholder:text-muted-foreground
  • focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2
  • disabled:cursor-not-allowed disabled:opacity-50
  • md:text-sm
Inheritance

Constructors

ShadcnTextInput(TextInputProps props, {Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
props TextInputProps
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited