ArcaneStylesheet class abstract

Constructors

ArcaneStylesheet()
const

Properties

baseCss String
no setter
bodyClass String?
no setter
cacheKey Object
no setter
componentCss String
no setter
darkSeed ThemeSeed
no setter
fontFaces String
no setter
fonts FontConfig
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
layouts LayoutRenderers
no setter
lightSeed ThemeSeed
no setter
name String
no setter
radius RadiusConfig
no setter
renderers ComponentRenderers
no setter
rootAttributes Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeClass String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited