ArcaneStylesheetCss class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
{required Object cacheKey, required String fontFaces, required ThemeSeed lightSeed, required ThemeSeed darkSeed, required FontConfig fonts, required RadiusConfig radius, required String componentCss}) → String