FontConfig class
Font family configuration for a theme.
Constructors
- FontConfig({String sans = "'Akzidenz-GroteskPro'", String? heading = "'ITCAvantGardeStd'", String mono = "'Hack'"})
-
const
- FontConfig.system()
-
System fonts only (no external fonts needed).
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → String?
-
Font stack for headings. Falls back to sans if null.
final
- headingOrSans → String
-
Returns heading if set, otherwise sans.
no setter
- mono → String
-
Monospace font stack for code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sans → String
-
Sans-serif font stack for body text.
final
Methods
-
copyWith(
{String? sans, String? heading, String? mono}) → FontConfig - Create a copy with some fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited