ThemePalette class

Complete color palette derived from ThemeSeed.

All colors are stored as int (0xAARRGGBB format). This is the full set of colors needed by the CSS generator.

Constructors

ThemePalette({required bool isDark, required int background, required int foreground, required int card, required int cardForeground, required int cardHover, required int popover, required int popoverForeground, required int primary, required int primaryForeground, required int primaryContainer, required int secondary, required int secondaryForeground, required int secondaryContainer, required int accent, required int accentForeground, required int accentHover, required int accentContainer, required int muted, required int mutedForeground, required int destructive, required int destructiveForeground, required int destructiveHover, required int destructiveContainer, required int success, required int successForeground, required int successHover, required int successContainer, required int warning, required int warningForeground, required int warningHover, required int warningContainer, required int info, required int infoForeground, required int infoHover, required int infoContainer, required int border, required int input, required int ring, required int overlay, required int navbar, required int codeBackground, required String shadowXs, required String shadowSm, required String shadowMd, required String shadowLg, required String shadowXl})
const

Properties

accent int
Accent color for highlights.
final
accentContainer int
Accent container.
final
accentForeground int
Text on accent background.
final
accentHover int
Accent hover state.
final
background int
Main background color.
final
border int
Border color.
final
card int
Card/surface background.
final
cardForeground int
Card text color.
final
cardHover int
Card hover state.
final
codeBackground int
Code block background.
final
destructive int
final
destructiveContainer int
final
destructiveForeground int
final
destructiveHover int
final
foreground int
Main text color.
final
hashCode int
The hash code for this object.
no setterinherited
info int
final
infoContainer int
final
infoForeground int
final
infoHover int
final
input int
Input border color.
final
isDark bool
Whether this is a dark mode palette.
final
muted int
Muted background.
final
mutedForeground int
Muted text (for secondary text, placeholders).
final
Navbar background (semi-transparent).
final
overlay int
Modal overlay (50% black typically).
final
popover int
Popover/dropdown background.
final
popoverForeground int
Popover text color.
final
primary int
Primary brand color.
final
primaryContainer int
Primary at 10% opacity for containers.
final
primaryForeground int
Text on primary background.
final
ring int
Focus ring color.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary int
Secondary/muted surface color.
final
secondaryContainer int
Secondary container.
final
secondaryForeground int
Text on secondary background.
final
shadowLg String
final
shadowMd String
final
shadowSm String
final
shadowXl String
final
shadowXs String
Shadow configuration strings (pre-computed).
final
success int
final
successContainer int
final
successForeground int
final
successHover int
final
warning int
final
warningContainer int
final
warningForeground int
final
warningHover int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited