RadiusConfig class

Border radius configuration for a theme.

Constructors

RadiusConfig()
const
RadiusConfig.compact()
Smaller radii for compact/dense UIs.
const
RadiusConfig.dense()
Tight radii for dense, technical interfaces.
const
RadiusConfig.sharp()
Sharp corners.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
md String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm String
final
xs String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited