Colors class abstract

Common color constants.

Constructors

Colors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amber → const Color
amber50 → const Color
amber100 → const Color
amber200 → const Color
amber300 → const Color
amber400 → const Color
amber500 → const Color
amber600 → const Color
amber700 → const Color
amber800 → const Color
amber900 → const Color
amber950 → const Color
black → const Color
blue → const Color
cyan → const Color
cyan50 → const Color
cyan100 → const Color
cyan200 → const Color
cyan300 → const Color
cyan400 → const Color
cyan500 → const Color
cyan600 → const Color
cyan700 → const Color
cyan800 → const Color
cyan900 → const Color
cyan950 → const Color
emerald → const Color
emerald50 → const Color
emerald100 → const Color
emerald200 → const Color
emerald300 → const Color
emerald400 → const Color
emerald500 → const Color
emerald600 → const Color
emerald700 → const Color
emerald800 → const Color
emerald900 → const Color
emerald950 → const Color
fuchsia → const Color
gray50 → const Color
gray100 → const Color
gray200 → const Color
gray300 → const Color
gray400 → const Color
gray500 → const Color
gray600 → const Color
gray700 → const Color
gray800 → const Color
gray900 → const Color
gray950 → const Color
green → const Color
indigo → const Color
lime → const Color
orange → const Color
pink → const Color
purple → const Color
red → const Color
red50 → const Color
red100 → const Color
red200 → const Color
red300 → const Color
red400 → const Color
red500 → const Color
red600 → const Color
red700 → const Color
red800 → const Color
red900 → const Color
red950 → const Color
rose → const Color
sky → const Color
slate50 → const Color
slate100 → const Color
slate200 → const Color
slate300 → const Color
slate400 → const Color
slate500 → const Color
slate600 → const Color
slate700 → const Color
slate800 → const Color
slate900 → const Color
slate950 → const Color
teal → const Color
transparent → const Color
violet → const Color
violet50 → const Color
violet100 → const Color
violet200 → const Color
violet300 → const Color
violet400 → const Color
violet500 → const Color
violet600 → const Color
violet700 → const Color
violet800 → const Color
violet900 → const Color
violet950 → const Color
white → const Color
yellow → const Color
zinc50 → const Color
zinc100 → const Color
zinc200 → const Color
zinc300 → const Color
zinc400 → const Color
zinc500 → const Color
zinc600 → const Color
zinc700 → const Color
zinc800 → const Color
zinc900 → const Color
zinc950 → const Color