CardCarouselTheme class

Card carousel theme configuration

Constructors

CardCarouselTheme({double cardWidth = 300, double cardHeight = 200, double spacing = 16})
const

Properties

cardHeight double
final
cardWidth double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited