themeOf static method
Get theme from context or fall back to global
Implementation
static ArcaneTheme themeOf(BuildContext context) {
return ArcaneTheme.maybeOf(context) ?? globalTheme;
}
Get theme from context or fall back to global
static ArcaneTheme themeOf(BuildContext context) {
return ArcaneTheme.maybeOf(context) ?? globalTheme;
}