BoxConstraints class

Flutter-like box constraints.

Constructors

BoxConstraints({double? minWidth, double? maxWidth, double? minHeight, double? maxHeight})
const
BoxConstraints.expand({double? width, double? height})
const
BoxConstraints.tight(double width, double height)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxHeight double?
final
maxWidth double?
final
minHeight double?
final
minWidth double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited