EdgeInsets class

Flutter-like edge insets for padding and margin.

Constructors

EdgeInsets.all(double value)
const
EdgeInsets.only({double left = 0, double top = 0, double right = 0, double bottom = 0})
const
EdgeInsets.symmetric({double horizontal = 0, double vertical = 0})
const

Properties

bottom double
final
hashCode int
The hash code for this object.
no setterinherited
left double
final
margin String
no setter
padding String
no setter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final

Methods

copyWith({double? left, double? top, double? right, double? bottom}) EdgeInsets
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(double factor) EdgeInsets
operator +(EdgeInsets other) EdgeInsets
operator ==(Object other) bool
The equality operator.
inherited

Constants

zero → const EdgeInsets