PasswordPolicy class

Password validation policy with configurable requirements.

Constructors

PasswordPolicy({int minLength = 6, int maxLength = 128, bool requireUppercase = false, bool requireLowercase = false, bool requireNumber = false, bool requireSpecialChar = false})
const

Properties

description String
no setter
hashCode int
The hash code for this object.
no setterinherited
maxLength int
final
minLength int
final
requireLowercase bool
final
requireNumber bool
final
requireSpecialChar bool
final
requireUppercase bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(String password) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String password) String?

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

medium → const PasswordPolicy
strong → const PasswordPolicy
weak → const PasswordPolicy