ArcaneCommonStyles class abstract

Common style patterns.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bodyText Map<String, String>
no setter
card Map<String, String>
no setter
cardSubtle Map<String, String>
no setter
flexCenter Map<String, String>
no setter
flexCol Map<String, String>
no setter
flexRow Map<String, String>
no setter
flexRowSpaced Map<String, String>
no setter
heading Map<String, String>
no setter
imageCover Map<String, String>
no setter
labelText Map<String, String>
no setter
sectionHeader Map<String, String>
no setter
subheading Map<String, String>
no setter
tinyText Map<String, String>
no setter

Static Methods

container({String? maxWidth}) Map<String, String>
grid(int cols, {String gap = '24px'}) Map<String, String>
gridAuto({String minWidth = '300px', String gap = '24px'}) Map<String, String>
imageContainer(String size) Map<String, String>
section({String? background}) Map<String, String>
statusBadge(String bgColor, String textColor) Map<String, String>