ArcaneEffects class abstract

Effects design tokens.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

backdropBlur → const String
backdropBlurStrong → const String
glowCyan → const String
glowGreen → const String
glowOrange → const String
glowPink → const String
glowPrimary → const String
glowPurple → const String
hoverLift → const String
hoverScale → const String
shadowCard → const String
shadowLgStatic → const String
shadowMd → const String
shadowSm → const String
shadowXlStatic → const String
shadowXs → const String
transitionBounce → const String
transitionFast → const String
transitionNormal → const String
transitionSlow → const String