ArcaneLayout class abstract
Layout design tokens.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- headerHeight → const String
- maxWidthCard → const String
- maxWidthContainer → const String
- maxWidthContent → const String
- maxWidthForm → const String
- maxWidthFull → const String
- maxWidthNarrow → const String
- maxWidthNarrowText → const String
- maxWidthText → const String