RainbowScripts class

JavaScript for Codex rainbow theme animation.

This script animates the --primary and --ring CSS variables through a rainbow color cycle when the .codex-rainbow class is present. IMPORTANT: Only activates if .codex-rainbow class is already on the root element.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

code → const String