ButtonSizeStyle class

Button size presets

Properties

fontSize String
final
gap String
final
hashCode int
The hash code for this object.
no setterinherited
height String
final
paddingH String
final
paddingV String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Map<String, String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

lg → const ButtonSizeStyle
Large button (48px height)
md → const ButtonSizeStyle
Medium button (40px height) - Default
sm → const ButtonSizeStyle
Small button (32px height)