ButtonStyle class

Button styling presets Use like: ArcaneButton(style: ButtonStyle.warning)

Constructors

ButtonStyle.custom({required Map<String, String> base, Map<String, String> hover = const {}, Map<String, String> active = const {}, Map<String, String> disabled = const {}})
Create a custom button style
const

Properties

active Map<String, String>
Styles applied when active/pressed
final
base Map<String, String>
Base styles applied to the button
final
disabled Map<String, String>
Styles applied when disabled
final
hashCode int
The hash code for this object.
no setterinherited
hover Map<String, String>
Styles applied on hover (via @css or classes)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withOverrides(Map<String, String> overrides) Map<String, String>
Merge base styles with additional properties

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

danger → const ButtonStyle
Alias for destructive
destructive → const ButtonStyle
Destructive/danger button (red)
ghost → const ButtonStyle
Ghost button (transparent background)
info → const ButtonStyle
Info button (blue)
Link-style button
outline → const ButtonStyle
Outline button with border
primary → const ButtonStyle
Primary action button with accent color
secondary → const ButtonStyle
Secondary/muted button
success → const ButtonStyle
Success button (green)
warning → const ButtonStyle
Warning button (amber)