CheckboxStyle class

Checkbox styling presets Use like: Checkbox(style: CheckboxStyle.primary)

Properties

checkColor String
final
checkedColor String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uncheckedBorder String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

destructive → const CheckboxStyle
Destructive checkbox (red)
primary → const CheckboxStyle
Primary checkbox (accent color)
success → const CheckboxStyle
Success checkbox (green)
warning → const CheckboxStyle
Warning checkbox (amber)