IconButtonStyle class

Icon button styling presets Use like: ArcaneIconButton(style: IconButtonStyle.primary)

Properties

base Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
hover Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

destructive → const IconButtonStyle
Destructive icon button
ghost → const IconButtonStyle
Ghost icon button (default)
outline → const IconButtonStyle
Outline icon button
primary → const IconButtonStyle
Primary icon button
secondary → const IconButtonStyle
Secondary icon button
success → const IconButtonStyle
Success icon button
warning → const IconButtonStyle
Warning icon button