InputSizeStyle class

Input size presets

Properties

fontSize String
final
hashCode int
The hash code for this object.
no setterinherited
height String
final
paddingH String
final
paddingV String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Map<String, String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

lg → const InputSizeStyle
Large input (48px height)
md → const InputSizeStyle
Medium input (40px height) - Default
sm → const InputSizeStyle
Small input (32px height)