ProgressStyle class

Progress bar styling presets

Properties

fillColor String
final
gradientValue String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackColor String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

error → const ProgressStyle
Error progress (red)
gradient → const ProgressStyle
Gradient progress
standard → const ProgressStyle
Default progress (accent color)
success → const ProgressStyle
Success progress (green)
warning → const ProgressStyle
Warning progress (amber)