ArcaneColors class

Centralized design tokens for Arcane Jaspr All values are static const strings that reference CSS variables for theme reactivity or provide consistent static values for spacing, typography, etc. Color tokens referencing CSS variables for dynamic theming

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accent → const String
Primary accent color
accentContainer → const String
Accent container/background
accentForeground → const String
Text on accent backgrounds
accentHover → const String
Accent color on hover
arkBlue → const String
ARK blue
background → const String
Main background
backgroundOverlay → const String
Background overlay (for modals/dialogs)
backgroundSecondary → const String
Secondary background
backgroundTertiary → const String
Tertiary background
black → const String
Pure black
border → const String
Primary border
borderLight → const String
Light border (most visible)
borderMedium → const String
Medium border (more visible than subtle)
borderSubtle → const String
Subtle border
card → const String
Card/elevated surface background
cardAlt → const String
Alternate card background
cardForeground → const String
Card foreground/text
cardHover → const String
Card hover state
codeBackground → const String
Code block background
cs2Orange → const String
CS2 orange
error → const String
Error/destructive state
errorForeground → const String
info → const String
Informational state
infoForeground → const String
input → const String
Input field background
inputForeground → const String
Input field foreground
inverseSurface → const String
minecraftGreen → const String
Minecraft green
muted → const String
Muted/secondary text
mutedForeground → const String
Muted foreground text
Navbar background (with transparency)
neonCyan → const String
Neon cyan
neonGreen → const String
Neon green
neonOrange → const String
Neon orange
neonPink → const String
Neon pink
neonPurple → const String
Neon purple
onBackground → const String
Text on background
onInverseSurface → const String
onPrimary → const String
onPrimaryContainer → const String
onSecondary → const String
onSecondaryContainer → const String
onSurface → const String
Text on surface
onSurfaceVariant → const String
Text on surface variant
onTertiary → const String
onTertiaryContainer → const String
outline → const String
outlineVariant → const String
primary → const String
primaryContainer → const String
ring → const String
Focus ring color
rustOrange → const String
Rust orange
scrim → const String
secondary → const String
secondaryContainer → const String
shadow → const String
success → const String
Success/positive state
successContainer → const String
successForeground → const String
successHover → const String
surface → const String
Primary surface
surfaceTint → const String
surfaceVariant → const String
Variant surface (slightly different from primary)
terrariaGreen → const String
Terraria green
tertiary → const String
tertiaryContainer → const String
textFaint → const String
Faint text (least visible)
textSubtle → const String
Subtle text (less visible than muted)
tooltip → const String
Tooltip background
tooltipForeground → const String
Tooltip text
transparent → const String
Transparent
valheimGold → const String
Valheim gold
warning → const String
Warning/caution state
warningForeground → const String
white → const String
Pure white
windowDotGreen → const String
Window maximize button (green)
windowDotRed → const String
Window close button (red)
windowDotYellow → const String
Window minimize button (yellow)