isClient property
bool
get
isClient
Whether the current app is run on the client (in the browser)
Implementation
bool get isClient;
Whether the current app is run on the client (in the browser)
bool get isClient;