reportBuildError abstract method
Report an error that occurred during the build process of element.
Implementation
void reportBuildError(Element element, Object error, StackTrace stackTrace);
Report an error that occurred during the build process of element.
void reportBuildError(Element element, Object error, StackTrace stackTrace);