rootElement property
The Element that is at the root of the hierarchy.
This is initialized when runApp is called.
Implementation
@override
RenderObjectElement? get rootElement => _rootElement;
The Element that is at the root of the hierarchy.
This is initialized when runApp is called.
@override
RenderObjectElement? get rootElement => _rootElement;