fantasy constant
FontFamily
const fantasy
Generic font family where glyphs have a playful, decorative design.
Implementation
static const FontFamily fantasy = FontFamily._generic('fantasy');
Generic font family where glyphs have a playful, decorative design.
static const FontFamily fantasy = FontFamily._generic('fantasy');