monospace constant
FontFamily
const monospace
Generic font family where all glyphs have the same fixed width.
Implementation
static const FontFamily monospace = FontFamily._generic('monospace');
Generic font family where all glyphs have the same fixed width.
static const FontFamily monospace = FontFamily._generic('monospace');