currentNode property
T?
get
currentNode
The web.Node for the component in the tree that currently has this global key.
The current node is null if (1) the current environment is not web, or (2) there is no component in the tree that matches this global key.
Implementation
T? get currentNode => switch (_currentElement) {
RenderObjectElement(renderObject: RenderObject(:final T node)) => node,
Element(slot: ElementSlot(target: RenderObjectElement(renderObject: RenderObject(:final T node)))) => node,
_ => null,
};