updateShouldNotify abstract method
Whether the framework should notify components that inherit from this component.
When this component is rebuilt, sometimes we need to rebuild the components that
inherit from this component but sometimes we do not. For example, if the data
held by this component is the same as the data held by oldComponent, then we
do not need to rebuild the components that inherited the data held by
oldComponent.
The framework distinguishes these cases by calling this function with the component that previously occupied this location in the tree as an argument. The given component is guaranteed to have the same runtimeType as this object.
Implementation
@protected
bool updateShouldNotify(covariant InheritedComponent oldComponent);