InheritedModel<T> class abstract

Inheritance

Constructors

InheritedModel({Key? key, required Component child})
Creates an inherited component that supports dependencies qualified by "aspects", i.e. a descendant component can indicate that it should only be rebuilt if a specific aspect of the model changes.
const

Properties

child Component
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() InheritedModelElement<T>
Inflates this configuration to a concrete instance.
override
isSupportedAspect(Object aspect) bool
Returns true if this model supports the given aspect.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(covariant InheritedComponent oldComponent) bool
Whether the framework should notify components that inherit from this component.
inherited
updateShouldNotifyDependent(covariant InheritedModel<T> oldComponent, Set<T> dependencies) bool
Return true if the changes between this model and oldComponent match any of the dependencies.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

inheritFrom<T extends InheritedModel<Object>>(BuildContext context, {Object? aspect}) → T?
Makes context dependent on the specified aspect of an InheritedModel of type T.