InheritedModel<T> constructor

const InheritedModel<T>({
  1. Key? key,
  2. required Component child,
})

Creates an inherited component that supports dependencies qualified by "aspects", i.e. a descendant component can indicate that it should only be rebuilt if a specific aspect of the model changes.

Implementation

const InheritedModel({super.key, required super.child});