MultiChildElement constructor
MultiChildElement(
- Component component
Creates an element that uses the given component as its configuration.
Implementation
MultiChildElement(super.component);
Creates an element that uses the given component as its configuration.
MultiChildElement(super.component);