RenderObject class abstract

Constructors

RenderObject()

Properties

hashCode int
The hash code for this object.
no setterinherited
node → Node?
no setter
parent RenderObject?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(covariant RenderObject child, {covariant RenderObject? after}) → void
createChildRenderElement(String tag) RenderElement
createChildRenderFragment() RenderFragment
createChildRenderText(String text) RenderText
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(covariant RenderObject child) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited