SchedulerBinding mixin
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedulerPhase → SchedulerPhase
-
no setter
Methods
-
addPostFrameCallback(
VoidCallback callback) → void -
completeInitialFrame(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scheduleBuild(
VoidCallback buildCallback) → void -
Schedules a build and ultimately calls
_handleFramewith the providedbuildCallback. -
scheduleFrame(
VoidCallback frameCallback) → void -
Schedules a frame with the provided
frameCallback. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited