getState abstract method
U
getState()
Called on the server after the initial build, to retrieve the state data of this component.
Implementation
U getState();
Called on the server after the initial build, to retrieve the state data of this component.
U getState();