updateState abstract method

void updateState(
  1. U value
)

Called on the client during initState to receive the synced state from the server.

On initialization, this will be called as part of the super.initState() call. It is recommended to start with the inherited method call in you custom initState() implementation, however when you want to do some work before the initial updateState() call, you can invoke the super.initState() later in your implementation.

@override
void initState() {
  // do some pre-initialization
  super.initState(); // this will also call your updateState() implementation
  // do some post-initialization
}

Implementation

void updateState(U value);