ArcaneLoginCard class
Login card with email/password form and social sign-in options.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneLoginCard
Constructors
-
ArcaneLoginCard({List<
AuthMethod> methods = const <AuthMethod>[AuthMethod.email, AuthMethod.github, AuthMethod.google], Component? header, String? signupRoute, String? forgotPasswordRoute, PasswordPolicy? passwordPolicy, void onSuccess()?, String maxWidth = '400px', Key? key}) -
const
Properties
- forgotPasswordRoute → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxWidth → String
-
final
-
methods
→ List<
AuthMethod> -
final
- onSuccess → void Function()?
-
final
- passwordPolicy → PasswordPolicy?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signupRoute → String?
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneLoginCard> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited