SocialProviderConfig class
Configuration for a social provider's appearance.
Constructors
Properties
- backgroundColor → String
-
final
- borderColor → String
-
final
- buildIcon → Widget Function()
-
final
- defaultLabel → String
-
final
- foregroundColor → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverBackgroundColor → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forProvider(
SocialProvider provider) → SocialProviderConfig - Get the configuration for a given provider.