ArcaneAuthorCard class
Author attribution card with avatar, name, and role.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneAuthorCard
Constructors
- ArcaneAuthorCard({String? avatarUrl, required String name, String? role, AuthorCardSize size = AuthorCardSize.md, String? initials, String? avatarBackground, String? nameColor, String? roleColor, Key? key})
-
const
- ArcaneAuthorCard.lg({String? avatarUrl, required String name, String? role, String? initials, String? avatarBackground, String? nameColor, String? roleColor, Key? key})
-
const
- ArcaneAuthorCard.sm({String? avatarUrl, required String name, String? role, String? initials, String? avatarBackground, String? nameColor, String? roleColor, Key? key})
-
const
Properties
- avatarBackground → String?
-
final
- avatarUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initials → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- name → String
-
final
- nameColor → String?
-
final
- role → String?
-
final
- roleColor → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → AuthorCardSize
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited