PricingCard class
A plan surface: an optional icon, a title, a price row, an optional subtitle, an included/excluded feature list, an optional spec table, and a call-to-action button. Themed automatically by the active stylesheet.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- PricingCard
Constructors
-
PricingCard({PricingTier? tier, void onCtaPressed()?, String? title, String? subtitle, String? price, String period = '/month', List<
String> features = const <String>[], List<String> excludedFeatures = const <String>[], List<SpecEntry> ? specs, String buttonText = 'Get Started', String? buttonLink, void onButtonClick()?, PricingCardVariant variant = PricingCardVariant.standard, ArcaneGlyph? icon, ArcaneStyleData? styles, ArcaneDecoration? decoration, Key? key}) -
const
-
PricingCard.compact({required String title, required String price, String? subtitle, String period = '/month', List<
String> features = const <String>[], List<String> excludedFeatures = const <String>[], List<SpecEntry> ? specs, String buttonText = 'Get Started', String? buttonLink, void onButtonClick()?, ArcaneGlyph? icon, ArcaneStyleData? styles, ArcaneDecoration? decoration, Key? key}) -
Creates a compact pricing card for grids.
const
Properties
-
final
-
final
- decoration → ArcaneDecoration?
-
Semantic, theme-interpreted decoration (elevation + theme-specific fields).
final
-
excludedFeatures
→ List<
String> -
final
-
features
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → ArcaneGlyph?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onButtonClick → void Function()?
-
final
- onCtaPressed → void Function()?
-
final
- period → String
-
final
- price → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
specs
→ List<
SpecEntry> ? -
final
- styles → ArcaneStyleData?
-
Literal, theme-permeable style override (always applied, wins over theme).
final
- subtitle → String?
-
final
- tier → PricingTier?
-
final
- title → String?
-
final
- variant → PricingCardVariant
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited