ArcaneInfiniteCarousel class
Infinite scrolling carousel that auto-scrolls horizontally.
Features:
- Click and drag to manually scroll
- Infinite looping in both directions
- Auto-resume scrolling after inactivity
- Touch support for mobile devices
- Pauses on hover
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneInfiniteCarousel
Constructors
-
ArcaneInfiniteCarousel({Key? key, required List<
Widget> children, String gap = '1.5rem', int animationDuration = 60, bool showFadeEdges = true, String fadeWidth = '150px', String backgroundColor = 'var(--card)', int resumeDelay = 5}) -
const
-
ArcaneInfiniteCarousel.withClass({Key? key, required List<
Widget> children, required String? trackClass, String gap = '1.5rem', int animationDuration = 60, bool showFadeEdges = true, String fadeWidth = '150px', String backgroundColor = 'var(--card)', int resumeDelay = 5}) -
const
Properties
- animationDuration → int
-
final
- backgroundColor → String
-
final
-
children
→ List<
Widget> -
final
- fadeWidth → String
-
final
- gap → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- resumeDelay → int
-
Delay in seconds before resuming auto-scroll after user interaction.
Default: 5 seconds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showFadeEdges → bool
-
final
- trackClass → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited