ArcaneCommand class
Command palette for quick actions and navigation.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneCommand
Constructors
-
ArcaneCommand({required List<
CommandGroup> groups, bool isOpen = false, void onClose()?, String placeholder = 'Type a command or search...', String emptyMessage = 'No results found.', void onSearch(String)?, bool filterFn(CommandItem, String)?, Key? key}) -
const
Properties
- emptyMessage → String
-
final
- filterFn → bool Function(CommandItem, String)?
-
final
-
groups
→ List<
CommandGroup> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onClose → void Function()?
-
final
- onSearch → void Function(String)?
-
final
- placeholder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneCommand> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited