CommandItem class
A single command item.
Constructors
Properties
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
Optional href for JavaScript-based navigation.
final
- hrefTarget → String?
-
Target for href navigation (e.g., '_blank' for new tab).
final
- icon → Widget?
-
final
-
keywords
→ List<
String> ? -
final
- label → String
-
final
- onSelect → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcut → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited