ArcaneDialog class

A modal dialog component.

Inheritance

Constructors

ArcaneDialog({String? title, required Component child, List<Component>? actions, bool showCloseButton = true, void onClose()?, double maxWidth = 500, bool barrierDismissible = true, Key? key})
const

Properties

actions List<Component>?
Footer actions
final
barrierDismissible bool
Whether to close on barrier click
final
child Component
Dialog content
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxWidth double
Maximum width
final
onClose → void Function()?
Close handler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool
Whether to show close button
final
title String?
Dialog title
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final