ArcaneInputDialog class
Input dialog supporting text, email, password, multiline, and number inputs.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneInputDialog
Constructors
-
ArcaneInputDialog({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, InputDialogType type = InputDialogType.text, int? maxLength, int maxLines = 1, bool requireWorkEmail = false, List<
String> ? blockedDomains, num? minValue, num? maxValue, Key? key}) -
const
-
ArcaneInputDialog.email({required String title, String? message, String placeholder = 'Enter email address...', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, bool requireWorkEmail = false, List<
String> ? blockedDomains, Key? key}) -
const
- ArcaneInputDialog.multiline({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, int? maxLength, int maxLines = 4, Key? key})
-
const
- ArcaneInputDialog.number({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, num? minValue, num? maxValue, Key? key})
-
const
- ArcaneInputDialog.password({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, int? maxLength, Key? key})
-
const
- ArcaneInputDialog.text({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, int? maxLength, Key? key})
-
const
Properties
-
blockedDomains
→ List<
String> ? -
final
- cancelText → String
-
final
- confirmText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxLength → int?
-
final
- maxLines → int
-
final
- maxValue → num?
-
final
- message → String?
-
final
- minValue → num?
-
final
- onCancel → void Function()?
-
final
- onConfirm → void Function(String value)?
-
final
- placeholder → String
-
final
- requireWorkEmail → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- type → InputDialogType
-
final
- validator → String? Function(String value)?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited