ArcanePopover class
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcanePopover
Constructors
Properties
- closeOnEscape → bool
-
final
- closeOnOutsideClick → bool
-
final
- content → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- offset → int
-
final
- onOpenChange → void Function(bool isOpen)?
-
final
- position → FloatingPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
final
- trigger → Widget
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited