ArcaneSonner class
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneSonner
Constructors
- ArcaneSonner({ToastPosition position = ToastPosition.bottomRight, int maxVisible = 3, double gap = 12, double offset = 20, Key? key})
-
const
Properties
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxVisible → int
-
final
- offset → double
-
final
- position → ToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dismiss(
String id) → void -
dismissAll(
) → void -
error(
String message, {String? title, String? description, int duration = 6000, ToastAction? action, Widget? icon, ToastPosition? position}) → String -
info(
String message, {String? title, String? description, int duration = 4000, ToastAction? action, Widget? icon, ToastPosition? position}) → String -
loading(
String message, {String? title, String? description, ToastPosition? position}) → String -
success(
String message, {String? title, String? description, int duration = 4000, ToastAction? action, Widget? icon, ToastPosition? position}) → String -
warning(
String message, {String? title, String? description, int duration = 5000, ToastAction? action, Widget? icon, ToastPosition? position}) → String