TextInputDialog class
A text input dialog component.
- Inheritance
-
- Object
- Component
- StatefulComponent
- TextInputDialog
Constructors
- TextInputDialog({required String title, String? message, String placeholder = '', String? initialValue, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(String value)?, void onCancel()?, String? validator(String value)?, bool obscureText = false, int? maxLength, int maxLines = 1, Key? key})
-
const
Properties
- cancelText → String
-
Cancel button text
final
- confirmText → String
-
Confirm button text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → String?
-
Initial value
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxLength → int?
-
Maximum length
final
- maxLines → int
-
Whether the input is multiline
final
- message → String?
-
Optional message/description
final
- obscureText → bool
-
Whether to obscure the text (password input)
final
- onCancel → void Function()?
-
Cancel callback
final
- onConfirm → void Function(String value)?
-
Confirm callback with the entered value
final
- placeholder → String
-
Input placeholder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Dialog title
final
- validator → String? Function(String value)?
-
Input validation
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< TextInputDialog> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited