ArcaneToast class
Toast notification component with auto-dismiss and global API support.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneToast
Constructors
- ArcaneToast({required String message, String? title, String? description, ToastVariant variant = ToastVariant.info, ToastPosition position = ToastPosition.bottomRight, int duration = 4000, bool dismissible = true, ToastAction? action, Widget? icon, void onClose()?, String? id, Key? key})
-
const
Properties
- action → ToastAction?
-
final
- description → String?
-
final
- dismissible → bool
-
final
- duration → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- id → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- message → String
-
final
- onClose → void Function()?
-
final
- position → ToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- variant → ToastVariant
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneToast> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited