ToastData class
Toast data for the queue.
Constructors
- ToastData({required String id, required String message, String? title, String? description, ToastVariant variant = ToastVariant.info, int duration = 4000, bool dismissible = true, ToastAction? action, Widget? icon, ToastPosition position = ToastPosition.bottomRight})
Properties
- action → ToastAction?
-
final
- description → String?
-
final
- dismissible → bool
-
final
- duration → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- id → String
-
final
- message → String
-
final
- position → ToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- variant → ToastVariant
-
final
Methods
-
copyWith(
{String? message, String? title, String? description, ToastVariant? variant, int? duration, bool? dismissible, ToastAction? action, Widget? icon}) → ToastData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited