AlertBanner class
An alert/banner component (Supabase-style)
- Inheritance
-
- Object
- Component
- StatelessComponent
- AlertBanner
Constructors
- AlertBanner({required String message, String? title, AlertVariant variant = AlertVariant.info, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
-
const
- AlertBanner.error({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
-
Error alert
const
- AlertBanner.info({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
-
Info alert
const
- AlertBanner.success({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
-
Success alert
const
- AlertBanner.warning({required String message, String? title, Component? icon, Component? action, bool dismissible = false, void onDismiss()?, bool filled = false, Key? key})
-
Warning alert
const
Properties
- action → Component?
-
Optional action button
final
- dismissible → bool
-
Whether the alert is dismissible
final
- filled → bool
-
Whether to use filled style
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component?
-
Optional icon
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- message → String
-
Alert message
final
- onDismiss → void Function()?
-
Callback when dismissed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional title
final
- variant → AlertVariant
-
Alert variant
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited