Tooltip class
A tooltip component (Supabase-style)
- Inheritance
-
- Object
- Component
- StatefulComponent
- Tooltip
Constructors
Properties
- child → Component
-
Child widget to wrap
final
- content → String
-
Tooltip content text
final
- delay → int
-
Delay before showing (ms)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxWidth → double
-
Maximum width
final
- position → TooltipPosition
-
Tooltip position
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< Tooltip> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited