TooltipCustom class
A tooltip with custom content
- Inheritance
-
- Object
- Component
- StatefulComponent
- TooltipCustom
Constructors
- TooltipCustom({required Component child, required Component tooltipContent, TooltipPosition position = TooltipPosition.top, double? maxWidth, Key? key})
-
const
Properties
- child → Component
-
Child widget to wrap
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- maxWidth → double?
-
Maximum width
final
- position → TooltipPosition
-
Tooltip position
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltipContent → Component
-
Custom tooltip content
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< TooltipCustom> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited