ArcaneField<T> class
A generic form field component in the Arcane UI component system.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneField
Constructors
-
ArcaneField({required ArcaneFieldMetadata meta, required ArcaneFieldProvider<
T> provider, required Component builder(BuildContext context, T value, void onChanged(T)), Key? key}) -
const
Properties
- builder → Component Function(BuildContext context, T value, void onChanged(T))
-
Custom builder function for the input widget.
final
- dataRuntimeType → Type
-
Returns the runtime type of the field's data
T.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- meta → ArcaneFieldMetadata
-
Metadata associated with this field.
final
-
provider
→ ArcaneFieldProvider<
T> -
Provider responsible for managing the field's data state.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneField< T> > -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited