ArcaneFieldMetadata class
Metadata class holding descriptive information for an ArcaneField.
Constructors
Properties
- description → String?
-
Descriptive text explaining the field's purpose.
final
- effectiveKey → String
-
Computes an effective key for the field.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Icon identifier for the field.
final
- key → String?
-
Unique identifier for the field.
final
- name → String?
-
Human-readable name for the field.
final
- placeholder → String?
-
Placeholder text for the field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited