ArcaneInput class
Factory class for creating common field types.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkbox(
{String? name, String? description, String? icon, bool defaultValue = false, required Future< bool> getter(), required Future<void> setter(bool)}) → ArcaneField<bool> -
select<
T> ({String? name, String? description, String? icon, required T defaultValue, required List< T> options, required Future<T> getter(), required Future<void> setter(T), String labelBuilder(T)?}) → ArcaneField<T> -
textArea(
{String? name, String? description, String? icon, String? placeholder, int minLines = 3, int maxLines = 6, String defaultValue = "", required Future< String> getter(), required Future<void> setter(String)}) → ArcaneField<String> -
textField(
{String? name, String? description, String? icon, String? placeholder, int? minLines, int? maxLines, String defaultValue = "", required Future< String> getter(), required Future<void> setter(String)}) → ArcaneField<String>