ArcaneForm class
A complete form component with built-in state management.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneForm
Constructors
Properties
- cancelText → String?
-
Cancel button text.
final
-
children
→ List<
Component> -
Form fields.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onCancel → void Function()?
-
Cancel handler.
final
- onSubmit → void Function()?
-
Submit handler.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showActions → bool
-
Whether to show action buttons.
final
- spacing → double
-
Spacing between fields.
final
- submitText → String?
-
Submit button text.
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneForm> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited