ArcaneFormScope class
Inherited component to provide form context to descendants.
- Inheritance
-
- Object
- Component
- InheritedComponent
- InheritedWidget
- ArcaneFormScope
Constructors
- ArcaneFormScope({required ArcaneFormContext formContext, required Component child, Key? key})
-
const
Properties
- child → Component
-
finalinherited
- formContext → ArcaneFormContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant ArcaneFormScope oldComponent) → bool -
Whether the framework should notify components that inherit from this component.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → ArcaneFormContext?