ArcaneImage class
Styled image wrapper.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneImage
Constructors
-
ArcaneImage({required String src, required String alt, ArcaneStyleData? styles, String? classes, String? id, String? width, String? height, String? loading, String? decoding, Map<
String, void Function(dynamic)> ? events, Key? key}) -
const
-
ArcaneImage.lazy({required String src, required String alt, ArcaneStyleData? styles, String? classes, String? id, String? width, String? height, String? decoding, Map<
String, void Function(dynamic)> ? events, Key? key}) -
const
Properties
- alt → String
-
final
- classes → String?
-
final
- decoding → String?
-
final
-
events
→ Map<
String, void Function(dynamic)> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → String?
-
final
- id → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- loading → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- src → String
-
final
- styles → ArcaneStyleData?
-
final
- width → String?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited