ArcaneRadio class
Radio button component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneRadio
Constructors
- ArcaneRadio({required bool selected, String? label, String? description, CheckboxSize size = CheckboxSize.medium, CheckboxVariant variant = CheckboxVariant.primary, bool disabled = false, void onSelected()?, void onTap()?, Key? key})
-
const
Properties
- description → String?
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
final
- size → CheckboxSize
-
final
- variant → CheckboxVariant
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited