ArcaneCycleButton<T> class
A button that cycles through a list of values on each click.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneCycleButton
Constructors
-
ArcaneCycleButton({required List<
CycleOption< options, required T value, void onChanged(T value)?, CycleButtonVariant variant = CycleButtonVariant.outline, CycleButtonSize size = CycleButtonSize.medium, bool disabled = false, String? id, Map<T> >String, String> ? attributes, Key? key}) -
const
Properties
-
attributes
→ Map<
String, String> ? -
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onChanged → void Function(T value)?
-
final
-
options
→ List<
CycleOption< T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → CycleButtonSize
-
final
- value → T
-
final
- variant → CycleButtonVariant
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited