FAB class
A floating action button component.
Use style presets for cleaner code:
FAB(
icon: Icon(Icons.add),
style: FABStyle.primary,
)
- Inheritance
Constructors
- FAB({required Component icon, String? label, void onPressed()?, FABStyle? style, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, Key? key})
-
const
- FAB.destructive({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, Key? key})
-
Destructive FAB
const
- FAB.primary({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, Key? key})
-
Primary FAB
const
- FAB.success({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, Key? key})
-
Success FAB
const
- FAB.surface({required Component icon, String? label, void onPressed()?, FABSize size = FABSize.regular, bool disabled = false, FABPosition position = FABPosition.bottomRight, String? tooltip, Key? key})
-
Surface FAB
const
Properties
- disabled → bool
-
Whether the FAB is disabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component
-
The icon to display
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
Optional label for extended FAB
final
- onPressed → void Function()?
-
Click handler
final
- position → FABPosition
-
Position of the FAB
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → FABSize
-
FAB size
final
- style → FABStyle?
-
Style preset (preferred)
final
- tooltip → String?
-
Tooltip text
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited