ArcaneFileUpload class
File upload/dropzone component.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneFileUpload
Constructors
-
ArcaneFileUpload({List<
String> accept = const [], int? maxSize, bool multiple = false, void onFilesSelected(List<UploadedFile> )?, void onError(String error)?, FileUploadStyle style = FileUploadStyle.dropzone, FileUploadSize size = FileUploadSize.md, bool disabled = false, String? dropzoneText, String browseText = 'Browse files', String? helperText, String? label, Key? key}) -
const
-
ArcaneFileUpload.documents({int? maxSize, bool multiple = true, void onFilesSelected(List<
UploadedFile> )?, void onError(String error)?, FileUploadSize size = FileUploadSize.md, bool disabled = false, String? dropzoneText = 'Drag documents here or click to browse', String browseText = 'Select documents', String? helperText, String? label, Key? key}) -
const
-
ArcaneFileUpload.images({int? maxSize, bool multiple = true, void onFilesSelected(List<
UploadedFile> )?, void onError(String error)?, FileUploadSize size = FileUploadSize.md, bool disabled = false, String? dropzoneText = 'Drag images here or click to browse', String browseText = 'Select images', String? helperText, String? label, Key? key}) -
const
Properties
-
accept
→ List<
String> -
final
- browseText → String
-
final
- disabled → bool
-
final
- dropzoneText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- maxSize → int?
-
final
- multiple → bool
-
final
- onError → void Function(String error)?
-
final
-
onFilesSelected
→ void Function(List<
UploadedFile> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → FileUploadSize
-
final
- style → FileUploadStyle
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneFileUpload> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited