ArcaneFormattedInput class
A formatted/patterned input for structured data like dates, phone numbers, etc.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneFormattedInput
Constructors
- ArcaneFormattedInput({required FormattedValue initialValue, void onChanged(FormattedValue value)?, String? label, String? error, bool disabled = false, FormattedInputSize size = FormattedInputSize.md, Key? key})
-
const
- ArcaneFormattedInput.creditCard({void onChanged(FormattedValue value)?, String? label, String? error, bool disabled = false})
-
factory
- ArcaneFormattedInput.date({String? initialMonth, String? initialDay, String? initialYear, void onChanged(FormattedValue value)?, String? label, String? error, bool disabled = false})
-
factory
- ArcaneFormattedInput.phone({String? initialAreaCode, String? initialPrefix, String? initialLine, void onChanged(FormattedValue value)?, String? label, String? error, bool disabled = false})
-
factory
- ArcaneFormattedInput.time({String? initialHour, String? initialMinute, void onChanged(FormattedValue value)?, String? label, String? error, bool disabled = false})
-
factory
Properties
- disabled → bool
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → FormattedValue
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- onChanged → void Function(FormattedValue value)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → FormattedInputSize
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneFormattedInput> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited