InputPart class
A part of a formatted input (editable segment or static text).
Constructors
- InputPart.editable({int? length, double? width, String? placeholder, String inputType = 'text'})
-
const
- InputPart.static(String text)
-
const
Properties
- editable → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputType → String
-
final
- length → int?
-
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staticText → String?
-
final
- value → String?
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withValue(
String value) → InputPart
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited