ArcaneIconButton class

An icon-only button component.

Use style presets for cleaner code:

ArcaneIconButton(
  icon: Icon(Icons.close),
  style: IconButtonStyle.ghost,
)
Inheritance

Constructors

ArcaneIconButton({required Component icon, void onPressed()?, IconButtonStyle? style, @Deprecated('Use style parameter instead') ButtonVariant? variant, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
const
ArcaneIconButton.destructive({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
Destructive icon button
const
ArcaneIconButton.ghost({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
Ghost icon button (default minimal style)
const
ArcaneIconButton.outline({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
Outline icon button
const
ArcaneIconButton.primary({required Component icon, void onPressed()?, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip, Key? key})
Primary icon button
const

Properties

disabled bool
Whether the button is disabled
final
hashCode int
The hash code for this object.
no setterinherited
icon Component
The icon to display
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loading bool
Whether the button is loading
final
onPressed → void Function()?
Click handler
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size IconButtonSize
Button size
final
style IconButtonStyle?
Style preset (preferred)
final
tooltip String?
Optional tooltip text
final
variant ButtonVariant?
Button variant (legacy - use style instead)
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited