ArcaneOtpInput class
One-time password input with separate digit fields.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneOtpInput
Constructors
- ArcaneOtpInput({int length = 6, void onComplete(String)?, void onChange(String)?, String? value, bool obscure = false, OtpInputSize size = OtpInputSize.md, bool disabled = false, String? error, String? label, String? separator, int? separatorPosition, Key? key})
-
const
- ArcaneOtpInput.fourDigit({void onComplete(String)?, void onChange(String)?, String? value, bool obscure = false, OtpInputSize size = OtpInputSize.md, bool disabled = false, String? error, String? label, String? separator, int? separatorPosition, Key? key})
-
const
- ArcaneOtpInput.sixDigit({void onComplete(String)?, void onChange(String)?, String? value, bool obscure = false, OtpInputSize size = OtpInputSize.md, bool disabled = false, String? error, String? label, String? separator, int? separatorPosition, Key? key})
-
const
Properties
- disabled → bool
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- length → int
-
final
- obscure → bool
-
final
- onChange → void Function(String)?
-
final
- onComplete → void Function(String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → String?
-
final
- separatorPosition → int?
-
final
- size → OtpInputSize
-
final
- value → String?
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneOtpInput> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited