Search class

A search input component with optional icon and clear button.

Inheritance

Constructors

Search({String placeholder = 'Search...', String? value, void onChanged(String value)?, void onSubmitted(String value)?, bool showClear = true, bool loading = false, Component? icon, bool autofocus = false, bool disabled = false, Key? key})
const

Properties

autofocus bool
Whether to autofocus
final
disabled bool
Whether the input is disabled
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
Custom leading icon
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loading bool
Whether the search is loading
final
onChanged → void Function(String value)?
Callback when value changes
final
onSubmitted → void Function(String value)?
Callback when search is submitted
final
placeholder String
Placeholder text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showClear bool
Whether to show the clear button
final
value String?
The current value
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<Search>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited