ArcaneSelector<T> class
A dropdown selector component with extensive customization options.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneSelector
Constructors
-
ArcaneSelector({required List<
ArcaneSelectorOption< options, T? value, List<T> >T> ? values, void onChanged(T value)?, void onMultiChanged(List<T> values)?, String placeholder = 'Select...', bool disabled = false, bool clearable = false, bool searchable = false, bool multiSelect = false, String? label, String? helperText, String? error, SelectorSize size = SelectorSize.md, bool required = false, String? maxDropdownHeight, bool loading = false, String loadingText = 'Loading...', String emptyMessage = 'No options found', String searchPlaceholder = 'Search...', DropdownDirection dropdownDirection = DropdownDirection.down, bool closeOnSelect = true, bool showSelectedCount = true, Component? prefix, bool filterFn(ArcaneSelectorOption<T> option, String query)?, int? maxSelections, bool showCheckboxes = true, Key? key}) -
const
Properties
- clearable → bool
-
final
- closeOnSelect → bool
-
final
- disabled → bool
-
final
- dropdownDirection → DropdownDirection
-
final
- emptyMessage → String
-
final
- error → String?
-
final
-
filterFn
→ bool Function(ArcaneSelectorOption<
T> option, String query)? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- loading → bool
-
final
- loadingText → String
-
final
- maxDropdownHeight → String?
-
final
- maxSelections → int?
-
final
- multiSelect → bool
-
final
- onChanged → void Function(T value)?
-
final
-
onMultiChanged
→ void Function(List<
T> values)? -
final
-
options
→ List<
ArcaneSelectorOption< T> > -
final
- placeholder → String
-
final
- prefix → Component?
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchable → bool
-
final
- searchPlaceholder → String
-
final
- showCheckboxes → bool
-
final
- showSelectedCount → bool
-
final
- size → SelectorSize
-
final
- value → T?
-
final
-
values
→ List<
T> ? -
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneSelector< T> > -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited