Selector<T> class
A dropdown selector component.
- Inheritance
-
- Object
- Component
- StatefulComponent
- Selector
Constructors
Properties
- clearable → bool
-
Whether to allow clearing the selection
final
- disabled → bool
-
Whether the selector is disabled
final
- error → String?
-
Error message
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
Label for the field
final
- onChanged → void Function(T value)?
-
Callback when selection changes
final
-
options
→ List<
SelectorOption< T> > -
The available options
final
- placeholder → String
-
Placeholder text when no selection
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchable → bool
-
Whether the dropdown is searchable
final
- value → T?
-
The currently selected value
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< Selector< T> > -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited