ArcaneTextInput class
A styled text input component
Use style presets for cleaner code:
ArcaneTextInput(
style: InputStyle.standard,
size: InputSizeStyle.md,
)
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneTextInput
Constructors
- ArcaneTextInput({String? placeholder, InputType type = InputType.text, InputStyle? style, InputSizeStyle size = InputSizeStyle.md, bool disabled = false, bool required = false, bool readOnly = false, String? value, String? name, String? id, Component? prefix, Component? suffix, String? error, String? helperText, String? label, void onChange(String)?, void onFocus()?, void onBlur()?, void onSubmit(String)?, bool fullWidth = false, Key? key})
-
const
Properties
- disabled → bool
-
Whether input is disabled
final
- error → String?
-
Error message
final
- fullWidth → bool
-
Full width
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
Helper text
final
- id → String?
-
Input ID
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
Label text
final
- name → String?
-
Input name (for forms)
final
- onBlur → void Function()?
-
Blur callback
final
- onChange → void Function(String)?
-
Change callback
final
- onFocus → void Function()?
-
Focus callback
final
- onSubmit → void Function(String)?
-
Submit callback
final
- placeholder → String?
-
Input placeholder
final
- prefix → Component?
-
Prefix icon/text
final
- readOnly → bool
-
Whether input is read-only
final
- required → bool
-
Whether input is required
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → InputSizeStyle
-
Size preset
final
- style → InputStyle?
-
Style preset (preferred)
final
- suffix → Component?
-
Suffix icon/text
final
- type → InputType
-
Input type
final
- value → String?
-
Input value
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited