ArcaneTimePicker class
A time picker input with dropdown selection.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneTimePicker
Constructors
- ArcaneTimePicker({String? id, TimeOfDay? value, void onChanged(TimeOfDay?)?, String? label, String? placeholder, bool use24Hour = false, int minuteInterval = 1, bool disabled = false, String? error, bool clearable = true, bool showSeconds = false, ComponentSize size = ComponentSize.md, Key? key})
-
const
Properties
- clearable → bool
-
final
- disabled → bool
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- minuteInterval → int
-
final
- onChanged → void Function(TimeOfDay?)?
-
final
- placeholder → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSeconds → bool
-
final
- size → ComponentSize
-
final
- use24Hour → bool
-
final
- value → TimeOfDay?
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneTimePicker> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited