ArcaneToggleGroup class
A toggle group component for selecting one or multiple options.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneToggleGroup
Constructors
-
ArcaneToggleGroup({required List<
ToggleGroupItem> items, String? value, void onChanged(String?)?, ToggleGroupVariant variant = ToggleGroupVariant.defaultVariant, ToggleGroupSize size = ToggleGroupSize.md, bool disabled = false, Key? key}) -
const
-
ArcaneToggleGroup.multiple({required List<
ToggleGroupItem> items, Set<String> ? values, void onMultiChanged(Set<String> )?, ToggleGroupVariant variant = ToggleGroupVariant.defaultVariant, ToggleGroupSize size = ToggleGroupSize.md, bool disabled = false, Key? key}) -
const
Properties
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
ToggleGroupItem> -
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onChanged → void Function(String?)?
-
final
-
onMultiChanged
→ void Function(Set<
String> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ToggleGroupSize
-
final
- type → ToggleGroupType
-
final
- value → String?
-
final
-
values
→ Set<
String> ? -
final
- variant → ToggleGroupVariant
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited