ToggleGroupItem class

A toggle group item.

Constructors

ToggleGroupItem({required String value, required Component child, bool disabled = false})
const
ToggleGroupItem.text(String value, {String? label, bool disabled = false})
factory

Properties

child Component
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited