ToggleSwitch class
A toggle switch component (Supabase-style)
- Inheritance
-
- Object
- Component
- StatefulComponent
- ToggleSwitch
Constructors
Properties
- disabled → bool
-
Whether the switch is disabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
Optional label text
final
- labelLeft → bool
-
Whether to show the label on the left side
final
- onChanged → void Function(bool)?
-
Callback when the switch is toggled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → String
-
Size of the switch (sm, md, lg)
final
- value → bool
-
Whether the switch is on
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ToggleSwitch> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited