ArcaneExpander class
Expandable/collapsible component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneExpander
Constructors
- ArcaneExpander({required Component header, required Component child, bool initiallyExpanded = false, void onExpansionChanged(bool expanded)?, Component? leading, bool showIcon = true, EdgeInsets? contentPadding, bool maintainState = true, Key? key})
-
const
Properties
- child → Component
-
final
- contentPadding → EdgeInsets?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component
-
final
- initiallyExpanded → bool
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- leading → Component?
-
final
- maintainState → bool
-
final
- onExpansionChanged → void Function(bool expanded)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited