ArcaneToolbar class
A toolbar component for a horizontal bar of actions.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneToolbar
Constructors
-
ArcaneToolbar({required List<
Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, double gap = 8, EdgeInsets? padding, Key? key}) -
const
Properties
-
children
→ List<
Widget> -
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited