Column class
A column layout component (vertical flex).
- Inheritance
Constructors
-
Column({required List<
Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.stretch, MainAxisSize mainAxisSize = MainAxisSize.max, double gap = 0, Gap? gapSize, ArcaneStyleData? style, Key? key}) -
const
Properties
-
children
→ List<
Widget> -
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- gap → double
-
final
- gapSize → Gap?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- mainAxisSize → MainAxisSize
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ArcaneStyleData?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited