ArcaneFooter class
A website footer component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneFooter
Constructors
-
const
Properties
-
bottomLinks
→ List<
FooterLink> ? -
final
- copyright → String?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
linkGroups
→ List<
FooterLinkGroup> -
final
- logo → Component?
-
final
-
final
-
final
- onNewsletterSubmit → void Function(String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNewsletter → bool
-
final
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited