component/layout/gutter library

Classes

ArcaneBox
A container component with enum-based styling.
ArcaneGap
A flexible gap component.
ArcaneGutter
A spacing component that provides consistent gaps between elements.
ArcanePositioned
A positioned child for use within an ArcaneStack.
ArcaneStack
An ArcaneStack component for positioning children on top of each other.
GapProps
Gap component properties.
GutterProps
Gutter/spacing component properties.

Enums

GutterSize