HeroSection class

A hero section component (Supabase-style)

Inheritance

Constructors

HeroSection({required String headline, String? subheadline, Component? primaryCta, Component? secondaryCta, Component? badge, Component? media, bool centered = true, double verticalPadding = 80, double maxWidth = 800, Key? key})
const

Properties

badge Component?
Optional badge/pill above headline
final
centered bool
Whether to center content
final
hashCode int
The hash code for this object.
no setterinherited
headline String
Main headline text
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
maxWidth double
Maximum content width
final
media Component?
Optional media (video, image, etc.)
final
primaryCta Component?
Primary CTA component
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryCta Component?
Secondary CTA component
final
subheadline String?
Subheadline/description text
final
verticalPadding double
Vertical padding
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited