LogoCarousel class
An infinite scrolling logo carousel (Supabase-style)
- Inheritance
-
- Object
- Component
- StatelessComponent
- LogoCarousel
Constructors
Properties
- duration → int
-
Animation duration in seconds
final
- gap → double
-
Gap between logos
final
- grayscale → bool
-
Grayscale logos
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- logoHeight → double
-
Logo height
final
-
logos
→ List<
LogoItem> -
Logo items
final
- pauseOnHover → bool
-
Whether to pause on hover
final
- reverse → bool
-
Whether to reverse direction
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional title above the carousel
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited