RadioCards<T> class
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- RadioCards
Constructors
-
RadioCards({required List<
T> values, required String labelBuilder(T), T? value, void onChanged(T)?, String descriptionBuilder(T)?, Key? key}) -
const
Properties
- descriptionBuilder → String Function(T)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- labelBuilder → String Function(T)
-
final
- onChanged → void Function(T)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
final
-
values
→ List<
T> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited