RadioCards<T> class
A group of selectable cards where only one can be selected at a time.
- Inheritance
-
- Object
- Component
- StatefulComponent
- RadioCards
Constructors
-
RadioCards({required List<
RadioCardItem< items, T? value, void onChanged(T value)?, double gap = 12, bool wrap = true, double? cardWidth, Key? key})T> > -
const
Properties
- cardWidth → double?
-
Card width (null for auto)
final
- gap → double
-
Gap between cards
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
RadioCardItem< T> > -
The items to display
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onChanged → void Function(T value)?
-
Callback when selection changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
The currently selected value
final
- wrap → bool
-
Whether to wrap cards
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< RadioCards< T> > -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited