ArcaneResizable class
A resizable panel group with draggable dividers.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneResizable
Constructors
-
ArcaneResizable({required List<
ResizablePanelData> panels, ResizeDirection direction = ResizeDirection.horizontal, double handleSize = 8, bool showGrip = true, Key? key}) -
const
-
factory
- ArcaneResizable.splitView({required Widget top, required Widget bottom, double topSize = 50, double topMinSize = 20, double topMaxSize = 80, Key? key})
-
factory
Properties
- direction → ResizeDirection
-
final
- handleSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
panels
→ List<
ResizablePanelData> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGrip → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited