ArcaneVirtualScroll<T> class
A virtualized scroll list for large datasets.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneVirtualScroll
Constructors
-
ArcaneVirtualScroll({required List<
T> items, required Component itemBuilder(BuildContext context, T item, int index), required double itemHeight, required String height, int overscan = 3, Key? key}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → String
-
final
- itemBuilder → Component Function(BuildContext context, T item, int index)
-
final
- itemHeight → double
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- overscan → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneVirtualScroll< T> > -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited