ArcaneScrollRailLayout class

A layout component that combines a scroll rail with main content.

Inheritance

Constructors

ArcaneScrollRailLayout({required Component rail, required Component child, ScrollRailPosition railPosition = ScrollRailPosition.left, ScrollRailSize railSize = ScrollRailSize.md, String? railWidth, String headerHeight = '0px', bool showBorder = true, String? railBackground, String? contentBackground, Key? key})
const

Properties

child Component
final
contentBackground String?
final
hashCode int
The hash code for this object.
no setterinherited
headerHeight String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
rail Component
final
railBackground String?
final
railPosition ScrollRailPosition
final
railSize ScrollRailSize
final
railWidth String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBorder bool
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited