Section class
A section component for grouping related content with an optional header.
- Inheritance
-
- Object
- Component
- StatelessComponent
- Section
Constructors
Properties
- card → bool
-
Whether this is a card-style section
final
-
children
→ List<
Component> -
The child components
final
- gap → double
-
Gap between children
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → String?
-
Optional section header text
final
- headerComponent → Component?
-
Optional header component (overrides header text)
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- padding → EdgeInsets?
-
Custom padding
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDivider → bool
-
Whether to show a divider after the header
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited