ArcaneSectionHeader class
A reusable section header with label, heading, and description.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneSectionHeader
Constructors
- ArcaneSectionHeader({String? label, required String heading, String? description, SectionHeaderAlign align = SectionHeaderAlign.center, String? descriptionMaxWidth, String? marginBottom, String? labelColor, String? headingColor, String? descriptionColor, Key? key})
-
const
- ArcaneSectionHeader.center({String? label, required String heading, String? description, String? descriptionMaxWidth, String? marginBottom, String? labelColor, String? headingColor, String? descriptionColor, Key? key})
-
const
- ArcaneSectionHeader.left({String? label, required String heading, String? description, String? descriptionMaxWidth, String? marginBottom, String? labelColor, String? headingColor, String? descriptionColor, Key? key})
-
const
Properties
- align → SectionHeaderAlign
-
final
- description → String?
-
final
- descriptionColor → String?
-
final
- descriptionMaxWidth → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → String
-
final
- headingColor → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- labelColor → String?
-
final
- marginBottom → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited