ArcaneDropdownMenu class

Dropdown menu component.

Inheritance

Constructors

ArcaneDropdownMenu({required Widget trigger, required List<ArcaneMenuItem> items, DropdownAlignment alignment = DropdownAlignment.left, double? width, Key? key})
const

Properties

alignment DropdownAlignment
final
hashCode int
The hash code for this object.
no setterinherited
items List<ArcaneMenuItem>
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger Widget
final
width double?
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneDropdownMenu>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited