BottomNavigationBar class
A bottom navigation bar component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- BottomNavigationBar
Constructors
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Height of the navigation bar
final
-
items
→ List<
BottomNavItem> -
The navigation items
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onChanged → void Function(int index)?
-
Callback when selection changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex → int
-
The currently selected index
final
- showLabels → bool
-
Whether to show labels
final
- showSelectedLabels → bool
-
Whether to show labels only when selected
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited