MobileMenu class
A mobile hamburger menu (Supabase-style)
- Inheritance
-
- Object
- Component
- StatefulComponent
- MobileMenu
Constructors
-
MobileMenu({required List<
MobileNavItem> items, Component? logo, Component? cta, void onClose()?, bool isOpen = false, Key? key}) -
const
Properties
- cta → Component?
-
Optional CTA button
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
Whether the menu is open
final
-
items
→ List<
MobileNavItem> -
Navigation items
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- logo → Component?
-
Optional logo
final
- onClose → void Function()?
-
Close callback
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< MobileMenu> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited