ArcaneDropdownItem class
Dropdown item component with multiple style variants.
Supports simple inline icons and a compact style for dense lists.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneDropdownItem
Constructors
- ArcaneDropdownItem({required String label, required String href, required ArcaneGlyph icon, String? description, bool isExternal = false, ArcaneDropdownItemStyle variant = ArcaneDropdownItemStyle.simple, Key? key})
-
const
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String
-
final
- icon → ArcaneGlyph
-
final
- isExternal → bool
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → ArcaneDropdownItemStyle
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneDropdownItem> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited