ArcanePagination class
Page navigation component.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcanePagination
Constructors
- ArcanePagination({required int currentPage, required int totalPages, void onPageChange(int page)?, PaginationStyle style = PaginationStyle.outline, PaginationSize size = PaginationSize.md, int siblingCount = 1, bool showFirstLast = true, bool showPrevNext = true, bool showPageCount = false, String previousText = '\u{2190}', String nextText = '\u{2192}', Key? key})
-
const
- ArcanePagination.simple({required int currentPage, required int totalPages, void onPageChange(int page)?, PaginationSize size = PaginationSize.md, String previousText = '\u{2190} Previous', String nextText = 'Next \u{2192}', Key? key})
-
const
Properties
- currentPage → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- nextText → String
-
final
- onPageChange → void Function(int page)?
-
final
- previousText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showFirstLast → bool
-
final
- showPageCount → bool
-
final
- showPrevNext → bool
-
final
- siblingCount → int
-
final
- size → PaginationSize
-
final
- style → PaginationStyle
-
final
- totalPages → int
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited