ArcaneSidebar class
Sidebar navigation component.
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneSidebar
Constructors
Properties
-
children
→ List<
Widget> -
final
- collapsed → bool
-
final
- collapsedWidth → double
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onCollapseChanged → void Function(bool collapsed)?
-
final
- rightSide → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCollapseToggle → bool
-
final
- width → double
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneSidebar> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited