ArcaneBottomFloatingBanner class
Bottom floating banner that slides up with optional countdown timer.
Great for limited-time offers and flash sales.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneBottomFloatingBanner
Constructors
Properties
- countdownDuration → Duration?
-
final
- ctaHref → String?
-
final
- ctaText → String?
-
final
- delayMs → int
-
final
- expiresAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- message → String
-
final
- onCtaClick → void Function()?
-
final
- onDismiss → void Function()?
-
final
- promoCode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneBottomFloatingBanner> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited