FillScreen class
A screen that fills the entire viewport.
- Inheritance
-
- Object
- Component
- StatelessComponent
- FillScreen
Constructors
-
FillScreen({required Component child, Component? header, String? title, String? subtitle, List<
Component> ? actions, Component? sidebar, bool sidebarRight = false, Component? background, double? loadingProgress, bool loadingIndeterminate = false, void onBack()?, bool scrollable = true, Key? key}) -
const
Properties
-
actions
→ List<
Component> ? -
Trailing actions
final
- background → Component?
-
Background component
final
- child → Component
-
Main content
final
-
Footer component
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component?
-
Header bar
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- loadingIndeterminate → bool
-
Whether loading is indeterminate
final
- loadingProgress → double?
-
Loading progress (0.0 to 1.0)
final
- onBack → void Function()?
-
Back button handler
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollable → bool
-
Whether to scroll the content
final
-
Sidebar component
final
-
Whether sidebar is on the right
final
- subtitle → String?
-
Subtitle text
final
- title → String?
-
Title text
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited