NavigationScreen class
A screen with built-in navigation (sidebar or bottom nav).
- Inheritance
-
- Object
- Component
- StatefulComponent
- NavigationScreen
Constructors
-
const
Properties
- breakpoint → double
-
Breakpoint for switching between modes in auto mode
final
-
destinations
→ List<
NavigationDestination> -
Navigation destinations
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialIndex → int
-
Initial selected index
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- mode → NavigationMode
-
Navigation mode (auto, sidebar, bottom, rail)
final
-
Callback when navigation changes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Initial sidebar collapsed state
final
-
Whether sidebar is collapsible
final
-
Footer for sidebar mode
final
-
Header for sidebar mode
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< NavigationScreen> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited