ArcaneNotFoundAction class
A recovery link rendered by ArcaneNotFoundPage.
Constructors
- ArcaneNotFoundAction({required String label, required String href, bool primary = false, String? ariaLabel})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited