ArcaneNotFoundPage constructor
const
ArcaneNotFoundPage({
- String? id,
- String applicationName = 'Application',
- String code = '404',
- String title = 'Page not found',
- String description = 'The page you requested does not exist or is no longer available.',
- String? requestedPath,
- String? diagnosticCode,
- List<
ArcaneNotFoundAction> actions = const <ArcaneNotFoundAction>[ArcaneNotFoundAction(label: 'Return home', href: '/', primary: true)], - bool standalone = true,
- String classes = '',
- Map<
String, String> attributes = const <String, String>{}, - Key? key,
Implementation
const ArcaneNotFoundPage({
this.id,
this.applicationName = 'Application',
this.code = '404',
this.title = 'Page not found',
this.description =
'The page you requested does not exist or is no longer available.',
this.requestedPath,
this.diagnosticCode,
this.actions = const <ArcaneNotFoundAction>[
ArcaneNotFoundAction(label: 'Return home', href: '/', primary: true),
],
this.standalone = true,
this.classes = '',
this.attributes = const <String, String>{},
super.key,
});