ArcaneApp class
Root application component for Arcane Jaspr apps.
The stylesheet parameter is required - there is no default stylesheet. You must explicitly choose a stylesheet for your app:
- ShadcnStylesheet - Clean, minimal ShadCN-inspired design
- CodexStylesheet - Premium dark-first system with restrained accent atmosphere (rainbow is opt-in)
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- ArcaneApp
Constructors
-
ArcaneApp({required ArcaneStylesheet stylesheet, Brightness brightness = Brightness.dark, required Widget child, String? title, String? description, List<
Widget> ? head, bool includeFallbackScripts = true, Key? key}) -
const
Properties
- brightness → Brightness
-
final
- child → Widget
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
head
→ List<
Widget> ? -
final
- includeFallbackScripts → bool
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stylesheet → ArcaneStylesheet
-
final
- title → String?
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneApp> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited