ArcaneApp class

Root application component for Arcane Jaspr apps.

Wraps the app with theme provider and applies CSS custom properties.

Inheritance

Constructors

ArcaneApp({ArcaneTheme theme = const ArcaneTheme(), required Component child, String? title, String? description, List<Component>? head, Key? key})
const

Properties

child Component
The child component to render
final
description String?
Optional meta description
final
hashCode int
The hash code for this object.
no setterinherited
Optional additional head elements
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme ArcaneTheme
The theme configuration
final
title String?
Optional document title
final

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneApp>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final