HeadElementData class
Data for head element injection
Constructors
-
HeadElementData({required String tag, Map<
String, String> ? attributes, String? textContent}) -
const
- HeadElementData.link(String href, {String rel = 'stylesheet'})
-
factory
- HeadElementData.preconnect(String href, {bool crossorigin = false})
-
factory
- HeadElementData.style(String css)
-
factory
Properties
-
attributes
→ Map<
String, String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
final
- textContent → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited