Icons class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- calendar → IconData
-
no setter
- check → IconData
-
no setter
- chevronDown → IconData
-
no setter
- chevronLeft → IconData
-
no setter
- chevronRight → IconData
-
no setter
- chevronUp → IconData
-
no setter
- circleAlert → IconData
-
no setter
- clock3 → IconData
-
no setter
- image → IconData
-
no setter
-
no setter
- moreHorizontal → IconData
-
no setter
- palette → IconData
-
no setter
- pencil → IconData
-
no setter
- plus → IconData
-
no setter
- search → IconData
-
no setter
- sparkles → IconData
-
no setter
- trash2 → IconData
-
no setter
- x → IconData
-
no setter