Headline class
A styled headline component (Supabase-style typography)
- Inheritance
-
- Object
- Component
- StatelessComponent
- Headline
Constructors
- Headline(String content, {HeadlineLevel level = HeadlineLevel.h1, String? color, String align = 'left', String? className, bool gradient = false, Key? key})
-
const
- Headline.h1(String content, {String? color, String align = 'left', String? className, bool gradient = false, Key? key})
-
H1 headline
const
- Headline.h2(String content, {String? color, String align = 'left', String? className, bool gradient = false, Key? key})
-
H2 headline
const
- Headline.h3(String content, {String? color, String align = 'left', String? className, bool gradient = false, Key? key})
-
H3 headline
const
- Headline.h4(String content, {String? color, String align = 'left', String? className, bool gradient = false, Key? key})
-
H4 headline
const
Properties
- align → String
-
Text alignment
final
- className → String?
-
Additional CSS classes
final
- color → String?
-
Optional custom color
final
- content → String
-
The headline text
final
- gradient → bool
-
Whether to use gradient text (accent gradient)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- level → HeadlineLevel
-
The headline level (h1-h6)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited