ArcaneAlert class

Inline alert component for important messages that need user attention.

Inheritance

Constructors

ArcaneAlert({required AlertSeverity severity, String? title, String? message, Component? child, AlertVariant variant = AlertVariant.subtle, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Component? action, Key? key})
const
ArcaneAlert.error({String? title, String? message, Component? child, AlertVariant variant = AlertVariant.subtle, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Component? action, Key? key})
const
ArcaneAlert.info({String? title, String? message, Component? child, AlertVariant variant = AlertVariant.subtle, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Component? action, Key? key})
const
ArcaneAlert.success({String? title, String? message, Component? child, AlertVariant variant = AlertVariant.subtle, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Component? action, Key? key})
const
ArcaneAlert.warning({String? title, String? message, Component? child, AlertVariant variant = AlertVariant.subtle, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Component? action, Key? key})
const

Properties

action Component?
final
child Component?
final
dismissible bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
message String?
final
onDismiss → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity AlertSeverity
final
showIcon bool
final
title String?
final
variant AlertVariant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited