MetricDisplay class
A metric display with label
- Inheritance
-
- Object
- Component
- StatelessComponent
- MetricDisplay
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Optional icon
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String
-
Metric label
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trend → String?
-
Optional trend indicator
final
- trendPositive → bool
-
Whether trend is positive
final
- value → String
-
Metric value
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited