ArcaneAvatar class
Avatar component for displaying user images or initials.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneAvatar
Constructors
- ArcaneAvatar({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, AvatarShape shape = AvatarShape.circle, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
-
const
- ArcaneAvatar.circle({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
-
const
- ArcaneAvatar.rounded({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
-
const
- ArcaneAvatar.square({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
-
const
Properties
- borderColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
final
- initials → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onTap → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → AvatarShape
-
final
- showStatus → bool
-
final
- size → AvatarSize
-
final
- statusColor → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited