ArcaneAvatar class

Avatar component for displaying user images or initials

Use style presets for cleaner code:

ArcaneAvatar(
  initials: 'JD',
  style: AvatarStyle.circle,
  size: AvatarSize.lg,
)
Inheritance

Constructors

ArcaneAvatar({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, AvatarStyle? style, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
const
ArcaneAvatar.circle({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
Circle avatar (default)
const
ArcaneAvatar.rounded({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
Rounded square avatar
const
ArcaneAvatar.square({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?, Key? key})
Square avatar
const

Properties

borderColor String?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
final
initials String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showStatus bool
final
size AvatarSize
final
statusColor String?
final
style AvatarStyle?
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited