Badge class

A pill-shaped badge/label component (Supabase-style)

Inheritance

Constructors

Badge(String label, {Component? icon, BadgeVariant variant = BadgeVariant.default_, String size = 'md', Key? key})
const
Badge.destructive(String label, {Component? icon, String size = 'md', Key? key})
Destructive badge
const
Badge.outline(String label, {Component? icon, String size = 'md', Key? key})
Outline badge
const
Badge.primary(String label, {Component? icon, String size = 'md', Key? key})
Primary badge
const
Badge.success(String label, {Component? icon, String size = 'md', Key? key})
Success badge
const
Badge.warning(String label, {Component? icon, String size = 'md', Key? key})
Warning badge
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Component?
Optional leading icon
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
The badge text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String
Badge size (sm, md, lg)
final
variant BadgeVariant
Badge variant
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited