Bar class

An app bar / header component.

Inheritance

Constructors

Bar({String? titleText, Component? title, String? subtitleText, Component? subtitle, List<Component>? leading, List<Component>? trailing, BarBackButtonMode backButton = BarBackButtonMode.auto, void onBack()?, bool transparent = false, bool centerTitle = false, double? height, EdgeInsets? padding, Key? key})
const

Properties

backButton BarBackButtonMode
Back button mode
final
centerTitle bool
Whether to center the title
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Custom height
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
leading List<Component>?
Leading components
final
onBack → void Function()?
Custom back button handler
final
padding EdgeInsets?
Custom padding
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle Component?
Subtitle component (overrides subtitleText)
final
subtitleText String?
Subtitle text
final
title Component?
Title component (overrides titleText)
final
titleText String?
Title text
final
trailing List<Component>?
Trailing components
final
transparent bool
Whether the bar is transparent
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

styles List<StyleRule>
final