ArcaneFeatureRow class
A feature/benefit row commonly used in pricing or comparison sections.
Displays a feature with check/x indicator for included/excluded states. Supports circular icon containers, strikethrough, and tooltips.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneFeatureRow
Constructors
- ArcaneFeatureRow({required String feature, bool included = true, String? includedColor, String? excludedColor, bool strikethrough = true, bool circularIcon = true, String? tooltip, String? iconSize, Key? key})
-
const
- ArcaneFeatureRow.excluded({required String feature, String? excludedColor, bool strikethrough = true, bool circularIcon = true, String? tooltip, String? iconSize, Key? key})
-
Creates a feature row for an excluded feature.
const
- ArcaneFeatureRow.included({required String feature, String? includedColor, bool strikethrough = true, bool circularIcon = true, String? tooltip, String? iconSize, Key? key})
-
Creates a feature row for an included feature.
const
Properties
- circularIcon → bool
-
final
- excludedColor → String?
-
final
- feature → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → String?
-
final
- included → bool
-
final
- includedColor → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strikethrough → bool
-
final
- tooltip → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited