ArcaneChip class

Chip/tag component for labels and filters

Inheritance

Constructors

ArcaneChip({required String label, String? icon, String? color, String? backgroundColor, String size = 'medium', bool outlined = false, bool removable = false})
const

Properties

backgroundColor String?
final
color String?
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
final
outlined bool
final
removable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited