ArcaneCodeWindow class
A code display window with macOS-style window chrome.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneCodeWindow
Constructors
- ArcaneCodeWindow({required String code, String? title, CodeWindowStyle style = CodeWindowStyle.dark, bool showButtons = true, String? codeColor, String? headerBackground, String? bodyBackground, Key? key})
-
const
- ArcaneCodeWindow.terminal({required String code, String? title, bool showButtons = true, String? codeColor, String? headerBackground, String? bodyBackground, Key? key})
-
const
Properties
- bodyBackground → String?
-
final
- code → String
-
final
- codeColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackground → String?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showButtons → bool
-
final
- style → CodeWindowStyle
-
final
- title → String?
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited