DataTable<T> class
- Inheritance
-
- Object
- Component
- StatefulComponent
- StatefulWidget
- DataTable
Constructors
-
DataTable({required List<
T> items, required List<DataColumn< columns, void onRowTap(T item)?, bool selectable = false, Set<T> >T> ? selectedItems, void onSelectionChanged(Set<T> selected)?, bool showDividers = true, bool showHeader = true, bool stickyHeader = false, String emptyMessage = 'No data available', Key? key}) -
const
Properties
-
columns
→ List<
DataColumn< T> > -
final
- emptyMessage → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- onRowTap → void Function(T item)?
-
final
-
onSelectionChanged
→ void Function(Set<
T> selected)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectable → bool
-
final
-
selectedItems
→ Set<
T> ? -
final
- showDividers → bool
-
final
- showHeader → bool
-
final
- stickyHeader → bool
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< DataTable< T> > -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited