GradientGlass class
A gradient glass effect
- Inheritance
-
- Object
- Component
- StatelessComponent
- GradientGlass
Constructors
- GradientGlass({required Component child, double blur = 12.0, String? gradientStart, String? gradientEnd, double opacity = 0.2, EdgeInsets? padding, double? radius, String direction = 'to bottom right', Key? key})
-
const
Properties
- blur → double
-
final
- child → Component
-
final
- direction → String
-
final
- gradientEnd → String?
-
final
- gradientStart → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- opacity → double
-
final
- padding → EdgeInsets?
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited