ArcaneGradientText class
Text with gradient color.
Supports multiple ways to define gradients:
- Simple two-color: gradientStart and gradientEnd
- Multi-color:
colorslist of ArcaneColor values - Custom stops: colorStops list of GradientStop with positions
- Raw CSS: gradient string for full control
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneGradientText
Constructors
-
ArcaneGradientText({required String content, String? gradient, String? gradientStart, String? gradientEnd, String? gradientAngle, List<
GradientStop> ? colorStops, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key}) -
const
- ArcaneGradientText.accent({required String content, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key})
-
Accent gradient using accent color variations.
const
- ArcaneGradientText.brand({required String content, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key})
-
Brand gradient using primary and accent colors.
const
-
ArcaneGradientText.custom({required String content, required List<
GradientStop> stops, String? gradientAngle = '135deg', String fontSize = 'inherit', String fontWeight = 'inherit', Key? key}) -
Creates gradient text with custom color stops for precise control.
const
- ArcaneGradientText.error({required String content, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key})
-
Error/destructive gradient.
const
-
ArcaneGradientText.fromColors({required String content, required List<
ArcaneColor> colors, String angle = '135deg', String fontSize = 'inherit', String fontWeight = 'inherit', Key? key}) -
Creates gradient text from a list of ArcaneColor values.
factory
- ArcaneGradientText.rainbow({required String content, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key})
-
Rainbow gradient cycling through multiple colors.
const
- ArcaneGradientText.success({required String content, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key})
-
Success gradient using success color.
const
- ArcaneGradientText.warning({required String content, String fontSize = 'inherit', String fontWeight = 'inherit', Key? key})
-
Warning gradient using warning color.
const
Properties
-
colorStops
→ List<
GradientStop> ? -
final
- content → String
-
final
- fontSize → String
-
final
- fontWeight → String
-
final
- gradient → String?
-
final
- gradientAngle → String?
-
final
- gradientEnd → String?
-
final
- gradientStart → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited