ArcaneHovercard class
A floating card that appears on hover with rich, interactive content.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcaneHovercard
Constructors
Properties
- closeDelay → int
-
final
- content → Component
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- offset → int
-
final
- onOpenChange → void Function(bool isOpen)?
-
final
- openDelay → int
-
final
- position → HovercardPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
final
- trigger → Component
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcaneHovercard> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited