ArcaneMap class
Unified map component supporting both world and USA maps.
Renders an interactive SVG map with optional location pins, region highlighting, and tooltips.
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneMap
Constructors
-
ArcaneMap({MapType type = MapType.world, List<
MapLocation> locations = const [], MapLocationCallback? onLocationTap, MapLocationCallback? onLocationHover, MapRegionCallback? onRegionTap, MapRegionCallback? onRegionHover, Component tooltipBuilder(MapLocation)?, MapStyle style = const MapStyle(), bool showTooltips = true, String? height, Set<String> activeRegions = const {}, bool debugMode = false, Key? key}) -
const
Properties
-
activeRegions
→ Set<
String> -
Set of region codes that are highlighted/active.
final
- debugMode → bool
-
Enable debug mode to show coordinates on hover.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → String?
-
Optional fixed height (CSS value).
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
locations
→ List<
MapLocation> -
Location pins to display on the map.
final
- onLocationHover → MapLocationCallback?
-
Callback when hovering over a location pin.
final
- onLocationTap → MapLocationCallback?
-
Callback when a location pin is tapped.
final
- onRegionHover → MapRegionCallback?
-
Callback when hovering over a region.
final
- onRegionTap → MapRegionCallback?
-
Callback when a region (state/country) is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTooltips → bool
-
Whether to show tooltips on hover.
final
- style → MapStyle
-
Style configuration for the map.
final
- tooltipBuilder → Component Function(MapLocation)?
-
Custom tooltip builder for location pins.
final
- type → MapType
-
The type of map to display.
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited