MapLocation class
A location pin on the map.
Constructors
Properties
- code → String?
-
Optional custom code (e.g., airport code 'JFK').
final
- description → String?
-
Optional description shown in tooltip.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this location.
final
- isActive → bool
-
Whether this location is in an active/highlighted state.
final
- latitude → double
-
Latitude coordinate (-90 to 90).
final
- longitude → double
-
Longitude coordinate (-180 to 180).
final
-
metadata
→ Map<
String, dynamic> ? -
Optional custom metadata.
final
- name → String
-
Display name for the location.
final
- region → String?
-
Optional region/country name.
final
- regionCode → String?
-
Optional region code (e.g., 'US', 'CA', 'NY').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? id, String? name, double? latitude, double? longitude, String? region, String? regionCode, String? code, String? description, Map< String, dynamic> ? metadata, bool? isActive}) → MapLocation -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited