MapRegion class
A region on the map (state or country).
Properties
- code → String
-
Region code (e.g., 'CA', 'US', 'NY').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Full region name (e.g., 'California', 'United States').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- svgPath → String
-
SVG path data for rendering the region.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited