MapStyle class
Style configuration for ArcaneMap.
Uses explicit hex colors for reliability across all themes.
Constructors
- MapStyle({String backgroundColor = '#111827', String regionFill = '#374151', String regionStroke = '#4b5563', String strokeWidth = '0.5', String regionHoverFill = '#4b5563', String regionActiveFill = '#3b82f6', String pinColor = '#3b82f6', String pinHoverColor = '#60a5fa', String pinActiveColor = '#22c55e', double pinSize = 6, double pinGlowIntensity = 0.3, String pinGlowColor = '#3b82f6', String tooltipBackground = '#1e1e2e', String tooltipBorder = '#4b5563', String tooltipTextColor = '#f8fafc', String tooltipSecondaryColor = '#9ca3af'})
-
const
Properties
- backgroundColor → String
-
Background/ocean color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pinActiveColor → String
-
Pin color when active.
final
- pinColor → String
-
Default pin color.
final
- pinGlowColor → String
-
Pin glow color.
final
- pinGlowIntensity → double
-
Pin glow intensity (0.0 to 1.0).
final
- pinHoverColor → String
-
Pin color on hover.
final
- pinSize → double
-
Pin size in SVG units.
final
- regionActiveFill → String
-
Fill color for active/selected regions.
final
- regionFill → String
-
Default fill color for regions (land/states).
final
- regionHoverFill → String
-
Fill color when hovering over a region.
final
- regionStroke → String
-
Stroke color for region borders.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → String
-
Stroke width for region borders.
final
- tooltipBackground → String
-
Tooltip background color.
final
- tooltipBorder → String
-
Tooltip border color.
final
- tooltipSecondaryColor → String
-
Tooltip secondary/muted text color.
final
- tooltipTextColor → String
-
Tooltip primary text color.
final
Methods
-
copyWith(
{String? backgroundColor, String? regionFill, String? regionStroke, String? strokeWidth, String? regionHoverFill, String? regionActiveFill, String? pinColor, String? pinHoverColor, String? pinActiveColor, double? pinSize, double? pinGlowIntensity, String? pinGlowColor, String? tooltipBackground, String? tooltipBorder, String? tooltipTextColor, String? tooltipSecondaryColor}) → MapStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited