ArcanePopover class
A floating content panel that appears relative to a trigger element.
- Inheritance
-
- Object
- Component
- StatefulComponent
- ArcanePopover
Constructors
- ArcanePopover({required Component trigger, required Component content, PopoverPosition position = PopoverPosition.bottom, PopoverTrigger triggerType = PopoverTrigger.click, bool? isOpen, void onOpenChange(bool isOpen)?, bool showArrow = true, bool closeOnOutsideClick = true, bool closeOnEscape = true, int offset = 8, int openDelay = 0, int closeDelay = 0, Key? key})
-
const
Properties
- closeDelay → int
-
final
- closeOnEscape → bool
-
final
- closeOnOutsideClick → bool
-
final
- content → Component
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- offset → int
-
final
- onOpenChange → void Function(bool isOpen)?
-
final
- openDelay → int
-
final
- position → PopoverPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
final
- trigger → Component
-
final
- triggerType → PopoverTrigger
-
final
Methods
-
createElement(
) → Element -
Creates a StatefulElement to manage this component's location in the tree.
inherited
-
createState(
) → State< ArcanePopover> -
Creates the mutable state for this component at a given location in the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited