ArcaneProgressBar class
Progress bar component with various styles
Use style presets for cleaner code:
ArcaneProgressBar(
value: 0.75,
style: ProgressStyle.success,
)
- Inheritance
-
- Object
- Component
- StatelessComponent
- ArcaneProgressBar
Constructors
- ArcaneProgressBar({required double value, String? label, ProgressSize size = ProgressSize.md, ProgressStyle? style, bool showPercentage = false, bool animated = true, Key? key})
-
const
- ArcaneProgressBar.error({required double value, String? label, ProgressSize size = ProgressSize.md, bool showPercentage = false, bool animated = true, Key? key})
-
Error progress bar
const
- ArcaneProgressBar.standard({required double value, String? label, ProgressSize size = ProgressSize.md, bool showPercentage = false, bool animated = true, Key? key})
-
Standard progress bar
const
- ArcaneProgressBar.success({required double value, String? label, ProgressSize size = ProgressSize.md, bool showPercentage = false, bool animated = true, Key? key})
-
Success progress bar
const
- ArcaneProgressBar.warning({required double value, String? label, ProgressSize size = ProgressSize.md, bool showPercentage = false, bool animated = true, Key? key})
-
Warning progress bar
const
Properties
- animated → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPercentage → bool
-
final
- size → ProgressSize
-
final
- style → ProgressStyle?
-
final
- value → double
-
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited