ArcaneProgressBar class

Progress bar component with various styles

Inheritance

Constructors

ArcaneProgressBar({required double value, String? label, String height = '8px', String? gradientStart, String? gradientEnd, bool showPercentage = false, bool animated = true, String? backgroundColor})
const

Properties

animated bool
final
backgroundColor String?
final
gradientEnd String?
final
gradientStart String?
final
hashCode int
The hash code for this object.
no setterinherited
height String
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPercentage bool
final
value double
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited