ArcaneSeparator class
A visual separator/divider component.
Combines features from the previous ArcaneDivider and ArcaneSeparator into a single unified component with support for:
- Horizontal and vertical orientations
- Visual variants (standard, subtle, bold)
- Dashed line style
- Labels and icons in the middle
- Custom colors
- Inheritance
-
- Object
- Component
- StatelessComponent
- StatelessWidget
- ArcaneSeparator
Constructors
- ArcaneSeparator({SeparatorOrientation orientation = SeparatorOrientation.horizontal, SeparatorVariant variant = SeparatorVariant.standard, String? label, Widget? icon, String? color, bool dashed = false, bool decorative = true, double? margin, double? height, Key? key})
-
const
- ArcaneSeparator.bold({SeparatorOrientation orientation = SeparatorOrientation.horizontal, String? label, Widget? icon, String? color, bool dashed = false, double? margin, double? height, Key? key})
-
Creates a bold (thicker) separator.
const
- ArcaneSeparator.dashed({SeparatorOrientation orientation = SeparatorOrientation.horizontal, SeparatorVariant variant = SeparatorVariant.standard, String? label, Widget? icon, String? color, double? margin, double? height, Key? key})
-
Creates a dashed separator.
const
- ArcaneSeparator.subtle({SeparatorOrientation orientation = SeparatorOrientation.horizontal, String? label, Widget? icon, String? color, bool dashed = false, double? margin, double? height, Key? key})
-
Creates a subtle (muted) separator.
const
- ArcaneSeparator.vertical({SeparatorVariant variant = SeparatorVariant.standard, String? color, bool dashed = false, bool decorative = true, double? margin, double? height, Key? key})
-
Creates a vertical separator.
const
- ArcaneSeparator.withIcon({required Widget icon, SeparatorVariant variant = SeparatorVariant.standard, String? color, bool dashed = false, double? margin, Key? key})
-
Creates a separator with an icon in the middle.
const
- ArcaneSeparator.withLabel({required String label, SeparatorVariant variant = SeparatorVariant.standard, String? color, bool dashed = false, double? margin, Key? key})
-
Creates a separator with a text label in the middle.
const
Properties
- color → String?
-
final
- dashed → bool
-
final
- decorative → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- icon → Widget?
-
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String?
-
final
- margin → double?
-
final
- orientation → SeparatorOrientation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → SeparatorVariant
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited