StaticTable class
A static table component for displaying simple tabular data.
- Inheritance
-
- Object
- Component
- StatelessComponent
- StaticTable
Constructors
Properties
-
alignments
→ List<
TextAlign> ? -
Column alignments
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
String> -
Table headers
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
-
rows
→ List<
List< Component> > -
Table rows (each row is a list of cell contents)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDividers → bool
-
Whether to show row dividers
final
- showHeader → bool
-
Whether to show the header
final
- stickyHeader → bool
-
Whether the header is sticky
final
- striped → bool
-
Whether to stripe alternate rows
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited