Tile class
A list tile component for displaying items in a list.
- Inheritance
Constructors
Properties
- dense → bool
-
Whether to use dense layout
final
- disabled → bool
-
Whether the tile is disabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- leading → Component?
-
Leading component (usually an icon or avatar)
final
- onTap → void Function()?
-
Click handler
final
- padding → EdgeInsets?
-
Custom padding
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
Whether the tile is selected
final
- subtitle → String?
-
Subtitle text
final
- subtitleWidget → Component?
-
Subtitle component (overrides subtitle string)
final
- title → String?
-
Title text
final
- titleWidget → Component?
-
Title component (overrides title string)
final
- trailing → Component?
-
Trailing component (usually an action button or info)
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited