TimelineItem class
Timeline item data class
Constructors
Properties
- completed → bool
-
Whether this item is completed
final
- description → String?
-
Description text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Icon to display
final
- iconColor → String?
-
Custom icon color
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Subtitle (e.g., date, time)
final
- title → String
-
Item title
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited