AlertBannerProps class
Alert banner component properties.
Constructors
- AlertBannerProps({required String message, String? title, AlertBannerVariant variant = AlertBannerVariant.info, Widget? icon, Widget? action, bool dismissible = false, void onDismiss()?, bool filled = false})
-
const
Properties
- action → Widget?
-
final
- dismissible → bool
-
final
- filled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- message → String
-
final
- onDismiss → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- variant → AlertBannerVariant
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited