AlertProps class
Alert component properties.
Constructors
- AlertProps({required ColorVariant color, String? title, String? message, Widget? child, AlertStyle style = AlertStyle.subtle, Widget? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Widget? action})
-
const
Properties
- action → Widget?
-
final
- child → Widget?
-
final
- color → ColorVariant
-
final
- dismissible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- message → String?
-
final
- onDismiss → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
- style → AlertStyle
-
final
- title → String?
-
final
Methods
-
copyWith(
{ColorVariant? color, String? title, String? message, Widget? child, AlertStyle? style, Widget? icon, bool? showIcon, bool? dismissible, void onDismiss()?, Widget? action}) → AlertProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited