AlertProps class

Alert component properties.

Constructors

AlertProps({required AlertSeverity severity, String? title, String? message, Component? child, AlertVariant variant = AlertVariant.subtle, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?, Component? action})
const

Properties

action Component?
final
child Component?
final
dismissible bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
message String?
final
onDismiss → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity AlertSeverity
final
showIcon bool
final
title String?
final
variant AlertVariant
final

Methods

copyWith({AlertSeverity? severity, String? title, String? message, Component? child, AlertVariant? variant, Component? icon, bool? showIcon, bool? dismissible, void onDismiss()?, Component? action}) AlertProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited