AnimatedCounterProps class
Animated counter component properties.
Constructors
Properties
- color → String?
-
final
- fontSize → String
-
final
- gradientEnd → String?
-
final
- gradientStart → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- prefix → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → String?
-
final
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited