ArrowLinkProps class

Arrow link component properties.

Constructors

ArrowLinkProps({required String label, String? href, ArrowLinkSize size = ArrowLinkSize.sm, bool showArrow = true, bool arrowBefore = false, bool accent = true, void onTap()?, ArrowLinkVariant variant = ArrowLinkVariant.inline, bool animateArrow = false})
const
ArrowLinkProps.pill({required String label, String? href, ArrowLinkSize size = ArrowLinkSize.sm, bool showArrow = true, bool arrowBefore = false, bool accent = true, void onTap()?, bool animateArrow = true})
Creates a pill-style arrow link (button-like with background).
const

Properties

accent bool
final
animateArrow bool
Whether arrow should animate on hover (for pill variant).
final
arrowBefore bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
label String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrow bool
final
size ArrowLinkSize
final
variant ArrowLinkVariant
Visual variant: inline (text link) or pill (button-like).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited