ArrowLinkProps class

Arrow link component properties.

Constructors

ArrowLinkProps({required String label, String? href, ArrowLinkSize size = ArrowLinkSize.sm, bool showArrow = true, bool arrowBefore = false, bool accent = true, void onTap()?})
const

Properties

accent bool
final
arrowBefore bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
label String
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrow bool
final
size ArrowLinkSize
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited