AvatarProps class
Avatar component properties.
Constructors
- AvatarProps({String? imageUrl, String? initials, AvatarSize size = AvatarSize.md, AvatarShape shape = AvatarShape.circle, String? borderColor, bool showStatus = false, String? statusColor, void onTap()?})
-
const
Properties
- borderColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
final
- initials → String?
-
final
- onTap → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → AvatarShape
-
final
- showStatus → bool
-
final
- size → AvatarSize
-
final
- statusColor → String?
-
final
Methods
-
copyWith(
{String? imageUrl, String? initials, AvatarSize? size, AvatarShape? shape, String? borderColor, bool? showStatus, String? statusColor, void onTap()?}) → AvatarProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited