BarProps class
Bar/app bar component properties.
Constructors
Properties
- backButton → BarBackButtonMode
-
final
- centerTitle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
-
leading
→ List<
Widget> ? -
final
- onBack → void Function()?
-
final
- padding → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → Widget?
-
final
- subtitleText → String?
-
final
- title → Widget?
-
final
- titleText → String?
-
final
-
trailing
→ List<
Widget> ? -
final
- transparent → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited