BreadcrumbsProps class
Breadcrumbs component properties.
Constructors
-
BreadcrumbsProps({required List<
BreadcrumbItemProps> items, BreadcrumbSeparatorStyle separator = BreadcrumbSeparatorStyle.chevron, BreadcrumbSizeVariant size = BreadcrumbSizeVariant.md, bool showHomeIcon = false, Widget? customSeparator, void onItemClick(BreadcrumbItemProps item, int index)?}) -
const
Properties
- customSeparator → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
BreadcrumbItemProps> -
final
- onItemClick → void Function(BreadcrumbItemProps item, int index)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → BreadcrumbSeparatorStyle
-
final
- showHomeIcon → bool
-
final
- size → BreadcrumbSizeVariant
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited