ToolbarProps class
Toolbar component properties.
Constructors
-
ToolbarProps({required List<
Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, double gap = 8, EdgeInsets? padding}) -
const
Properties
-
children
→ List<
Widget> -
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited