ButtonProps class

Constructors

ButtonProps({String? label, Widget? child, Widget? icon, Widget? trailing, void onPressed()?, ArcaneInteraction? action, ButtonVariant variant = ButtonVariant.primary, ButtonSize size = ButtonSize.md, bool disabled = false, bool loading = false, bool fullWidth = false, String? id, Map<String, String>? attributes, String? href, bool showArrow = false})
const

Properties

action ArcaneInteraction?
final
attributes Map<String, String>?
final
child Widget?
final
disabled bool
final
fullWidth bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
icon Widget?
final
id String?
final
label String?
final
loading bool
final
onPressed → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrow bool
final
size ButtonSize
final
trailing Widget?
final
variant ButtonVariant
final

Methods

copyWith({String? label, Widget? child, Widget? icon, Widget? trailing, void onPressed()?, ArcaneInteraction? action, ButtonVariant? variant, ButtonSize? size, bool? disabled, bool? loading, bool? fullWidth, String? id, Map<String, String>? attributes, String? href, bool? showArrow}) ButtonProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited