CalendarProps class
Calendar component properties.
Constructors
- CalendarProps({DateTime? selected, required DateTime displayMonth, DateTime? minDate, DateTime? maxDate, bool showWeekNumbers = false, bool showToday = true, int firstDayOfWeek = 0, CalendarModeVariant mode = CalendarModeVariant.single, DateRangeValue? selectedRange, DateTime? rangeStart, bool isDisabled(DateTime)?, void onPreviousMonth()?, void onNextMonth()?, void onGoToToday()?, void onSelectDate(DateTime date)?})
-
const
Properties
- displayMonth → DateTime
-
final
- firstDayOfWeek → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisabled → bool Function(DateTime)?
-
final
- maxDate → DateTime?
-
final
- minDate → DateTime?
-
final
- mode → CalendarModeVariant
-
final
- onGoToToday → void Function()?
-
final
- onNextMonth → void Function()?
-
final
- onPreviousMonth → void Function()?
-
final
- onSelectDate → void Function(DateTime date)?
-
final
- rangeStart → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → DateTime?
-
final
- selectedRange → DateRangeValue?
-
final
- showToday → bool
-
final
- showWeekNumbers → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited