CalloutProps class
Callout component properties.
Constructors
- CalloutProps({String? title, String? content, Component? child, CalloutVariant variant = CalloutVariant.info, Component? icon, bool showIcon = true, bool dismissible = false, void onDismiss()?})
-
const
Properties
- child → Component?
-
final
- content → String?
-
final
- dismissible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component?
-
final
- onDismiss → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
- title → String?
-
final
- variant → CalloutVariant
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited