CardProps class
Card component properties.
Constructors
Properties
- backgroundColor → String?
-
final
- borderRadius → String?
-
final
- child → Widget?
-
final
-
children
→ List<
Widget> ? -
final
- fillWidth → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap → void Function()?
-
final
- padding → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → CardVariant
-
final
Methods
-
copyWith(
{Widget? child, List< Widget> ? children, CardVariant? variant, String? padding, String? borderRadius, String? backgroundColor, bool? fillWidth, void onTap()?}) → CardProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited