CheckboxProps class

Checkbox component properties.

Constructors

CheckboxProps({required String id, required bool checked, String? label, String? description, ComponentSize size = ComponentSize.md, ColorVariant color = ColorVariant.primary, bool disabled = false, void onChanged(bool)?, String? group, String? value})
const

Properties

checked bool
final
color ColorVariant
final
description String?
final
disabled bool
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String?
final
onChanged → void Function(bool)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ComponentSize
final
value String?
final

Methods

copyWith({String? id, bool? checked, String? label, String? description, ComponentSize? size, ColorVariant? color, bool? disabled, void onChanged(bool)?, String? group, String? value}) CheckboxProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited