CheckboxProps class
Checkbox component properties.
Constructors
- CheckboxProps({required bool checked, String? label, String? description, CheckboxSize size = CheckboxSize.medium, CheckboxVariant variant = CheckboxVariant.primary, bool disabled = false, void onChanged(bool)?})
-
const
Properties
- checked → bool
-
final
- description → String?
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- onChanged → void Function(bool)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → CheckboxSize
-
final
- variant → CheckboxVariant
-
final
Methods
-
copyWith(
{bool? checked, String? label, String? description, CheckboxSize? size, CheckboxVariant? variant, bool? disabled, void onChanged(bool)?}) → CheckboxProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited