ChipProps class
Chip component properties.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component?
-
final
- label → String
-
final
- onRemove → void Function()?
-
final
- onTap → void Function()?
-
final
- removable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ChipSize
-
final
- variant → ChipVariant
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited