CommandProps class
Command palette component properties.
Constructors
-
CommandProps({required bool isOpen, required List<
CommandGroupProps> groups, void onClose()?, String placeholder = 'Type a command or search...', String emptyMessage = 'No results found.', String searchQuery = '', List<CommandItemProps> filteredItems = const [], void onSearch(String)?, void onSelectItem(CommandItemProps)?}) -
const
Properties
- emptyMessage → String
-
final
-
filteredItems
→ List<
CommandItemProps> -
final
-
groups
→ List<
CommandGroupProps> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
final
- onClose → void Function()?
-
final
- onSearch → void Function(String)?
-
final
- onSelectItem → void Function(CommandItemProps)?
-
final
- placeholder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchQuery → String
-
final
Methods
-
copyWith(
{bool? isOpen, void onClose()?, List< CommandGroupProps> ? groups, String? placeholder, String? emptyMessage, String? searchQuery, List<CommandItemProps> ? filteredItems, void onSearch(String)?, void onSelectItem(CommandItemProps)?}) → CommandProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited