ContextMenuProps class
Context menu component properties.
Constructors
-
ContextMenuProps({required Widget trigger, required List<
ArcaneMenuItem> items}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
ArcaneMenuItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trigger → Widget
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited