CycleButtonProps<T> class

Cycle button component properties.

Constructors

CycleButtonProps({required List<CycleOption<T>> options, required T value, void onChanged(T value)?, CycleButtonVariant variant = CycleButtonVariant.outline, CycleButtonSize size = CycleButtonSize.medium, bool disabled = false, String? id, Map<String, String>? attributes})
const

Properties

attributes Map<String, String>?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
onChanged → void Function(T value)?
final
options List<CycleOption<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size CycleButtonSize
final
value → T
final
variant CycleButtonVariant
final

Methods

copyWith({List<CycleOption<T>>? options, T? value, void onChanged(T value)?, CycleButtonVariant? variant, CycleButtonSize? size, bool? disabled, String? id, Map<String, String>? attributes}) CycleButtonProps<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited