DialogProps class
Dialog component properties.
Constructors
Properties
-
actions
→ List<
Widget> ? -
final
- barrierDismissible → bool
-
final
-
content
→ List<
Widget> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxWidth → double
-
final
- onClose → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool
-
final
- title → String?
-
final
Methods
-
copyWith(
{String? title, List< Widget> ? content, List<Widget> ? actions, bool? showCloseButton, void onClose()?, double? maxWidth, bool? barrierDismissible}) → DialogProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited