SheetProps class
Sheet/drawer component properties.
Constructors
- SheetProps({required bool isOpen, required Widget child, SheetPosition position = SheetPosition.right, SheetSizeVariant size = SheetSizeVariant.auto, void onClose()?, bool showCloseButton = true, String? title, String? description, Widget? header, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showDragHandle = true, String? maxWidth})
-
const
Properties
- child → Widget
-
final
- closeOnBackdropClick → bool
-
final
- description → String?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
final
- isOpen → bool
-
final
- maxWidth → String?
-
final
- onClose → void Function()?
-
final
- position → SheetPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBackdrop → bool
-
final
- showCloseButton → bool
-
final
- showDragHandle → bool
-
final
- size → SheetSizeVariant
-
final
- title → String?
-
final
Methods
-
copyWith(
{bool? isOpen, Widget? child, SheetPosition? position, SheetSizeVariant? size, void onClose()?, bool? showCloseButton, String? title, String? description, Widget? header, bool? showBackdrop, bool? closeOnBackdropClick, bool? showDragHandle, String? maxWidth}) → SheetProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited