SheetProps class

Sheet/drawer component properties.

Constructors

SheetProps({String? id, required bool isOpen, required Widget child, SheetPosition position = SheetPosition.right, SheetSizeVariant size = SheetSizeVariant.auto, void onClose()?, bool showCloseButton = true, String? title, String? description, Widget? header, Widget? footer, bool showBackdrop = true, bool closeOnBackdropClick = true, bool showDragHandle = true, String? maxWidth, bool escapeCloses = true, bool focusTrap = true, bool restoreFocus = true})
const

Properties

child Widget
final
closeOnBackdropClick bool
final
description String?
final
escapeCloses bool
final
focusTrap bool
final
final
hashCode int
The hash code for this object.
no setterinherited
final
id String?
final
isOpen bool
final
maxWidth String?
final
onClose → void Function()?
final
position SheetPosition
final
restoreFocus bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBackdrop bool
final
showCloseButton bool
final
showDragHandle bool
final
size SheetSizeVariant
final
title String?
final

Methods

copyWith({String? id, bool? isOpen, Widget? child, SheetPosition? position, SheetSizeVariant? size, void onClose()?, bool? showCloseButton, String? title, String? description, Widget? header, Widget? footer, bool? showBackdrop, bool? closeOnBackdropClick, bool? showDragHandle, String? maxWidth, bool? escapeCloses, bool? focusTrap, bool? restoreFocus}) SheetProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited