DisclosureProps class

Disclosure component properties.

Constructors

DisclosureProps({required Component summary, required Component child, bool open = false, DisclosureVariant variant = DisclosureVariant.default_, bool showChevron = true, bool showTreeLines = true, String? classes})
const

Properties

child Component
final
classes String?
final
hashCode int
The hash code for this object.
no setterinherited
open bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showChevron bool
final
showTreeLines bool
final
summary Component
final
variant DisclosureVariant
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited