DividerProps class
Divider component properties.
Constructors
- DividerProps({double? margin, DividerVariant variant = DividerVariant.standard, String? label, bool dashed = false, DividerOrientation orientation = DividerOrientation.horizontal, double? height})
-
const
Properties
- dashed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- label → String?
-
final
- margin → double?
-
final
- orientation → DividerOrientation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → DividerVariant
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited