DropdownMenuProps class
Dropdown menu component properties.
Constructors
-
DropdownMenuProps({required String id, required Widget trigger, required List<
ArcaneMenuItem> items, DropdownAlignment alignment = DropdownAlignment.left, double? width, bool keepOpenOnAction = false, bool initiallyOpen = false}) -
const
Properties
- alignment → DropdownAlignment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- initiallyOpen → bool
-
final
-
items
→ List<
ArcaneMenuItem> -
final
- keepOpenOnAction → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trigger → Widget
-
final
- width → double?
-
final
Methods
-
copyWith(
{String? id, Widget? trigger, List< ArcaneMenuItem> ? items, DropdownAlignment? alignment, double? width, bool? keepOpenOnAction, bool? initiallyOpen}) → DropdownMenuProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited