EmptyStateProps class
Empty state component properties.
Constructors
- EmptyStateProps({required String title, Widget? icon, String? description, Widget? action, Widget? secondaryAction, EmptyStateStyleVariant style = EmptyStateStyleVariant.centered, EmptyStateSizeVariant size = EmptyStateSizeVariant.md})
-
const
Properties
- action → Widget?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAction → Widget?
-
final
- size → EmptyStateSizeVariant
-
final
- style → EmptyStateStyleVariant
-
final
- title → String
-
final
Methods
-
copyWith(
{Widget? icon, String? title, String? description, Widget? action, Widget? secondaryAction, EmptyStateStyleVariant? style, EmptyStateSizeVariant? size}) → EmptyStateProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited