EmptyStateProps class
Empty state component properties.
Constructors
- EmptyStateProps({required String title, Widget? icon, String? description, Widget? action, Widget? secondaryAction, EmptyStateStyleVariant variant = EmptyStateStyleVariant.centered, EmptyStateSizeVariant size = EmptyStateSizeVariant.md, ArcaneStyleData? styles, ArcaneDecoration? decoration})
-
const
Properties
- action → Widget?
-
final
- decoration → ArcaneDecoration?
-
Semantic, theme-interpreted decoration (elevation intent + theme-specific
fields honored-or-ignored per theme).
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAction → Widget?
-
final
- size → EmptyStateSizeVariant
-
final
- styles → ArcaneStyleData?
-
Literal, theme-permeable style override (always applied, wins over theme).
final
- title → String
-
final
- variant → EmptyStateStyleVariant
-
final
Methods
-
copyWith(
{Widget? icon, String? title, String? description, Widget? action, Widget? secondaryAction, EmptyStateStyleVariant? variant, EmptyStateSizeVariant? size, ArcaneStyleData? styles, ArcaneDecoration? decoration}) → EmptyStateProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited