EmptyStateProps class
Empty state component properties.
Constructors
- EmptyStateProps({required String title, Component? icon, String? emoji, String? description, Component? action, Component? secondaryAction, EmptyStateStyleVariant style = EmptyStateStyleVariant.centered, EmptyStateSizeVariant size = EmptyStateSizeVariant.md})
-
const
Properties
- action → Component?
-
final
- description → String?
-
final
- emoji → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Component?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryAction → Component?
-
final
- size → EmptyStateSizeVariant
-
final
- style → EmptyStateStyleVariant
-
final
- title → String
-
final
Methods
-
copyWith(
{Component? icon, String? emoji, String? title, String? description, Component? action, Component? secondaryAction, EmptyStateStyleVariant? style, EmptyStateSizeVariant? size}) → EmptyStateProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited