ExpanderProps class
Expander component properties.
Constructors
- ExpanderProps({required Widget header, required Widget child, bool initiallyExpanded = false, void onExpansionChanged(bool expanded)?, Widget? leading, bool showIcon = true, EdgeInsets? contentPadding, bool maintainState = true})
-
const
Properties
- child → Widget
-
final
- contentPadding → EdgeInsets?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget
-
final
- initiallyExpanded → bool
-
final
- leading → Widget?
-
final
- maintainState → bool
-
final
- onExpansionChanged → void Function(bool expanded)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited