ExpanderProps class
Expander component properties.
Constructors
- ExpanderProps({required Component header, required Component child, bool initiallyExpanded = false, void onExpansionChanged(bool expanded)?, Component? leading, bool showIcon = true, EdgeInsets? contentPadding, bool maintainState = true})
-
const
Properties
- child → Component
-
final
- contentPadding → EdgeInsets?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component
-
final
- initiallyExpanded → bool
-
final
- leading → Component?
-
final
- maintainState → bool
-
final
- onExpansionChanged → void Function(bool expanded)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showIcon → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited