FeatureCardProps class

Feature card component properties.

Constructors

FeatureCardProps({required String title, required String description, Component? icon, String? href, void onTap()?, bool showArrow = false, bool horizontal = false})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
horizontal bool
final
href String?
final
icon Component?
final
onTap → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrow bool
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited