FeatureShowcaseProps class
Feature showcase component properties.
Constructors
Properties
- background → String?
-
final
- centerHeader → bool
-
final
- collapsedFlex → double
-
final
- expandedFlex → double
-
final
- expandOnHover → bool
-
final
- gap → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
FeatureShowcaseItem> -
final
- minCardWidth → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited