FlowRendererContract mixin
Mixin defining the renderer methods for flow/layout components.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
center(
CenterProps props) → Widget -
column(
ColumnProps props) → Widget -
expanded(
ExpandedProps props) → Widget -
flow(
FlowProps props) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingWrapper(
PaddingWrapperProps props) → Widget -
row(
RowProps props) → Widget -
sizedBox(
SizedBoxProps props) → Widget -
spacer(
SpacerProps props) → Widget -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited