FlowRendererContract mixin

Mixin defining the renderer methods for flow/layout components.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

center(CenterProps props) Component
column(ColumnProps props) Component
expanded(ExpandedProps props) Component
flow(FlowProps props) Component
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingWrapper(PaddingWrapperProps props) Component
row(RowProps props) Component
sizedBox(SizedBoxProps props) Component
spacer(SpacerProps props) Component
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited