GameSelectorProps class
Game selector component properties.
Constructors
-
GameSelectorProps({required List<
GameTileProps> games, int columns = 4, double gap = 16, String? title, String? description}) -
const
Properties
- columns → int
-
final
- description → String?
-
final
-
games
→ List<
GameTileProps> -
final
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited