GameTileProps class

Game tile component properties.

Constructors

GameTileProps({required String name, String? iconUrl, Component? icon, bool selected = false, void onTap()?, bool popular = false, String? badge, String? subtitle})
const

Properties

badge String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
iconUrl String?
final
name String
final
onTap → void Function()?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
subtitle String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited