HeaderProps class

Header/navbar component properties.

Constructors

HeaderProps({required List<NavItemProps> navItems, List<Component>? actions, bool showSearch = false, String searchPlaceholder = 'Search...', void onSearch(String)?, bool sticky = true, bool transparent = false, bool bordered = true})
const

Properties

actions List<Component>?
final
bordered bool
final
hashCode int
The hash code for this object.
no setterinherited
final
final
onSearch → void Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholder String
final
showSearch bool
final
sticky bool
final
transparent bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited