HeroSectionProps class

Hero section component properties.

Constructors

HeroSectionProps({required String headline, String? subheadline, Component? primaryCta, Component? secondaryCta, Component? badge, Component? media, bool centered = true, double verticalPadding = 80, double maxWidth = 800})
const

Properties

badge Component?
final
centered bool
final
hashCode int
The hash code for this object.
no setterinherited
headline String
final
maxWidth double
final
media Component?
final
primaryCta Component?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryCta Component?
final
subheadline String?
final
verticalPadding double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited