HovercardProps class
Hovercard component properties.
Constructors
- HovercardProps({required Component trigger, required Component content, HovercardPositionVariant position = HovercardPositionVariant.top, bool showArrow = true, int offset = 8, bool isOpen = false, void onMouseEnter()?, void onMouseLeave()?})
-
const
Properties
- content → Component
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
final
- offset → int
-
final
- onMouseEnter → void Function()?
-
final
- onMouseLeave → void Function()?
-
final
- position → HovercardPositionVariant
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
final
- trigger → Component
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited