IconButtonProps class
Icon button component properties.
Constructors
- IconButtonProps({required Widget icon, void onPressed()?, ColorVariant color = ColorVariant.secondary, StyleVariant style = StyleVariant.ghost, ComponentSize size = ComponentSize.md, bool disabled = false, bool loading = false, String? tooltip})
-
const
Properties
- color → ColorVariant
-
final
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget
-
final
- loading → bool
-
final
- onPressed → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ComponentSize
-
final
- style → StyleVariant
-
final
- tooltip → String?
-
final
Methods
-
copyWith(
{Widget? icon, void onPressed()?, ColorVariant? color, StyleVariant? style, ComponentSize? size, bool? disabled, bool? loading, String? tooltip}) → IconButtonProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited