IconButtonProps class

Icon button component properties.

Constructors

IconButtonProps({required Component icon, void onPressed()?, IconButtonVariant variant = IconButtonVariant.ghost, IconButtonSize size = IconButtonSize.medium, bool disabled = false, bool loading = false, String? tooltip})
const

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component
final
loading bool
final
onPressed → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size IconButtonSize
final
tooltip String?
final
variant IconButtonVariant
final

Methods

copyWith({Component? icon, void onPressed()?, IconButtonVariant? variant, IconButtonSize? size, bool? disabled, bool? loading, String? tooltip}) IconButtonProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited