KbdProps class
Keyboard shortcut display component properties.
Constructors
-
KbdProps({String? keyText, List<
String> ? keys, String separator = '+', KbdStyle variant = KbdStyle.raised, ComponentSize size = ComponentSize.md, ArcaneStyleData? styles, ArcaneDecoration? decoration}) -
const
-
KbdProps.combo(List<
String> keys, {String separator = '+', KbdStyle variant = KbdStyle.raised, ComponentSize size = ComponentSize.md, ArcaneStyleData? styles, ArcaneDecoration? decoration}) -
const
- KbdProps.key(String key, {KbdStyle variant = KbdStyle.raised, ComponentSize size = ComponentSize.md, ArcaneStyleData? styles, ArcaneDecoration? decoration})
-
const
Properties
- decoration → ArcaneDecoration?
-
Semantic, theme-interpreted decoration (elevation intent + theme-specific
fields honored-or-ignored per theme).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
String> ? -
final
- keyText → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → String
-
final
- size → ComponentSize
-
final
- styles → ArcaneStyleData?
-
Literal, theme-permeable style override (always applied, wins over theme).
final
- variant → KbdStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited