ArcaneMenuItem class

Unified menu item for dropdown menus, context menus, and menubars.

Constructors

ArcaneMenuItem({required String label, Component? icon, void onSelect()?, String? href, String? description, bool disabled = false, bool destructive = false, String? shortcut, List<ArcaneMenuItem>? submenu, bool isSeparator = false, bool isCheckbox = false, bool checked = false, String? radioGroup, String? radioValue})
const
ArcaneMenuItem.checkbox({required String label, required bool checked, Component? icon, void onSelect()?, bool disabled = false, String? shortcut})
const
ArcaneMenuItem.divider()
const
ArcaneMenuItem.radio({required String label, required String group, required String value, required bool checked, Component? icon, void onSelect()?, bool disabled = false})
const
ArcaneMenuItem.separator()
const
ArcaneMenuItem.submenu({required String label, required List<ArcaneMenuItem> items, Component? icon, bool disabled = false})
const

Properties

checked bool
final
description String?
final
destructive bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
icon Component?
final
isCheckbox bool
final
isSeparator bool
final
label String
final
onSelect → void Function()?
final
radioGroup String?
final
radioValue String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcut String?
final
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited