MobileMenuProps class

Mobile menu component properties.

Constructors

MobileMenuProps({required List<MobileNavItem> items, Widget? cta, void onClose()?, bool isOpen = false})
const

Properties

cta Widget?
final
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
final
items List<MobileNavItem>
final
final
onClose → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited