OtpInputProps class

OTP input component properties.

Constructors

OtpInputProps({int length = 6, List<String> digits = const [], bool obscure = false, OtpInputSizeVariant size = OtpInputSizeVariant.md, bool disabled = false, String? error, String? label, String? separator, int? separatorPosition, void onInput(int index, String value)?})
const

Properties

digits List<String>
final
disabled bool
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
length int
final
obscure bool
final
onInput → void Function(int index, String value)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator String?
final
separatorPosition int?
final
size OtpInputSizeVariant
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited