PaginationProps class
Pagination component properties.
Constructors
-
PaginationProps({required int currentPage, required int totalPages, void onPageChange(int page)?, PaginationStyleVariant style = PaginationStyleVariant.outline, PaginationSizeVariant size = PaginationSizeVariant.md, int siblingCount = 1, bool showFirstLast = true, bool showPrevNext = true, bool showPageCount = false, String previousText = '<-', String nextText = '->', List<
int?> pageNumbers = const []}) -
const
Properties
- currentPage → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextText → String
-
final
- onPageChange → void Function(int page)?
-
final
-
pageNumbers
→ List<
int?> -
final
- previousText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showFirstLast → bool
-
final
- showPageCount → bool
-
final
- showPrevNext → bool
-
final
- siblingCount → int
-
final
- size → PaginationSizeVariant
-
final
- style → PaginationStyleVariant
-
final
- totalPages → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited