CircularProgressProps class
Circular progress component properties.
Constructors
Properties
- fillColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPercentage → bool
-
final
- size → String?
-
final
- strokeWidth → String?
-
final
- trackColor → String?
-
final
- value → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited