ProgressRendererContract mixin
Mixin defining the renderer methods for progress components.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
circularProgress(
CircularProgressProps props) → Component - Renders a circular progress indicator component.
-
loadingSpinner(
LoadingSpinnerProps props) → Component - Renders a loading spinner component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
progress(
ProgressProps props) → Component - Renders a linear progress bar component.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited