CornerPromoToastProps class
Props for the corner promo toast.
A corner toast-style promo notification that slides in from a corner. Less intrusive than a modal, great for subtle promotions.
Constructors
- CornerPromoToastProps({required String title, required String message, String? promoCode, String? ctaText, String? ctaHref, void onCtaClick()?, void onDismiss()?, PromoCornerPosition position = PromoCornerPosition.bottomRight, int delayMs = 3000, Widget? icon})
-
const
Properties
- ctaHref → String?
-
CTA button URL.
final
- ctaText → String?
-
CTA button text.
final
- delayMs → int
-
Delay in milliseconds before showing.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Optional icon to display.
final
- message → String
-
Toast message.
final
- onCtaClick → void Function()?
-
Callback when CTA is clicked.
final
- onDismiss → void Function()?
-
Callback when the toast is dismissed.
final
- position → PromoCornerPosition
-
Which corner to position the toast.
final
- promoCode → String?
-
Optional promo code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Toast title.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited