MarqueeTickerBarProps class
Props for the marquee ticker bar.
A scrolling marquee-style announcement bar. Great for creating urgency with continuous movement.
Constructors
Properties
- ctaHref → String?
-
CTA button URL.
final
- ctaText → String?
-
CTA button text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
String> -
List of messages to scroll.
final
- onCtaClick → void Function()?
-
Callback when CTA is clicked.
final
- onDismiss → void Function()?
-
Callback when dismissed.
final
- promoCode → String?
-
Optional promo code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAtBottom → bool
-
Whether to show at bottom instead of top.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited