RadioGroupProps<T> class
Radio group component properties.
Constructors
-
RadioGroupProps({required List<
RadioOptionProps< options, T? value, void onChanged(T value)?, String? name, RadioGroupLayout layout = RadioGroupLayout.vertical, RadioGroupVariant variant = RadioGroupVariant.standard, bool disabled = false, String? label, String? helperText, String? error, bool required = false, String gap = '0.5rem', int gridColumns = 2})T> > -
const
Properties
- disabled → bool
-
final
- error → String?
-
final
- gap → String
-
final
- gridColumns → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- label → String?
-
final
- layout → RadioGroupLayout
-
final
- name → String?
-
final
- onChanged → void Function(T value)?
-
final
-
options
→ List<
RadioOptionProps< T> > -
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T?
-
final
- variant → RadioGroupVariant
-
final
Methods
-
copyWith(
{T? value, List< RadioOptionProps< ? options, void onChanged(T value)?, String? name, RadioGroupLayout? layout, RadioGroupVariant? variant, bool? disabled, String? label, String? helperText, String? error, bool? required, String? gap, int? gridColumns}) → RadioGroupProps<T> >T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited