RatingStarsProps class
Rating stars component properties.
Constructors
Properties
- emptyColor → String?
-
final
- filledColor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rating → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showValue → bool
-
final
- size → String
-
final
- totalStars → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited