ResizableProps class

Resizable panel group component properties.

Constructors

ResizableProps({required List<ResizablePanelData> panels, ResizeDirection direction = ResizeDirection.horizontal, double handleSize = 8, bool showGrip = true})
const

Properties

direction ResizeDirection
final
handleSize double
final
hashCode int
The hash code for this object.
no setterinherited
panels List<ResizablePanelData>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showGrip bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited