SeparatorProps class
Unified separator component properties.
Combines features from both Divider and Separator into a single component.
Constructors
- SeparatorProps({SeparatorOrientation orientation = SeparatorOrientation.horizontal, SeparatorVariant variant = SeparatorVariant.standard, String? label, Widget? icon, String? color, bool dashed = false, bool decorative = true, double? margin, double? height})
-
const
Properties
- color → String?
-
Custom color override (CSS color value).
final
- dashed → bool
-
Whether to render as dashed line.
final
- decorative → bool
-
Whether the separator is purely decorative (affects ARIA).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Height of vertical separator in pixels (null = stretch to fill).
final
- icon → Widget?
-
Optional icon to display in the middle (horizontal only).
final
- label → String?
-
Optional text label to display in the middle (horizontal only).
final
- margin → double?
-
Margin around the separator in pixels.
final
- orientation → SeparatorOrientation
-
Orientation of the separator.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → SeparatorVariant
-
Visual style variant.
final
Methods
-
copyWith(
{SeparatorOrientation? orientation, SeparatorVariant? variant, String? label, Widget? icon, String? color, bool? dashed, bool? decorative, double? margin, double? height}) → SeparatorProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited