SeparatorProps class

Separator component properties.

Constructors

SeparatorProps({SeparatorOrientation orientation = SeparatorOrientation.horizontal, String? label, Component? icon, String? color, bool decorative = true})
const

Properties

color String?
final
decorative bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
label String?
final
orientation SeparatorOrientation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({SeparatorOrientation? orientation, String? label, Component? icon, String? color, bool? decorative}) SeparatorProps
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited