SidebarProps class
Sidebar component properties.
Constructors
Properties
-
children
→ List<
Component> -
final
- collapsedWidth → double
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Component?
-
final
- isCollapsed → bool
-
final
- onCollapseChanged → void Function(bool collapsed)?
-
final
- onToggleCollapse → void Function()?
-
final
- rightSide → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCollapseToggle → bool
-
final
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited