SidebarRendererContract mixin
Mixin defining the renderer methods for sidebar components.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
- Renders the main sidebar container.
- Renders content shown when sidebar is collapsed.
- Renders content shown when sidebar is expanded.
- Renders a sidebar group with optional label.
- Renders a sidebar navigation item.
- Renders a fixed (non-collapsible) sidebar section.
- Renders a sidebar separator.
- Renders a collapsible sidebar submenu.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited