SidebarSectionProps class
Sidebar section component properties (fixed, non-collapsible section).
For sections that are always expanded with a header.
Constructors
-
SidebarSectionProps({required String label, Widget? icon, required List<
Widget> children}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited