SidebarSubMenuProps class

Sidebar submenu component properties.

Constructors

SidebarSubMenuProps({required String label, required List<Component> children, Component? icon, bool isOpen = false, void onToggle()?, bool collapsed = false, String? badge})
const

Properties

badge String?
final
children List<Component>
final
collapsed bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Component?
final
isOpen bool
final
label String
final
onToggle → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited