SlotCounterRowProps class
Slot counter row component properties.
Constructors
-
SlotCounterRowProps({required List<
SlotCounterProps> counters, String gap = '2rem', bool wrap = true, String justifyContent = 'center'}) -
const
Properties
-
counters
→ List<
SlotCounterProps> -
final
- gap → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- justifyContent → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wrap → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited