KeyValueTableProps class

Key-value table component properties.

Constructors

KeyValueTableProps({required List<KeyValueRowData> rows, double? keyWidth, bool showDividers = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyWidth double?
final
rows List<KeyValueRowData>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDividers bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited