StaticTableProps class
Static table component properties.
Constructors
Properties
-
alignments
→ List<
TextAlign> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
String> -
final
-
rows
→ List<
List< Widget> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDividers → bool
-
final
- showHeader → bool
-
final
- stickyHeader → bool
-
final
- striped → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited