StepperProps class
Stepper component properties.
Constructors
-
StepperProps({required List<
StepItemData> items, StepsLayout layout = StepsLayout.horizontal, StepsSize size = StepsSize.md, bool showConnectors = true, int? currentStep, void onStepTap(int index)?}) -
const
Properties
- currentStep → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
StepItemData> -
final
- layout → StepsLayout
-
final
- onStepTap → void Function(int index)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showConnectors → bool
-
final
- size → StepsSize
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited