SurfaceCardProps class
Surface card component properties.
Constructors
-
SurfaceCardProps({required Component child, SurfaceEffect effect = SurfaceEffect.none, double blurAmount = 10.0, double backgroundOpacity = 0.8, String? backgroundColor, List<
String> ? gradientColors, int gradientAngle = 135, String? borderRadius, bool showBorder = true, String? padding, SurfaceShadow shadow = SurfaceShadow.md}) -
const
Properties
- backgroundColor → String?
-
final
- backgroundOpacity → double
-
final
- blurAmount → double
-
final
- borderRadius → String?
-
final
- child → Component
-
final
- effect → SurfaceEffect
-
final
- gradientAngle → int
-
final
-
gradientColors
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadow → SurfaceShadow
-
final
- showBorder → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited