TabBarProps class
Tab bar component properties.
Constructors
-
TabBarProps({required List<
TabBarItemProps> tabs, required int selectedIndex, required void onChanged(int index), bool fill = false}) -
const
Properties
- fill → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onChanged → void Function(int index)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex → int
-
final
-
tabs
→ List<
TabBarItemProps> -
final
Methods
-
copyWith(
{List< TabBarItemProps> ? tabs, int? selectedIndex, void onChanged(int index)?, bool? fill}) → TabBarProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited