TabsProps class
Tabs component properties.
Constructors
Properties
- fill → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onChanged → void Function(int index)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex → int
-
final
-
tabs
→ List<
TabItemProps> -
final
Methods
-
copyWith(
{List< TabItemProps> ? tabs, int? selectedIndex, void onChanged(int index)?, bool? fill}) → TabsProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited