TimeDialogProps class

Time dialog component properties.

Constructors

TimeDialogProps({required String title, String? message, TimeOfDay? initialTime, String confirmText = 'Confirm', String cancelText = 'Cancel', void onConfirm(TimeOfDay time)?, void onCancel()?, bool use24Hour = false, int minuteInterval = 1, bool showSeconds = false})
const

Properties

cancelText String
final
confirmText String
final
hashCode int
The hash code for this object.
no setterinherited
initialTime TimeOfDay?
final
message String?
final
minuteInterval int
final
onCancel → void Function()?
final
onConfirm → void Function(TimeOfDay time)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSeconds bool
final
title String
final
use24Hour bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited