TimePickerProps class
Time picker component properties.
Constructors
- TimePickerProps({required TimeOfDay? value, required String displayText, required bool disabled, required bool clearable, required ComponentSize size, required bool isOpen, required bool use24Hour, required int selectedHour, required int selectedMinute, required bool isPM, required int minuteInterval, String? label, String? error, void onToggle()?, void onClear()?, void onSelectHour(int hour)?, void onSelectMinute(int minute)?, void onTogglePeriod()?, void onConfirm()?, void onCancel()?})
-
const
Properties
- clearable → bool
-
final
- disabled → bool
-
final
- displayText → String
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpen → bool
-
final
- isPM → bool
-
final
- label → String?
-
final
- minuteInterval → int
-
final
- onCancel → void Function()?
-
final
- onClear → void Function()?
-
final
- onConfirm → void Function()?
-
final
- onSelectHour → void Function(int hour)?
-
final
- onSelectMinute → void Function(int minute)?
-
final
- onToggle → void Function()?
-
final
- onTogglePeriod → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedHour → int
-
final
- selectedMinute → int
-
final
- size → ComponentSize
-
final
- use24Hour → bool
-
final
- value → TimeOfDay?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited