ToastContainerProps class
Toast container component properties.
Constructors
-
ToastContainerProps({ToastPosition position = ToastPosition.bottomRight, int maxVisible = 3, double gap = 12, double offset = 20, List<
ToastProps> toasts = const []}) -
const
Properties
- gap → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxVisible → int
-
final
- offset → double
-
final
- position → ToastPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toasts
→ List<
ToastProps> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited