ToggleGroupProps class
Toggle group component properties.
Constructors
-
ToggleGroupProps({required List<
ToggleGroupItemProps> items, String? value, Set<String> ? values, ToggleGroupSelectionType type = ToggleGroupSelectionType.single, ToggleGroupVariantStyle variant = ToggleGroupVariantStyle.defaultVariant, ToggleGroupSizeVariant size = ToggleGroupSizeVariant.md, bool disabled = false, void onChanged(String?)?, void onMultiChanged(Set<String> )?}) -
const
Properties
- disabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
ToggleGroupItemProps> -
final
- onChanged → void Function(String?)?
-
final
-
onMultiChanged
→ void Function(Set<
String> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ToggleGroupSizeVariant
-
final
- type → ToggleGroupSelectionType
-
final
- value → String?
-
final
-
values
→ Set<
String> ? -
final
- variant → ToggleGroupVariantStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited