ToggleSwitchProps class
Toggle switch component properties.
Constructors
- ToggleSwitchProps({required String id, required bool value, void onChanged(bool)?, ArcaneInteraction? onChangeAction, bool disabled = false, ComponentSize size = ComponentSize.md, ColorVariant color = ColorVariant.primary, String? label, bool labelLeft = false, String? group, String? itemValue})
-
const
Properties
- color → ColorVariant
-
final
- disabled → bool
-
final
- group → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- itemValue → String?
-
final
- label → String?
-
final
- labelLeft → bool
-
final
- onChangeAction → ArcaneInteraction?
-
final
- onChanged → void Function(bool)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ComponentSize
-
final
- value → bool
-
final
Methods
-
copyWith(
{String? id, bool? value, void onChanged(bool)?, ArcaneInteraction? onChangeAction, bool? disabled, ComponentSize? size, ColorVariant? color, String? label, bool? labelLeft, String? group, String? itemValue}) → ToggleSwitchProps -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited