TreeViewProps class
Tree view component properties.
Constructors
-
TreeViewProps({required List<
TreeNodeData> nodes, void onNodeSelect(TreeNodeData node)?, void onNodeToggle(TreeNodeData node, bool expanded)?, TreeViewStyle style = TreeViewStyle.lines, TreeSelectionMode selectionMode = TreeSelectionMode.single, Set<String> initiallyExpanded = const {}, Set<String> selectedNodes = const {}, bool expandAll = false}) -
const
Properties
- expandAll → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initiallyExpanded
→ Set<
String> -
final
-
nodes
→ List<
TreeNodeData> -
final
- onNodeSelect → void Function(TreeNodeData node)?
-
final
- onNodeToggle → void Function(TreeNodeData node, bool expanded)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedNodes
→ Set<
String> -
final
- selectionMode → TreeSelectionMode
-
final
- style → TreeViewStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited