ComponentRenderers class abstract

Mixed-in types
Implementers

Constructors

ComponentRenderers()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accordion(AccordionProps props) Component
Renders an accordion with collapsible sections.
inherited
alert(AlertProps props) Component
Renders an alert notification component.
inherited
alertDialog(AlertDialogProps props) Component
inherited
aspectRatio(AspectRatioProps props) Component
inherited
avatar(AvatarProps props) Component
Renders an avatar component.
inherited
bottomFloatingBanner(BottomFloatingBannerProps props) Component
Render a bottom floating banner component.
inherited
Renders a breadcrumb navigation trail.
inherited
button(ButtonProps props) Component
Render a button component.
inherited
buttonGroup(ButtonGroupProps props) Component
inherited
buttonPanel(ButtonPanelProps props) Component
inherited
calendar(CalendarProps props) Component
inherited
card(CardProps props) Component
Renders a card container component.
inherited
center(CenterProps props) Component
inherited
chart(ChartProps props) Component
inherited
checkbox(CheckboxProps props) Component
Render a checkbox component.
inherited
checkItem(CheckItemProps props) Component
inherited
checkList(CheckListProps props) Component
inherited
circularProgress(CircularProgressProps props) Component
Renders a circular progress indicator component.
inherited
column(ColumnProps props) Component
inherited
command(CommandProps props) Component
inherited
confirmDialog(ConfirmDialogProps props) Component
inherited
contextMenu(ContextMenuProps props) Component
inherited
cornerPromoToast(CornerPromoToastProps props) Component
Render a corner promo toast component.
inherited
cycleButton<T>(CycleButtonProps<T> props) Component
Render a cycle button component.
inherited
dataTable<T>(DataTableProps<T> props) Component
inherited
datePicker(DatePickerProps props) Component
inherited
dialog(DialogProps props) Component
inherited
direction(DirectionProps props) Component
inherited
disclosure(DisclosureProps props) Component
inherited
disclosureGroup(DisclosureGroupProps props) Component
inherited
drawer(DrawerProps props) Component
inherited
inherited
emptyState(EmptyStateProps props) Component
Renders an empty state placeholder component.
inherited
expanded(ExpandedProps props) Component
inherited
expandingFabPromo(ExpandingFabPromoProps props) Component
Render an expanding FAB promo component.
inherited
fadeEdge(FadeEdgeProps props) Component
inherited
featureRow(FeatureRowProps props) Component
inherited
fieldWrapper(FieldWrapperProps props) Component
inherited
flexiCards(FlexiCardsProps props) Component
inherited
flexiCardsSimple(FlexiCardsSimpleProps props) Component
inherited
floating(FloatingProps props) Component
inherited
flow(FlowProps props) Component
inherited
form(FormProps props) Component
inherited
formSection(FormSectionProps props) Component
inherited
fullscreenTakeover(FullscreenTakeoverProps props) Component
Render a fullscreen takeover component.
inherited
gap(GapProps props) Component
inherited
gutter(GutterProps props) Component
inherited
inlineHeroBanner(InlineHeroBannerProps props) Component
Render an inline hero banner component.
inherited
inputGroup(InputGroupProps props) Component
inherited
item(ItemProps props) Component
inherited
kbd(KbdProps props) Component
Renders a keyboard shortcut display component.
inherited
keyValueTable(KeyValueTableProps props) Component
inherited
loadingSpinner(LoadingSpinnerProps props) Component
Renders a loading spinner component.
inherited
marqueeTickerBar(MarqueeTickerBarProps props) Component
Render a marquee ticker bar component.
inherited
inherited
minimizablePromo(MinimizablePromoProps props) Component
Render a minimizable promo component.
inherited
nativeSelect(NativeSelectProps props) Component
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
otpInput(OtpInputProps props) Component
Render an OTP input component.
inherited
paddingWrapper(PaddingWrapperProps props) Component
inherited
pagination(PaginationProps props) Component
Renders a pagination control.
inherited
progress(ProgressProps props) Component
Renders a linear progress bar component.
inherited
progressClaimBanner(ProgressClaimBannerProps props) Component
Render a progress claim banner component.
inherited
promoModal(PromoModalProps props) Component
Render a promo modal component.
inherited
radioGroup<T>(RadioGroupProps<T> props) Component
Render a radio group component.
inherited
resizable(ResizableProps props) Component
inherited
row(RowProps props) Component
inherited
scrollArea(ScrollAreaProps props) Component
Renders a scroll area component.
inherited
scrollRail(ScrollRailProps props) Component
inherited
scrollRailLayout(ScrollRailLayoutProps props) Component
inherited
select<T>(SelectProps<T> props) Component
inherited
separator(SeparatorProps props) Component
Renders a separator/divider component.
inherited
sheet(SheetProps props) Component
inherited
Renders the main sidebar container.
inherited
sidebarCollapsed(List<Component> children) Component
Renders content shown when sidebar is collapsed.
inherited
sidebarExpanded(List<Component> children) Component
Renders content shown when sidebar is expanded.
inherited
sidebarGroup(SidebarGroupProps props) Component
Renders a sidebar group with optional label.
inherited
sidebarItem(SidebarItemProps props) Component
Renders a sidebar navigation item.
inherited
sidebarSection(SidebarSectionProps props) Component
Renders a fixed (non-collapsible) sidebar section.
inherited
sidebarSeparator() Component
Renders a sidebar separator.
inherited
sidebarSubMenu(SidebarSubMenuProps props) Component
Renders a collapsible sidebar submenu.
inherited
sizedBox(SizedBoxProps props) Component
inherited
skeleton(SkeletonProps props) Component
Renders a skeleton loading placeholder component.
inherited
slider(SliderProps props) Component
Render a slider component.
inherited
slidingSidebarBanner(SlidingSidebarBannerProps props) Component
Render a sliding sidebar banner component.
inherited
slotCounter(SlotCounterProps props) Component
inherited
slotCounterCard(SlotCounterCardProps props) Component
inherited
slotCounterRow(SlotCounterRowProps props) Component
inherited
spacer(SpacerProps props) Component
inherited
specRow(SpecRowProps props) Component
Renders a spec row component.
inherited
staticTable(StaticTableProps props) Component
inherited
statusBadge(StatusBadgeProps props) Component
inherited
tabBar(TabBarProps props) Component
Renders a standalone tab bar without content panels.
inherited
tabs(TabsProps props) Component
Renders a tabbed interface with content panels.
inherited
textInput(TextInputProps props) Component
Render a text input component.
inherited
timePicker(TimePickerProps props) Component
Render a time picker component.
inherited
toast(ToastProps props) Component
inherited
toastContainer(ToastContainerProps props) Component
inherited
toggleButton(ToggleButtonProps props) Component
Render a toggle button component.
inherited
toggleGroup(ToggleGroupProps props) Component
inherited
toggleSwitch(ToggleSwitchProps props) Component
Render a toggle switch component.
inherited
toolbar(ToolbarProps props) Component
inherited
topAnnouncementBar(TopAnnouncementBarProps props) Component
Render a top announcement bar component.
inherited
toString() String
A string representation of this object.
inherited
virtualScroll<T>(VirtualScrollProps<T> props) Component
Renders a virtualized scroll list component.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited