ComponentRenderers class abstract

Interface that all stylesheets must implement.

Implementers

Constructors

ComponentRenderers()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accordion(AccordionProps props) Component
Render an accordion component
alert(AlertProps props) Component
Render an alert component
alertBanner(AlertBannerProps props) Component
Render an alert banner component
alertDialog(AlertDialogProps props) Component
Render an alert dialog component
animatedCounter(AnimatedCounterProps props) Component
Render an animated counter component
animatedGradientText(AnimatedGradientTextProps props) Component
Render an animated gradient text component
arcaneChip(ArcaneChipProps props) Component
Render a selectable chip component
arcaneDivider(ArcaneDividerProps props) Component
Render an arcane divider component
Render an arrow link component
aspectRatio(AspectRatioProps props) Component
Render an aspect ratio container
Render an auth back link component
authBrandingPanel(AuthBrandingPanelProps props) Component
Render an auth branding panel component
authLayout(AuthLayoutProps props) Component
Render an auth layout component
authorCard(AuthorCardProps props) Component
Render an author card component
authSplitLayout(AuthSplitLayoutProps props) Component
Render an auth split layout component
avatar(AvatarProps props) Component
Render an avatar component
badge(BadgeProps props) Component
Render a badge component
bar(BarProps props) Component
Render a bar/app bar component
bottomBar(BottomBarProps props) Component
Render a bottom bar component
bottomNavigationBar(BottomNavigationBarProps props) Component
Render a bottom navigation bar component
Render a breadcrumbs component
button(ButtonProps props) Component
Render a button component
buttonGroup(ButtonGroupProps props) Component
Render a button group component
buttonPanel(ButtonPanelProps props) Component
Render a button panel component
calendar(CalendarProps props) Component
Render a calendar component
callout(CalloutProps props) Component
Render a callout component
card(CardProps props) Component
Render a card component
cardSection(CardSectionProps props) Component
Render a card section component
carpet(CarpetProps props) Component
Render a carpet component
center(CenterProps props) Component
Render a center component
centerBody(CenterBodyProps props) Component
Render a center body component
checkbox(CheckboxProps props) Component
Render a checkbox component
checkItem(CheckItemProps props) Component
Render a check item component
checkList(CheckListProps props) Component
Render a check list component
chip(ChipProps props) Component
Render a chip component
chipGroup(ChipGroupProps props) Component
Render a chip group component
circularProgress(CircularProgressProps props) Component
Render a circular progress component
codePreview(CodePreviewProps props) Component
Render a code preview component
codeSnippet(CodeSnippetProps props) Component
Render a code snippet component
codeWindow(CodeWindowProps props) Component
Render a code window component
colorInput(ColorInputProps props) Component
Render a color input component
column(ColumnProps props) Component
Render a column layout component
command(CommandProps props) Component
Render a command palette component
confirmDialog(ConfirmDialogProps props) Component
Render a confirm dialog component
contextMenu(ContextMenuProps props) Component
Render a context menu component
counterRow(CounterRowProps props) Component
Render a counter row component
ctaBanner(CtaBannerProps props) Component
Render a CTA banner component
ctaGroup(CtaGroupProps props) Component
Render a CTA group component
cycleButton<T>(CycleButtonProps<T> props) Component
Render a cycle button component
dashboardLayout(DashboardLayoutProps props) Component
Render a dashboard layout component
dashboardTopBar(DashboardTopBarProps props) Component
Render a dashboard top bar component
dataTable<T>(DataTableProps<T> props) Component
Render a data table component
datePicker(DatePickerProps props) Component
Render a date picker component
dialog(DialogProps props) Component
Render a dialog component
dialogBar(DialogBarProps props) Component
Render a dialog bar component
disclosure(DisclosureProps props) Component
Render a disclosure component
disclosureGroup(DisclosureGroupProps props) Component
Render a disclosure group component
divider(DividerProps props) Component
Render a divider component
dotIndicator(DotIndicatorProps props) Component
Render a dot indicator component
drawer(DrawerProps props) Component
Render a drawer component
Render a dropdown menu component
emptyState(EmptyStateProps props) Component
Render an empty state component
errorState(ErrorStateProps props) Component
Render an error state component
expanded(ExpandedProps props) Component
Render an expanded component
expander(ExpanderProps props) Component
Render an expander component
fab(FABProps props) Component
Render a floating action button component
fadeEdge(FadeEdgeProps props) Component
Render a fade edge component
featureCard(FeatureCardProps props) Component
Render a feature card component
featureRow(FeatureRowProps props) Component
Render a feature row component
featureShowcase(FeatureShowcaseProps props) Component
Render a feature showcase component
fieldWrapper(FieldWrapperProps props) Component
Render a field wrapper component
fileUpload(FileUploadProps props) Component
Render a file upload component
flexiCards(FlexiCardsProps props) Component
Render a flexi cards component
flexiCardsSimple(FlexiCardsSimpleProps props) Component
Render a simple flexi cards component
flow(FlowProps props) Component
Render a flow layout component
Render a footer component
footerBrandColumn(FooterBrandColumnProps props) Component
Render a footer brand column component
footerColumn(FooterColumnProps props) Component
Render a footer column component
footerSocialIcon(FooterSocialIconProps props) Component
Render a footer social icon component
form(FormProps props) Component
Render a form component
formSection(FormSectionProps props) Component
Render a form section component
gameCard(GameCardProps props) Component
Render a game card component
gameSelector(GameSelectorProps props) Component
Render a game selector grid component
gameTile(GameTileProps props) Component
Render a game tile component
gap(GapProps props) Component
Render a gap component
glass(GlassProps props) Component
Render a glass container component
glassCard(GlassCardProps props) Component
Render a glass card component
glowText(GlowTextProps props) Component
Render a glow text component
gradientGlass(GradientGlassProps props) Component
Render a gradient glass component
gradientText(GradientTextProps props) Component
Render a gradient text component
gutter(GutterProps props) Component
Render a gutter component
hamburgerButton(HamburgerButtonProps props) Component
Render a hamburger button component
Render a header/navbar component
heroSection(HeroSectionProps props) Component
Render a hero section component
hovercard(HovercardProps props) Component
Render a hovercard component
iconButton(IconButtonProps props) Component
Render an icon button component
iconCard(IconCardProps props) Component
Render an icon card component
indexedStack(IndexedStackProps props) Component
Render an indexed stack component
inlineCode(InlineCodeProps props) Component
Render an inline code component
inputDialog(InputDialogProps props) Component
Render an input dialog component (text, email, password, multiline, number)
inputGroup(InputGroupProps props) Component
Render an input group component
integrationCard(IntegrationCardProps props) Component
Render an integration card component
integrationGrid(IntegrationGridProps props) Component
Render an integration grid component
itemPicker<T>(ItemPickerProps<T> props) Component
Render an item picker dialog component
kbd(KbdProps props) Component
Render a keyboard shortcut display component
keyValueTable(KeyValueTableProps props) Component
Render a key-value table component
listCard(ListCardProps props) Component
Render a list card component
loader(LoaderProps props) Component
Render a loader component
loadingOverlay(LoadingOverlayProps props) Component
Render a loading overlay component
loadingSpinner(LoadingSpinnerProps props) Component
Render a loading spinner component
loadingState(LoadingStateProps props) Component
Render a loading state component
logoCarousel(LogoCarouselProps props) Component
Render a logo carousel component
logoGrid(LogoGridProps props) Component
Render a logo grid component
marquee(MarqueeProps props) Component
Render a marquee component
Render a menubar component
meter(MeterProps props) Component
Render a meter/gauge component
metricDisplay(MetricDisplayProps props) Component
Render a metric display component
mobileMenu(MobileMenuProps props) Component
Render a mobile menu component
Render a standalone nav link component
Render a navigation tile component
newsletterForm(NewsletterFormProps props) Component
Render a newsletter form component
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
numberInput(NumberInputProps props) Component
Render a number input component
otpInput(OtpInputProps props) Component
Render an OTP input component
outlineText(OutlineTextProps props) Component
Render an outline text component
paddingWrapper(PaddingWrapperProps props) Component
Render a padding wrapper component
pageBody(PageBodyProps props) Component
Render a page body component
pagination(PaginationProps props) Component
Render a pagination component
popover(PopoverProps props) Component
Render a popover component
pricingCard(PricingCardProps props) Component
Render a pricing card component
pricingGrid(PricingGridProps props) Component
Render a pricing grid component
progress(ProgressProps props) Component
Render a progress bar component
radioCards<T>(RadioCardsProps<T> props) Component
Render a radio cards component
radioGroup<T>(RadioGroupProps<T> props) Component
Render a radio group component
ratingStars(RatingStarsProps props) Component
Render a rating stars component
ratingStarsSimple(RatingStarsSimpleProps props) Component
Render a simple rating stars component
resizable(ResizableProps props) Component
Render a resizable panel group component
row(RowProps props) Component
Render a row layout component
scrollArea(ScrollAreaProps props) Component
Render a scroll area component
scrollRail(ScrollRailProps props) Component
Render a scroll rail component
scrollRailLayout(ScrollRailLayoutProps props) Component
Render a scroll rail layout component
Render a search input component
section(SectionProps props) Component
Render a section component
sectionHeader(SectionHeaderProps props) Component
Render a section header component
select<T>(SelectProps<T> props) Component
Render a select/selector component
selectableChipGroup(SelectableChipGroupProps props) Component
Render a selectable chip group component
separator(SeparatorProps props) Component
Render a separator component
settingsInfoRow(SettingsInfoRowProps props) Component
Render a settings info row component
settingsNote(SettingsNoteProps props) Component
Render a settings note component
settingsSection(SettingsSectionProps props) Component
Render a settings section component
settingsSubheader(SettingsSubheaderProps props) Component
Render a settings subheader component
settingsToggleRow(SettingsToggleRowProps props) Component
Render a settings toggle row component
sheet(SheetProps props) Component
Render a sheet/drawer component
Render a sidebar component
sidebarCollapsed(List<Component> children) Component
Render content only when sidebar is collapsed
sidebarExpanded(List<Component> children) Component
Render content only when sidebar is expanded
sidebarGroup(SidebarGroupProps props) Component
Render a sidebar group component
sidebarItem(SidebarItemProps props) Component
Render a sidebar item component
sidebarSeparator() Component
Render a sidebar separator
sidebarSubMenu(SidebarSubMenuProps props) Component
Render a sidebar submenu (collapsible nested items)
sizedBox(SizedBoxProps props) Component
Render a sized box component
skeleton(SkeletonProps props) Component
Render a skeleton component
slider(SliderProps props) Component
Render a slider component
slotCounter(SlotCounterProps props) Component
Render a slot counter component
slotCounterCard(SlotCounterCardProps props) Component
Render a slot counter card component
slotCounterRow(SlotCounterRowProps props) Component
Render a slot counter row component
socialIcon(SocialIconProps props) Component
Render a social icon component
socialIconGroup(SocialIconGroupProps props) Component
Render a social icon group component
Render a social links component
spacer(SpacerProps props) Component
Render a spacer component
statCard(StatCardProps props) Component
Render a stat card component
statCardRow(StatCardRowProps props) Component
Render a stat card row component
statDisplay(StatDisplayProps props) Component
Render a stat display component
staticTable(StaticTableProps props) Component
Render a static table component
statRow(StatRowProps props) Component
Render a stat row component
statusBadge(SimpleStatusBadgeProps props) Component
Render a simple status badge component
statusBadge2(StatusBadgeProps props) Component
Render a status badge component
statusIndicator(StatusIndicatorProps props) Component
Render a status indicator component
stepIndicator(StepIndicatorProps props) Component
Render a step indicator component
stepper(StepperProps props) Component
Render a stepper/steps component
surface(SurfaceProps props) Component
Render a surface component
surfaceCard(SurfaceCardProps props) Component
Render a surface card component
switcher(SwitcherProps props) Component
Render a switcher component
tabBar(TabBarProps props) Component
Render a tab bar component (tabs only, no content)
tabs(TabsProps props) Component
Render a tabs component (tab bar + content panel)
tagInput(TagInputProps props) Component
Render a tag input component
terminal(TerminalProps props) Component
Render a terminal component
testimonialCard(TestimonialCardProps props) Component
Render a testimonial card component
textInput(TextInputProps props) Component
Render a text input component
thumbHashCard(ThumbHashCardProps props) Component
Render a thumbhash card component
tile(TileProps props) Component
Render a tile component
timeDialog(TimeDialogProps props) Component
Render a time dialog component
timeline(TimelineProps props) Component
Render a timeline component
timePicker(TimePickerProps props) Component
Render a time picker component
toast(ToastProps props) Component
Render a toast notification component
toastContainer(ToastContainerProps props) Component
Render a toast container component
toggleButton(ToggleButtonProps props) Component
Render a toggle button component
toggleGroup(ToggleGroupProps props) Component
Render a toggle group component
toggleSwitch(ToggleSwitchProps props) Component
Render a toggle switch component
toolbar(ToolbarProps props) Component
Render a toolbar component
tooltip(TooltipProps props) Component
Render a tooltip component
toString() String
A string representation of this object.
inherited
tracker(TrackerProps props) Component
Render a tracker component
treeView(TreeViewProps props) Component
Render a tree view component
uptimeTracker(UptimeTrackerProps props) Component
Render an uptime tracker component
virtualScroll<T>(VirtualScrollProps<T> props) Component
Render a virtual scroll component
waitlistForm(WaitlistFormProps props) Component
Render a waitlist form component

Operators

operator ==(Object other) bool
The equality operator.
inherited