SidebarGroupRenderBase class abstract
Collapsible sidebar group. Shared between the neon and neubrutalism themes; the root/label CSS classes and the label inline styles vary per theme.
- Inheritance
-
- Object
- Component
- StatelessComponent
- SidebarGroupRenderBase
Constructors
- SidebarGroupRenderBase(SidebarGroupProps props, {Key? key})
-
const
Properties
- cssClass → String
-
CSS class applied to the group root element.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- labelClass → String
-
CSS class applied to the group label element.
no setter
-
labelStyles
→ Map<
String, String> -
Inline styles for the group label element.
no setter
- props → SidebarGroupProps
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited