ComponentSize enum
Unified size enum supporting both naming conventions. Use whichever style you prefer - they are aliases.
Values
- sm → const ComponentSize
- md → const ComponentSize
- lg → const ComponentSize
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- large → const ComponentSize
- Alias for lg
- medium → const ComponentSize
- Alias for md
- small → const ComponentSize
- Alias for sm
-
values
→ const List<
ComponentSize> - A constant List of the values in this enum, in order of their declaration.