core/theme_provider library
Classes
- AccordionItemProps
- Accordion item data.
- AccordionProps
- Accordion component properties.
- AlertDialogProps
- Alert dialog component properties.
- AlertProps
- Alert component properties.
- ArcaneMenuItem
- Sealed class hierarchy for menu items. Use pattern matching to handle different item types in renderers.
- ArcaneStylesheet
- Base class for stylesheets.
- ArcaneThemeProvider
- Provides the current stylesheet and brightness to the component tree.
- AspectRatioProps
- Aspect ratio container component properties.
- AvatarProps
- Avatar component properties.
- BadgePosition
- Position configuration for absolutely positioned badges.
- BottomFloatingBannerProps
- Props for the bottom floating banner.
- BreadcrumbItemProps
- Breadcrumb item data.
- BreadcrumbsProps
- Breadcrumbs component properties.
- ButtonGroupProps
- Button group component properties.
- ButtonPanelProps
- Button panel component properties.
- ButtonProps
- Button component properties.
- CalendarProps
- Calendar component properties.
- CardProps
- Card component properties.
- CenterProps
- Center alignment component properties.
- ChartPointProps
- ChartProps
- CheckboxProps
- Checkbox component properties.
- CheckItemProps
- Check item component properties.
- CheckListProps
- Check list component properties.
- CircularProgressProps
- Circular progress component properties.
- ColumnProps
- Column layout component properties.
- CommandGroupProps
- Command group data.
- CommandItemProps
- Command item data.
- CommandProps
- Command palette component properties.
- ComponentRenderers
- ConfirmDialogProps
- Confirm dialog component properties.
- ContextMenuProps
- Context menu component properties.
- CornerPromoToastProps
- Props for the corner promo toast.
-
CycleButtonProps<
T> - Cycle button component properties.
-
CycleOption<
T> - Cycle option data.
-
DataColumnProps<
T> - Data column definition.
-
DataTableProps<
T> - Data table component properties.
- DatePickerProps
- Date picker component properties.
- DateRangeValue
- Date range value.
- DialogProps
- Dialog component properties.
- DirectionProps
- DisclosureGroupProps
- Disclosure group component properties.
- DisclosureItemProps
- Disclosure item data.
- DisclosureProps
- Disclosure component properties.
- DrawerProps
- Drawer component properties.
- DropdownMenuProps
- Dropdown menu component properties.
- EmptyStateProps
- Empty state component properties.
- ExpandedProps
- Expanded component properties.
- ExpandingFabPromoProps
- Props for the expanding FAB promo.
- FadeEdgeProps
- Fade edge component properties.
- FeatureRowProps
- Feature row component properties.
- FieldWrapperProps
- Field wrapper component properties.
- FlexiCardItem
- Flexi card item data.
- FlexiCardsProps
- FlexiCards component properties.
- FlexiCardsSimpleProps
- FlexiCards simple component properties.
- FloatingProps
- Unified floating component properties.
- FlowProps
- Flow layout component properties.
- FormProps
- Form component properties.
- FormSectionProps
- Form section component properties.
- FullscreenTakeoverProps
- Props for the fullscreen takeover.
- GapProps
- Gap component properties.
- GutterProps
- Gutter/spacing component properties.
- InlineHeroBannerProps
- Props for the inline hero banner.
- InputGroupProps
- Input group component properties.
- ItemProps
- KbdProps
- Keyboard shortcut display component properties.
- KeyValueRowData
- Key-value row data.
- KeyValueTableProps
- Key-value table component properties.
- LoadingSpinnerProps
- Loading spinner component properties.
- MarqueeTickerBarProps
- Props for the marquee ticker bar.
- MenubarMenuProps
- Menubar menu data.
- MenubarProps
- Menubar component properties.
- MenuItemAction
- Standard clickable menu item.
- MenuItemCheckbox
- Checkbox menu item.
- MenuItemLabel
- Label/header for grouping items (non-interactive).
- MenuItemRadio
- Radio menu item (part of a group).
- MenuItemSeparator
- Visual separator between menu items.
- Submenu with nested items.
- MinimizablePromoProps
- Props for the minimizable promo.
- NativeSelectOptionProps
- NativeSelectProps
- OtpInputProps
- OTP input component properties.
- PaddingWrapperProps
- Padding wrapper component properties.
- PaginationProps
- Pagination component properties.
- ProgressClaimBannerProps
- Props for the progress claim banner.
- ProgressProps
- Progress bar component properties.
- PromoModalProps
- Props for the promo modal.
-
RadioGroupProps<
T> - Radio group component properties.
-
RadioOptionProps<
T> - Radio option data.
- ResizablePanelData
- Resizable panel data.
- ResizableProps
- Resizable panel group component properties.
- RowProps
- Row layout component properties.
- ScrollAreaProps
- Scroll area component properties.
- ScrollRailLayoutProps
- Scroll rail layout component properties.
- ScrollRailProps
- Scroll rail component properties.
-
SelectOptionProps<
T> - Select option data.
-
SelectProps<
T> - Select component properties.
- SeparatorProps
- Unified separator component properties.
- SheetProps
- Sheet/drawer component properties.
- SidebarGroupProps
- Sidebar group component properties.
- SidebarItemProps
- Sidebar item component properties.
- SidebarProps
- Sidebar component properties.
- SidebarSectionProps
- Sidebar section component properties (fixed, non-collapsible section).
- SidebarSubMenuProps
- Sidebar submenu component properties (collapsible section).
- SizedBoxProps
- SizedBox component properties.
- SkeletonProps
- Skeleton component properties.
- SliderProps
- Slider component properties.
- SlidingSidebarBannerProps
- Props for the sliding sidebar banner.
- SlotCounterCardProps
- Slot counter card component properties.
- SlotCounterProps
- Slot counter component properties.
- SlotCounterRowProps
- Slot counter row component properties.
- SpacerProps
- Spacer component properties.
- SpecRowProps
- Spec row component properties.
- StaticTableProps
- Static table component properties.
- StatusBadgeProps
- Unified badge component properties.
- TabBarItemProps
- Tab bar item data.
- TabBarProps
- Tab bar component properties.
- TabItemProps
- Tab item data.
- TabsProps
- Tabs component properties.
- TextInputProps
- Text input component properties.
- TimeOfDay
- Represents a time of day with hour and minute.
- TimePickerProps
- Time picker component properties.
- ToastAction
- Toast action button data.
- ToastContainerProps
- Toast container component properties.
- ToastProps
- Toast component properties.
- ToggleButtonProps
- Toggle button component properties.
- ToggleGroupItemProps
- Toggle group item data.
- ToggleGroupProps
- Toggle group component properties.
- ToggleSwitchProps
- Toggle switch component properties.
- ToolbarProps
- Toolbar component properties.
- TopAnnouncementBarProps
- Props for the top announcement bar.
-
VirtualScrollProps<
T> - Virtual scroll component properties.
Enums
- AccordionVariant
- Accordion variant styles.
- AlertStyle
- Alert visual style variant.
- AvatarShape
- AvatarSize
- Avatar size with extended range for flexibility.
- BadgeVariant
- Badge variant for all badge styles.
- BreadcrumbSeparatorStyle
- BreadcrumbSizeVariant
- Brightness
- Brightness mode for the application.
- ButtonSize
- Button size enum with icon variants. Supports both abbreviated (sm/md/lg) and spelled-out (small/medium/large) styles.
- ButtonVariant
- CalendarModeVariant
- CardVariant
- CheckStyle
- ColorVariant
- Color variants for semantic meaning.
- ComponentSize
- Unified size enum supporting both naming conventions. Use whichever style you prefer - they are aliases.
- CycleButtonSize
- CycleButtonVariant
- DataTableTextAlign
- DatePickerSizeVariant
- DirectionValue
- DisclosureVariant
- DrawerPosition
- DrawerSize
- DropdownAlignment
- EmptyStateSizeVariant
- EmptyStateStyleVariant
- FadeDirection
- FloatingPosition
- Position of floating content relative to trigger.
- FloatingTrigger
- Floating content trigger mode.
- GutterSize
- KbdStyle
- OtpInputSizeVariant
- PaginationSizeVariant
- PaginationStyleVariant
- ProgressVariant
- PromoCornerPosition
- Position for the corner promo toast.
- PromoInlineHeroBannerStyle
- Style variants for the inline hero banner.
- PromoSidebarPosition
- Position for the sliding sidebar.
- RadioGroupLayout
- RadioGroupVariant
- ResizeDirection
- ScrollbarStyleVariant
- ScrollbarVisibilityVariant
- ScrollDirectionVariant
- ScrollRailPosition
- ScrollRailSize
- SelectDropdownDirection
- SeparatorOrientation
- Separator orientation.
- SeparatorVariant
- Separator visual style variants.
- SheetSizeVariant
- SkeletonShape
- SliderVariant
- SlotCounterColor
- SlotCounterSize
- StatusType
- StyleVariant
- Style variants for visual treatment.
- TextInputType
- TextInputVariant
- ThemeMode
- Theme mode selection.
- ToastPosition
- ToastVariant
- ToggleGroupSelectionType
- ToggleGroupSizeVariant
- ToggleGroupVariantStyle
Mixins
- AccordionRendererContract
- Mixin defining the renderer methods for accordion components.
- AlertRendererContract
- Mixin defining the renderer methods for alert components.
- AspectRatioRendererContract
- Mixin defining the renderer methods for aspect ratio components.
- AvatarRendererContract
- Mixin defining the renderer methods for avatar components.
- BreadcrumbsRendererContract
- Mixin defining the renderer methods for breadcrumb components.
- ButtonPanelRendererContract
- Mixin defining the renderer methods for button panel components.
- ButtonRendererContract
- Mixin defining the renderer method for button components.
- CalendarRendererContract
- Mixin defining the renderer methods for calendar components.
- CardRendererContract
- Mixin defining the renderer methods for card components.
- ChartRendererContract
- CheckboxRendererContract
- Mixin defining the renderer method for checkbox components.
- CheckListRendererContract
- Mixin defining the renderer methods for check list components.
- CommandRendererContract
- Mixin defining the renderer methods for command palette components.
- ConfirmDialogRendererContract
- Mixin defining the renderer methods for confirm and alert dialog components.
- ContextMenuRendererContract
- Mixin defining the renderer methods for context menu components.
- CycleButtonRendererContract
- Mixin defining the renderer methods for cycle button and toggle button components.
- DataTableRendererContract
- Mixin defining the renderer methods for data table components.
- DatePickerRendererContract
- Mixin defining the renderer methods for date picker components.
- DialogRendererContract
- Mixin defining the renderer methods for dialog components.
- DirectionRendererContract
- DisclosureRendererContract
- Mixin defining the renderer methods for disclosure components.
- DrawerRendererContract
- Mixin defining the renderer methods for drawer components.
- DropdownMenuRendererContract
- Mixin defining the renderer methods for dropdown menu components.
- EmptyStateRendererContract
- Mixin defining the renderer methods for empty state components.
- FadeEdgeRendererContract
- Mixin defining the renderer methods for fade edge components.
- FieldWrapperRendererContract
- Mixin defining the renderer methods for field wrapper components.
- FlexiCardsRendererContract
- Mixin defining the renderer methods for flexi cards components.
- FloatingRendererContract
- Mixin defining the renderer methods for floating components.
- FlowRendererContract
- Mixin defining the renderer methods for flow/layout components.
- GutterRendererContract
- Mixin defining the renderer methods for gutter/spacing components.
- ItemRendererContract
- KbdRendererContract
- Mixin defining the renderer methods for keyboard shortcut components.
- MenubarRendererContract
- Mixin defining the renderer methods for menubar components.
- NativeSelectRendererContract
- OtpInputRendererContract
- Mixin defining the renderer method for OTP input components.
- PaginationRendererContract
- Mixin defining the renderer methods for pagination components.
- ProgressRendererContract
- Mixin defining the renderer methods for progress components.
- PromoRendererContract
- Mixin defining the renderer methods for promo components.
- RadioGroupRendererContract
- Mixin defining the renderer method for radio group components.
- ResizableRendererContract
- Mixin defining the renderer methods for resizable components.
- ScrollAreaRendererContract
- Mixin defining the renderer methods for scroll area components.
- ScrollRailRendererContract
- Mixin defining the renderer methods for scroll rail components.
- SelectRendererContract
- Mixin defining the renderer methods for select components.
- SeparatorRendererContract
- Mixin defining the renderer methods for separator components.
- SidebarRendererContract
- Mixin defining the renderer methods for sidebar components.
- SkeletonRendererContract
- Mixin defining the renderer methods for skeleton components.
- SliderRendererContract
- Mixin defining the renderer method for slider components.
- SlotCounterRendererContract
- Mixin defining the renderer methods for slot counter components.
- SpecRowRendererContract
- Mixin defining the renderer methods for spec row components.
- StaticTableRendererContract
- Mixin defining the renderer methods for static table components.
- StatusBadgeRendererContract
- Mixin defining the renderer methods for status badge components.
- TabsRendererContract
- Mixin defining the renderer methods for tab components.
- TextInputRendererContract
- Mixin defining the renderer method for text input components.
- TimePickerRendererContract
- Mixin defining the renderer method for time picker components.
- ToastRendererContract
- Mixin defining the renderer methods for toast components.
- ToggleGroupRendererContract
- Mixin defining the renderer methods for toggle group components.
- ToggleSwitchRendererContract
- Mixin defining the renderer method for toggle switch components.
Extensions
- ArcaneThemeContext on BuildContext
- Extension for easy access to theme properties from context.