ArcaneThemeProvider class
Provides the current stylesheet and brightness to the component tree.
- Inheritance
-
- Object
- Component
- InheritedComponent
- InheritedWidget
- ArcaneThemeProvider
Constructors
- ArcaneThemeProvider({required ArcaneStylesheet stylesheet, Brightness brightness = Brightness.dark, required Component child, Key? key})
-
const
Properties
- brightness → Brightness
-
final
- child → Component
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- renderers → ComponentRenderers
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stylesheet → ArcaneStylesheet
-
final
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant ArcaneThemeProvider oldComponent) → bool -
Whether the framework should notify components that inherit from this component.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → ArcaneThemeProvider?