flutter library
Classes
- BuildContext
- The BuildContext supplied to a Components build() method.
- InheritedWidget
- Key
- A Key is an identifier for Components and Elements.
- StatefulWidget
- StatelessWidget
- UniqueKey
- A key that is only equal to itself.
-
ValueKey<
T> - A key that uses a value of a particular type to identify itself.
Typedefs
-
State<
T extends StatefulWidget> = State< T> - Widget = Component