flutter library
Classes
- BuildContext
- The BuildContext supplied to a Components build() method.
- Builder
- A stateless utility component whose build method uses its builder callback to create the component's child.
- InheritedWidget
- Key
- A Key is an identifier for Components and Elements.
- StatefulWidget
- StatelessWidget
- UniqueKey
- A key that is only equal to itself.
-
ValueKey<
T> - A key that uses a value of a particular type to identify itself.
Typedefs
-
AsyncCallback
= Future<
void> Function() - Signature of callbacks that have no arguments and return no data, but that return a Future to indicate when their work is complete.
- IndexedWidgetBuilder = Widget Function(BuildContext context, int index)
- NullableIndexedWidgetBuilder = Widget? Function(BuildContext context, int index)
-
State<
T extends StatefulWidget> = State< T> -
ValueChanged<
T> = void Function(T value) - Signature for callbacks that report that an underlying value has changed.
-
ValueGetter<
T> = T Function() - Signature for callbacks that are to report a value on demand.
-
ValueSetter<
T> = void Function(T value) - Signature for callbacks that report that a value has been set.
- VoidCallback = void Function()
- Signature of callbacks that have no arguments and return no data.
- Widget = Component
- WidgetBuilder = Widget Function(BuildContext context)