InheritedWidget class abstract
- Inheritance
-
- Object
- Component
- InheritedComponent
- InheritedWidget
- Implementers
Constructors
- InheritedWidget({required Component child, Key? key})
-
const
Properties
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant InheritedComponent oldComponent) → bool -
Whether the framework should notify components that inherit from this component.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited