JasprAuthService class
Stub implementation of JasprAuthService for non-web platforms.
Properties
-
authStateStream
→ Stream<
AuthState> -
no setter
- currentState → AuthState
-
no setter
- currentUser → AuthUser?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAccount(
) → Future< bool> -
dispose(
) → void -
initialize(
{String? serverApiUrl}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshToken(
) → Future< String?> -
registerWithEmail(
String email, String password, String displayName) → Future< void> -
sendPasswordResetEmail(
String email) → Future< void> -
signInWithApple(
) → Future< void> -
signInWithEmail(
String email, String password) → Future< void> -
signInWithGitHub(
) → Future< void> -
signInWithGoogle(
) → Future< void> -
signOut(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → JasprAuthService
-
no setter