AuthUser class
Represents an authenticated user.
Constructors
Properties
- displayName → String?
-
final
- email → String?
-
final
- emailVerified → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idToken → String?
-
final
- isAnonymous → bool
-
final
- photoURL → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid → String
-
final
Methods
-
copyWith(
{String? uid, String? email, String? displayName, String? photoURL, String? idToken, bool? isAnonymous, bool? emailVerified}) → AuthUser -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited