CodexAccent enum
Available accent themes for Codex.
Values
- green → const CodexAccent
-
Emerald green - #10b981
const CodexAccent(0xFF10b981) - red → const CodexAccent
-
Bright red - #ef4444
const CodexAccent(0xFFef4444) - blue → const CodexAccent
-
Electric blue - #3b82f6
const CodexAccent(0xFF3b82f6) - purple → const CodexAccent
-
Vibrant purple - #8b5cf6
const CodexAccent(0xFF8b5cf6) - cyan → const CodexAccent
-
Neon cyan - #22d3ee
const CodexAccent(0xFF22d3ee) - pink → const CodexAccent
-
Hot pink - #ec4899
const CodexAccent(0xFFec4899) - orange → const CodexAccent
-
Bright orange - #f97316
const CodexAccent(0xFFf97316) - rainbow → const CodexAccent
-
Rainbow RGB spin - cycles through all colors. Uses cyan as the base color, with CSS animation override.
const CodexAccent(0xFF22d3ee)
Properties
- color → int
-
The color value for this accent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CodexAccent> - A constant List of the values in this enum, in order of their declaration.