CssGenerator class abstract
Generates CSS variable blocks from ThemePalette.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generate(
ThemePalette palette, {String selector = ':root', FontConfig fonts = const FontConfig(), RadiusConfig radius = const RadiusConfig(), bool includeStatic = true}) → String - Generate CSS variables for a single palette.
-
generateBoth(
{required ThemePalette light, required ThemePalette dark, FontConfig fonts = const FontConfig(), RadiusConfig radius = const RadiusConfig()}) → String - Generate CSS for both light and dark mode.