RadiusConfig class

Border radius configuration for a theme.

Constructors

RadiusConfig({String xs = '4px', String sm = '6px', String md = '8px', String lg = '10px', String xl = '14px', String xxl = '18px', String full = '9999px'})
const
RadiusConfig.compact()
Smaller radii for compact/dense UIs.
const
RadiusConfig.large()
Larger radii for modern/gaming aesthetics.
const
RadiusConfig.sharp()
Sharp corners (no rounding except full).
const

Properties

full String
final
hashCode int
The hash code for this object.
no setterinherited
lg String
final
md String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm String
final
xl String
final
xs String
final
xxl String
final

Methods

copyWith({String? xs, String? sm, String? md, String? lg, String? xl, String? xxl, String? full}) RadiusConfig
Create a copy with some fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited