Color class
ARGB color representation with CSS output.
Constructors
Properties
- alpha → int
-
no setter
- blue → int
-
no setter
- css → String
-
no setter
- green → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- hex → String
-
no setter
- opacity → double
-
no setter
- red → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
computeLuminance(
) → double -
darken(
[int amount = 10]) → Color -
lighten(
[int amount = 10]) → Color -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
spin(
double degrees) → Color -
toString(
) → String -
A string representation of this object.
override
-
withAlpha(
int a) → Color -
withOpacity(
double opacity) → Color
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override