Color class
Color utilities for Arcane Jaspr Provides a simple color representation for CSS output
Constructors
Properties
- alpha → int
-
no setter
- blue → int
-
no setter
- css → String
-
Convert to CSS rgba() string
no setter
- green → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- hex → String
-
Convert to CSS hex string
no setter
- opacity → double
-
no setter
- red → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
computeLuminance(
) → double - Compute luminance (0.0 to 1.0)
-
darken(
[int amount = 10]) → Color - Darken the color by a percentage (0-100)
-
lighten(
[int amount = 10]) → Color - Lighten the color by a percentage (0-100)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
spin(
double degrees) → Color - Spin the hue by degrees
-
toString(
) → String -
A string representation of this object.
override
-
withAlpha(
int a) → Color -
withOpacity(
double opacity) → Color
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override