Arcane class
Core Arcane utility class for app-wide operations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- globalTheme ↔ ArcaneTheme
-
Get the global theme
getter/setter pair
Static Methods
- Navigate to a new component (client-side routing)
-
themeOf(
BuildContext context) → ArcaneTheme - Get theme from context or fall back to global