ReadingTimeResult class
Result of reading time calculation.
Constructors
- ReadingTimeResult({required int minutes, required int wordCount})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minutes → int
-
Estimated reading time in minutes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Human-readable reading time string.
no setter
- wordCount → int
-
Total word count.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited