ArcaneRadius class abstract
Border radius design tokens.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- circle → const String
- full → const String
- fullStatic → const String
- lg → const String
- lgStatic → const String
- md → const String
- mdStatic → const String
- none → const String
- sm → const String
- smStatic → const String
- xl → const String
- xlStatic → const String
- xs → const String
- xxl → const String
- xxlStatic → const String