util/style_types/index library
Barrel export for all style types
Classes
- ArcaneStyleData
- Immutable style configuration with type-safe enum properties.
- BadgePresets
- Common badge style presets
- ButtonPresets
- Common button style presets
- CardPresets
- Common card/surface style presets
- GradientBuilder
- Builds a CSS linear-gradient from a list of colors.
- GradientStop
- A color stop in a gradient, supporting both ArcaneColor and raw CSS values.
- InputPresets
- Common input style presets
- LayoutPresets
- Common layout style presets
- OverlayPresets
- Overlay/modal presets
- SectionPresets
- Common section/page style presets
- TextPresets
- Common text style presets
Enums
- AlignItems
- Align items values
- AlignSelf
- Align self values
- AnimationPreset
- Animation presets for common UI patterns
- ArcaneColor
- Semantic color values that map to theme CSS custom properties.
- BackdropFilter
- Backdrop filter presets
- Background
- Background color presets
- BorderColor
- Border color presets
- BorderPreset
- Border presets combining width, style, and color
- BorderStyle
- Border style values
- BorderWidth
- Border width presets
- Cursor
- Cursor presets
- Display
- CSS display property values
- Easing
- Animation timing functions
- FlexDirection
- Flex direction values
- FlexPreset
- Flex shorthand presets
- FlexWrap
- Flex wrap values
- FontFamily
- Font family presets
- FontSize
- Font size presets using rem units
- FontStyle
- Font style values
- Gap
- Gap presets for flex and grid layouts
- GridAutoFlow
- Grid auto-flow values
- GridColumns
- Grid template column presets
- GridRows
- Grid template row presets
- JustifyContent
- Justify content values
- LetterSpacing
- Letter spacing presets
- LineHeight
- Line height presets
- MarginPreset
- Compound margin presets
- MaxHeight
- Max height presets
- MaxWidth
- Max-width container presets
- MinWidth
- Min width presets
- ObjectFit
- Object fit values
- ObjectPosition
- Object position values
- Opacity
- Opacity presets
- OutlinePreset
- Outline presets
- Overflow
- Overflow behavior values
- OverflowAxis
- Overflow X/Y specific values
- PaddingPreset
- Compound padding presets
- PlaceContent
- Place content values
- PlaceItems
- Place items values
- PointerEvents
- Pointer events presets
- Position
- CSS position values
- Radius
- Border radius presets
- Shadow
- Box shadow presets
- Size
- Size keyword presets
- Spacing
- Single-value spacing scale based on 4px unit
- TextColor
- Text/foreground color presets
- TextDecoration
- Text decoration values
- TextTransform
- Text transform values
- Transform
- Transform presets
- TransformOrigin
- Transform origin presets
- Transition
- Transition presets
- UserSelect
- User select presets
- Visibility
- Visibility values
- WhiteSpace
- White space handling values
- WordBreak
- Word break values
- ZIndex
- Z-index layer presets
Extensions
-
ArcaneColorGradient
on List<
ArcaneColor> - Extension for creating gradients from a list of ArcaneColors.