ArcaneSpacing class
Spacing tokens for consistent padding, margin, and gap values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- heroY → const String
- Hero section vertical padding
- huge → const String
- Huge (96px)
- hugeNum → const double
- lg → const String
- Large (24px)
- lgNum → const double
- massive → const String
- Massive (120px)
- massiveNum → const double
- md → const String
- Medium (16px)
- mdNum → const double
- none → const String
- No spacing (0)
- sectionY → const String
- Vertical section padding
- sm → const String
- Small (8px)
- smNum → const double
- xl → const String
- Extra large (32px)
- xlNum → const double
- xs → const String
- Extra small (4px)
- xsNum → const double
- xxl → const String
- 2x Extra large (48px)
- xxlNum → const double
- xxxl → const String
- 3x Extra large (64px)
- xxxlNum → const double