ArcaneTypography class
Typography tokens for font sizes, weights, and line heights
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- font2xl → const String
- 2x large (24px / 1.5rem)
- font3xl → const String
- 3x large (32px / 2rem)
- font4xl → const String
- 4x large (40px / 2.5rem)
- font5xl → const String
- 5x large (48px / 3rem)
- fontBase → const String
- Base (15px / 0.9375rem)
- fontFamily → const String
- System/inherit font family
- fontFamilyMono → const String
- Monospace font family
- fontHero → const String
- Hero size (56px / 3.5rem)
- fontLg → const String
- Large (18px / 1.125rem)
- fontMd → const String
- Medium (14px / 0.875rem)
- fontMega → const String
- Mega size (72px / 4.5rem)
- fontReg → const String
- Regular (16px / 1rem)
- fontSize2xl → const String
- fontSize3xl → const String
- fontSize4xl → const String
- fontSize5xl → const String
- fontSizeBase → const String
- fontSizeHero → const String
- fontSizeLg → const String
- fontSizeMd → const String
- fontSizeMega → const String
- fontSizeSm → const String
- fontSizeXl → const String
- fontSizeXs → const String
- fontSm → const String
- Small (13px / 0.8125rem)
- fontWeightBold → const String
- fontWeightExtrabold → const String
- fontWeightMedium → const String
- fontWeightNormal → const String
- fontWeightSemibold → const String
- fontXl → const String
- Extra large (20px / 1.25rem)
- fontXs → const String
- Extra small (12px / 0.75rem)
- leadingNormal → const String
- Alias for lineHeightNormal
- leadingRelaxed → const String
- Alias for lineHeightRelaxed
- letterSpacingNormal → const String
- Normal letter spacing
- letterSpacingTight → const String
- Tight letter spacing
- letterSpacingWide → const String
- Wide letter spacing
- letterSpacingWidest → const String
- Widest letter spacing
- lineHeightNormal → const String
- Normal (1.5)
- lineHeightRelaxed → const String
- Relaxed (1.7)
- lineHeightSnug → const String
- Snug (1.25)
- lineHeightTight → const String
- Tight (1.1)
- weightBold → const String
- Bold weight (700)
- weightExtrabold → const String
- Extra bold weight (800)
- weightMedium → const String
- Medium weight (500)
- weightNormal → const String
- Normal weight (400)
- weightSemibold → const String
- Semibold weight (600)