AspectRatio.autoOrRatio constructor
Create an aspect ratio where auto auto is used if the element is a replaced element with a natural
aspect ratio, like an element. Otherwise, the specified ratio of num / denom is used as the
preferred aspect ratio.
Implementation
const factory AspectRatio.autoOrRatio(int num, [int? denom]) = _AspectAutoOrRatio;