InheritedModel<T> constructor
Creates an inherited component that supports dependencies qualified by "aspects", i.e. a descendant component can indicate that it should only be rebuilt if a specific aspect of the model changes.
Implementation
const InheritedModel({super.key, required super.child});